@@ -37,6 +37,34 @@ public class XpathRegressionAnonInnerLengthTest extends AbstractXpathTestSupport
         return checkName;
     }
 
+    @Test
+    public void testDefault() throws Exception {
+        final File fileToProcess =
+            new File(getPath("SuppressionXpathRegressionAnonInnerLengthDefault.java"));
+
+        final DefaultConfiguration moduleConfig =
+            createModuleConfig(AnonInnerLengthCheck.class);
+
+        final String[] expectedViolation = {
+            "7:29: " + getCheckMessage(AnonInnerLengthCheck.class,
+                AnonInnerLengthCheck.MSG_KEY, 26, 20),
+        };
+
+        final List<String> expectedXpathQueries = Arrays.asList(
+            "/CLASS_DEF[./IDENT[@text='SuppressionXpathRegressionAnonInnerLengthDefault']]"
+                + "/OBJBLOCK/METHOD_DEF[./IDENT[@text='test']]"
+                + "/SLIST/VARIABLE_DEF[./IDENT[@text='runnable']]"
+                + "/ASSIGN/EXPR",
+            "/CLASS_DEF[./IDENT[@text='SuppressionXpathRegressionAnonInnerLengthDefault']]"
+                + "/OBJBLOCK/METHOD_DEF[./IDENT[@text='test']]"
+                + "/SLIST/VARIABLE_DEF[./IDENT[@text='runnable']]"
+                + "/ASSIGN/EXPR/LITERAL_NEW[./IDENT[@text='Runnable']]"
+        );
+
+        runVerifications(moduleConfig, fileToProcess, expectedViolation,
+            expectedXpathQueries);
+    }
+
     @Test
     public void testMaxLength() throws Exception {
         final int maxLen = 5;
@@ -48,22 +76,21 @@ public class XpathRegressionAnonInnerLengthTest extends AbstractXpathTestSupport
         moduleConfig.addAttribute("max", String.valueOf(maxLen));
 
         final String[] expectedViolation = {
-            "7:41: " + getCheckMessage(AnonInnerLengthCheck.class,
+            "7:35: " + getCheckMessage(AnonInnerLengthCheck.class,
                     AnonInnerLengthCheck.MSG_KEY, 6, maxLen),
         };
 
         final List<String> expectedXpathQueries = Arrays.asList(
                 "/CLASS_DEF[./IDENT[@text='SuppressionXpathRegressionAnonInnerLength']]"
                         + "/OBJBLOCK/METHOD_DEF[./IDENT[@text='compare']]/SLIST"
-                        + "/VARIABLE_DEF[./IDENT[@text='comparator']]/ASSIGN/EXPR",
+                        + "/VARIABLE_DEF[./IDENT[@text='comp']]/ASSIGN/EXPR",
                 "/CLASS_DEF[./IDENT[@text='SuppressionXpathRegressionAnonInnerLength']]"
                         + "/OBJBLOCK/METHOD_DEF[./IDENT[@text='compare']]/SLIST"
-                        + "/VARIABLE_DEF[./IDENT[@text='comparator']]/ASSIGN/EXPR"
+                        + "/VARIABLE_DEF[./IDENT[@text='comp']]/ASSIGN/EXPR"
                         + "/LITERAL_NEW[./IDENT[@text='Comparator']]"
         );
 
         runVerifications(moduleConfig, fileToProcess, expectedViolation,
                 expectedXpathQueries);
     }
-
 }
