@@ -16,8 +16,8 @@ public class InputEmptyCatchBlockViolationsByVariableName
     private void foo1() {
         try {
             throw new RuntimeException();
-        } catch (Exception e) //warn
-        {}
+        } catch (Exception e)
+        {} // warn
 
     }
 
@@ -32,8 +32,8 @@ public class InputEmptyCatchBlockViolationsByVariableName
     private void foo3() { // comment
         try {
             throw new IOException();
-        } catch (IOException | NullPointerException | ArithmeticException e) //warn
-        {
+        } catch (IOException | NullPointerException | ArithmeticException e)
+        /*warn*/ {
         }
     }
 
@@ -48,15 +48,15 @@ public class InputEmptyCatchBlockViolationsByVariableName
     private void foo5() {
         try {
             throw new IOException();
-        } catch (IOException | NullPointerException | ArithmeticException e) //warn
-        {
+        } catch (IOException | NullPointerException | ArithmeticException e)
+        /*warn*/ {
         }
     }
     private void some() {
         try {
             throw new IOException();
-        } catch (IOException e) //warn
-        {
+        } catch (IOException e)
+        /*warn*/ {
 
         }
     }
