@@ -19,6 +19,10 @@
 
 package com.puppycrawl.tools.checkstyle;
 
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Set;
+
 /**
  * Contains constant definitions common to the package.
  **/
@@ -28,6 +32,12 @@ public final class Definitions {
     public static final String CHECKSTYLE_BUNDLE =
             "com.puppycrawl.tools.checkstyle.messages";
 
+    /** Name of modules which are not checks, but are internal modules. */
+    public static final Set<String> INTERNAL_MODULES = Collections.unmodifiableSet(
+            new HashSet<>(Collections.singletonList(
+                    "com.puppycrawl.tools.checkstyle.meta.JavadocMetadataScraper"
+    )));
+
     /**
      * Do no allow {@code Definitions} instances to be created.
      **/
