@@ -84,19 +84,9 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
         setFileExtensions("java");
     }
 
-    /**
-     * Sets classLoader to load class.
-     * @param classLoader class loader to resolve classes with.
-     * @deprecated Checkstyle is not type aware tool and all class loading is potentially
-     *     unstable.
-     */
-    @Deprecated
-    public void setClassLoader(ClassLoader classLoader) {
-        // no code
-    }
-
     /**
      * Sets the module factory for creating child modules (Checks).
+     *
      * @param moduleFactory the factory
      */
     public void setModuleFactory(ModuleFactory moduleFactory) {
@@ -108,12 +98,12 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
         final DefaultContext checkContext = new DefaultContext();
         checkContext.add("severity", getSeverity());
         checkContext.add("tabWidth", String.valueOf(getTabWidth()));
-
         childContext = checkContext;
     }
 
     /**
      * {@inheritDoc} Creates child module.
+     *
      * @noinspection ChainOfInstanceofChecks
      */
     @Override
@@ -178,6 +168,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Returns filtered set of {@link LocalizedMessage}.
+     *
      * @param fileName path to the file
      * @param fileContents the contents of the file
      * @param rootAST root AST element {@link DetailAST} of the file
@@ -201,6 +192,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Register a check for a given configuration.
+     *
      * @param check the check to register
      * @throws CheckstyleException if an error occurs
      */
@@ -213,7 +205,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
         else {
             tokens = check.getRequiredTokens();
 
-            //register configured tokens
+            // register configured tokens
             final int[] acceptableTokens = check.getAcceptableTokens();
             Arrays.sort(acceptableTokens);
             for (String token : checkTokens) {
@@ -242,6 +234,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Register a check for a specified token id.
+     *
      * @param tokenId the id of the token
      * @param check the check to register
      * @throws CheckstyleException if Check is misconfigured
@@ -252,6 +245,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Register a check for a specified token name.
+     *
      * @param token the name of the token
      * @param check the check to register
      * @throws CheckstyleException if Check is misconfigured
@@ -273,6 +267,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Initiates the walk of an AST.
+     *
      * @param ast the root AST
      * @param contents the contents of the file the AST was generated from.
      * @param astState state of AST.
@@ -286,6 +281,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Notify checks that we are about to begin walking a tree.
+     *
      * @param rootAST the root of the tree.
      * @param contents the contents of the file the AST was generated from.
      * @param astState state of AST.
@@ -310,6 +306,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Notify checks that we have finished walking a tree.
+     *
      * @param rootAST the root of the tree.
      * @param astState state of AST.
      */
@@ -331,6 +328,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Notify checks that visiting a node.
+     *
      * @param ast the node to notify for.
      * @param astState state of AST.
      */
@@ -346,6 +344,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Notify checks that leaving a node.
+     *
      * @param ast
      *        the node to notify for
      * @param astState state of AST.
@@ -409,6 +408,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Returns a set of external configuration resource locations which are used by the filters set.
+     *
      * @return a set of external configuration resource locations which are used by the filters set.
      */
     private Set<String> getExternalResourceLocationsOfFilters() {
@@ -424,6 +424,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
 
     /**
      * Returns a set of external configuration resource locations which are used by the checks set.
+     *
      * @param checks a set of checks.
      * @return a set of external configuration resource locations which are used by the checks set.
      */
@@ -440,6 +441,7 @@ public final class TreeWalker extends AbstractFileSetCheck implements ExternalRe
     /**
      * Processes a node calling interested checks at each node.
      * Uses iterative algorithm.
+     *
      * @param root the root of tree for process
      * @param astState state of AST.
      */
