@@ -30,9 +30,9 @@ import com.puppycrawl.tools.checkstyle.grammar.javadoc.JavadocParser;
  */
 public final class JavadocTokenTypes {
 
-    //--------------------------------------------------------------------------------------------//
-    //------------------        JAVADOC TAGS          --------------------------------------------//
-    //--------------------------------------------------------------------------------------------//
+    // ------------------------------------------------------------------------------------------ //
+    // -----------------        JAVADOC TAGS          ------------------------------------------- //
+    // ------------------------------------------------------------------------------------------ //
 
     /**
      * '@return' literal in {@code @return} Javadoc tag.
@@ -384,6 +384,7 @@ public final class JavadocTokenTypes {
      *         |--JAVADOC_INLINE_TAG_END[3x21] : [}]
      * </code>
      * </pre>
+     *
      * @noinspection HtmlTagCanBeJavadocTag
      */
     public static final int JAVADOC_INLINE_TAG_START = JavadocParser.JAVADOC_INLINE_TAG_START;
@@ -403,6 +404,7 @@ public final class JavadocTokenTypes {
      *         |--JAVADOC_INLINE_TAG_END[3x21] : [}]
      * </code>
      * </pre>
+     *
      * @noinspection HtmlTagCanBeJavadocTag
      */
     public static final int JAVADOC_INLINE_TAG_END = JavadocParser.JAVADOC_INLINE_TAG_END;
@@ -460,7 +462,7 @@ public final class JavadocTokenTypes {
      *
      * <p><b>Example:</b></p>
      * <pre><code>{&#64;docRoot
-     *}</code></pre>
+     * }</code></pre>
      * <b>Tree:</b>
      * <pre>
      * <code>  |--JAVADOC_INLINE_TAG[1x0] : [{&#64;docRoot \n}]
@@ -1010,9 +1012,9 @@ public final class JavadocTokenTypes {
      */
     public static final int FIELD_TYPE = JavadocParser.FIELD_TYPE;
 
-    //--------------------------------------------------------------------------------------------//
-    //------------------        HTML TAGS          -----------------------------------------------//
-    //--------------------------------------------------------------------------------------------//
+    // ------------------------------------------------------------------------------------------ //
+    // -----------------        HTML TAGS          ---------------------------------------------- //
+    // ------------------------------------------------------------------------------------------ //
 
     /**
      * Identifier inside HTML tag: tag name or attribute name.
@@ -1174,14 +1176,9 @@ public final class JavadocTokenTypes {
      */
     public static final int HTML_COMMENT_END = JavadocParser.HTML_COMMENT_END;
 
-    /**
-     * &lt;&#33;[CDATA[&#46;&#46;&#46;]]&gt; block.
-     */
-    public static final int CDATA = JavadocParser.CDATA;
-
-    //--------------------------------------------------------------------------------------------//
-    //------------------        OTHER          ---------------------------------------------------//
-    //--------------------------------------------------------------------------------------------//
+    // ------------------------------------------------------------------------------------------ //
+    // -----------------        OTHER          -------------------------------------------------- //
+    // ------------------------------------------------------------------------------------------ //
 
     /** Leading asterisk. */
     public static final int LEADING_ASTERISK = JavadocParser.LEADING_ASTERISK;
@@ -1208,9 +1205,9 @@ public final class JavadocTokenTypes {
      */
     public static final int EOF = -1;
 
-    //--------------------------------------------------------------------------------------------//
-    //------- JAVADOC TAGS DEPENDING ON RULE TYPES OFFSET ----------------------------------------//
-    //--------------------------------------------------------------------------------------------//
+    // ------------------------------------------------------------------------------------------ //
+    // ------ JAVADOC TAGS DEPENDING ON RULE TYPES OFFSET --------------------------------------- //
+    // ------------------------------------------------------------------------------------------ //
 
     /**
      * Rule types offset.
@@ -1318,6 +1315,7 @@ public final class JavadocTokenTypes {
      *        |--JAVADOC_INLINE_TAG_END[4x16] : [}]
      * </code>
      * </pre>
+     *
      * @noinspection HtmlTagCanBeJavadocTag
      */
     public static final int JAVADOC_INLINE_TAG = JavadocParser.RULE_javadocInlineTag
@@ -1403,9 +1401,9 @@ public final class JavadocTokenTypes {
      */
     public static final int DESCRIPTION = JavadocParser.RULE_description + RULE_TYPES_OFFSET;
 
-    //--------------------------------------------------------------------------------------------//
-    //--------- HTML TAGS DEPENDING ON RULE TYPES OFFSET -----------------------------------------//
-    //--------------------------------------------------------------------------------------------//
+    // ------------------------------------------------------------------------------------------ //
+    // -------- HTML TAGS DEPENDING ON RULE TYPES OFFSET ---------------------------------------- //
+    // ------------------------------------------------------------------------------------------ //
 
     /**
      * Parent node for all html tags.
@@ -1645,6 +1643,7 @@ public final class JavadocTokenTypes {
 
     /**
      * HTML void element {@code <embed>}.
+     *
      * @see #SINGLETON_ELEMENT
      * @see <a href="https://www.w3.org/TR/html51/semantics-embedded-content.html#elementdef-embed">
      *     W3 docs</a>
@@ -1653,6 +1652,7 @@ public final class JavadocTokenTypes {
 
     /**
      * HTML void element {@code <keygen>}.
+     *
      * @see #SINGLETON_ELEMENT
      * @see <a href="https://www.w3.org/TR/html51/sec-forms.html#elementdef-keygen">
      *     W3 docs</a>
@@ -1661,6 +1661,7 @@ public final class JavadocTokenTypes {
 
     /**
      * HTML void element {@code <source>}.
+     *
      * @see #SINGLETON_ELEMENT
      * @see <a href=
      *     "https://www.w3.org/TR/html51/semantics-embedded-content.html#elementdef-media-source">
@@ -1670,6 +1671,7 @@ public final class JavadocTokenTypes {
 
     /**
      * HTML void element {@code <track>}.
+     *
      * @see #SINGLETON_ELEMENT
      * @see <a
      *     href="https://www.w3.org/TR/html51/semantics-embedded-content.html#elementdef-track">
@@ -1679,6 +1681,7 @@ public final class JavadocTokenTypes {
 
     /**
      * HTML void element {@code <wbr>}.
+     *
      * @see #SINGLETON_ELEMENT
      * @see <a href="https://www.w3.org/TR/html51/textlevel-semantics.html#elementdef-wbr">
      *     W3 docs</a>
