@@ -62,6 +62,23 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *
  * }
  * </pre>
+ * <p>Example of record Foo in a file named Test.java</p>
+ * <pre>
+ * record Foo { // violation
+ *
+ * }
+ * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code type.file.mismatch}
+ * </li>
+ * </ul>
  *
  * @since 5.3
  */
@@ -106,6 +123,7 @@ public class OuterTypeFilenameCheck extends AbstractCheck {
             TokenTypes.INTERFACE_DEF,
             TokenTypes.ENUM_DEF,
             TokenTypes.ANNOTATION_DEF,
+            TokenTypes.RECORD_DEF,
         };
     }
 
