@@ -25,6 +25,7 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.regex.Pattern;
 
 import com.puppycrawl.tools.checkstyle.StatelessCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
@@ -43,6 +44,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * <li>
  * Property {@code aliasList} - Specify aliases for check names that can be used in code
  * within {@code SuppressWarnings}.
+ * Type is {@code java.lang.String[]}.
  * Default value is {@code null}.
  * </li>
  * </ul>
@@ -98,6 +100,9 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *   //...
  * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
  *
  * @since 5.7
  */
@@ -133,6 +138,16 @@ public class SuppressWarningsHolder
     private static final ThreadLocal<List<Entry>> ENTRIES =
             ThreadLocal.withInitial(LinkedList::new);
 
+    /**
+     * Compiled pattern used to match whitespace in text block content.
+     */
+    private static final Pattern WHITESPACE = Pattern.compile("\\s+");
+
+    /**
+     * Compiled pattern used to match preceding newline in text block content.
+     */
+    private static final Pattern NEWLINE = Pattern.compile("\\n");
+
     /**
      * Returns the default alias for the source name of a check, which is the
      * source name in lower case with any dotted prefix or "Check" suffix
@@ -470,6 +485,10 @@ public class SuppressWarningsHolder
             case TokenTypes.DOT:
                 expr = firstChild.getLastChild().getText();
                 break;
+            case TokenTypes.TEXT_BLOCK_LITERAL_BEGIN:
+                final String textBlockContent = firstChild.getFirstChild().getText();
+                expr = getContentWithoutPrecedingWhitespace(textBlockContent);
+                break;
             default:
                 // annotations with complex expressions cannot suppress warnings
         }
@@ -518,6 +537,18 @@ public class SuppressWarningsHolder
         return valueList;
     }
 
+    /**
+     * Remove preceding newline and whitespace from the content of a text block.
+     *
+     * @param textBlockContent the actual text in a text block.
+     * @return content of text block with preceding whitespace and newline removed.
+     */
+    private static String getContentWithoutPrecedingWhitespace(String textBlockContent) {
+        final String contentWithNoPrecedingNewline =
+            NEWLINE.matcher(textBlockContent).replaceAll("");
+        return WHITESPACE.matcher(contentWithNoPrecedingNewline).replaceAll("");
+    }
+
     @Override
     public void destroy() {
         super.destroy();
