@@ -35,52 +35,54 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * </p>
  * <ul>
  * <li>
- * {@code ElementStyle.COMPACT_NO_ARRAY}
+ * {@code ElementStyleOption.COMPACT_NO_ARRAY}
  * </li>
  * <li>
- * {@code ElementStyle.COMPACT}
+ * {@code ElementStyleOption.COMPACT}
  * </li>
  * <li>
- * {@code ElementStyle.EXPANDED}
+ * {@code ElementStyleOption.EXPANDED}
  * </li>
  * </ul>
  * <p>
- * To not enforce an element style a {@code ElementStyle.IGNORE} type is provided.
+ * To not enforce an element style a {@code ElementStyleOption.IGNORE} type is provided.
  * The desired style can be set through the {@code elementStyle} property.
  * </p>
  * <p>
- * Using the {@code ElementStyle.EXPANDED} style is more verbose.
+ * Using the {@code ElementStyleOption.EXPANDED} style is more verbose.
  * The expanded version is sometimes referred to as "named parameters" in other languages.
  * </p>
  * <p>
- * Using the {@code ElementStyle.COMPACT} style is less verbose.
+ * Using the {@code ElementStyleOption.COMPACT} style is less verbose.
  * This style can only be used when there is an element called 'value' which is either
  * the sole element or all other elements have default values.
  * </p>
  * <p>
- * Using the {@code ElementStyle.COMPACT_NO_ARRAY} style is less verbose.
- * It is similar to the {@code ElementStyle.COMPACT} style but single value arrays are flagged.
+ * Using the {@code ElementStyleOption.COMPACT_NO_ARRAY} style is less verbose.
+ * It is similar to the {@code ElementStyleOption.COMPACT} style but single value arrays are
+ * flagged.
  * With annotations a single value array does not need to be placed in an array initializer.
  * </p>
  * <p>
  * The ending parenthesis are optional when using annotations with no elements.
- * To always require ending parenthesis use the {@code ClosingParens.ALWAYS} type.
- * To never have ending parenthesis use the {@code ClosingParens.NEVER} type.
- * To not enforce a closing parenthesis preference a {@code ClosingParens.IGNORE} type is provided.
+ * To always require ending parenthesis use the {@code ClosingParensOption.ALWAYS} type.
+ * To never have ending parenthesis use the {@code ClosingParensOption.NEVER} type.
+ * To not enforce a closing parenthesis preference a {@code ClosingParensOption.IGNORE} type is
+ * provided.
  * Set this through the {@code closingParens} property.
  * </p>
  * <p>
  * Annotations also allow you to specify arrays of elements in a standard format.
  * As with normal arrays, a trailing comma is optional.
- * To always require a trailing comma use the {@code TrailingArrayComma.ALWAYS} type.
- * To never have a trailing comma use the {@code TrailingArrayComma.NEVER} type.
- * To not enforce a trailing array comma preference a {@code TrailingArrayComma.IGNORE} type
+ * To always require a trailing comma use the {@code TrailingArrayCommaOption.ALWAYS} type.
+ * To never have a trailing comma use the {@code TrailingArrayCommaOption.NEVER} type.
+ * To not enforce a trailing array comma preference a {@code TrailingArrayCommaOption.IGNORE} type
  * is provided. Set this through the {@code trailingArrayComma} property.
  * </p>
  * <p>
- * By default the {@code ElementStyle} is set to {@code COMPACT_NO_ARRAY},
- * the {@code TrailingArrayComma} is set to {@code NEVER},
- * and the {@code ClosingParens} is set to {@code NEVER}.
+ * By default the {@code ElementStyleOption} is set to {@code COMPACT_NO_ARRAY},
+ * the {@code TrailingArrayCommaOption} is set to {@code NEVER},
+ * and the {@code ClosingParensOption} is set to {@code NEVER}.
  * </p>
  * <p>
  * According to the JLS, it is legal to include a trailing comma
@@ -97,14 +99,20 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * <ul>
  * <li>
  * Property {@code elementStyle} - Define the annotation element styles.
+ * Type is {@code
+ * com.puppycrawl.tools.checkstyle.checks.annotation.AnnotationUseStyleCheck$ElementStyleOption}.
  * Default value is {@code compact_no_array}.
  * </li>
  * <li>
  * Property {@code closingParens} - Define the policy for ending parenthesis.
+ * Type is {@code
+ * com.puppycrawl.tools.checkstyle.checks.annotation.AnnotationUseStyleCheck$ClosingParensOption}.
  * Default value is {@code never}.
  * </li>
  * <li>
  * Property {@code trailingArrayComma} - Define the policy for trailing comma in arrays.
+ * Type is {@code
+ * com.puppycrawl.tools.checkstyle.checks.annotation.AnnotationUseStyleCheck$TrailingArrayCommaOption}.
  * Default value is {@code never}.
  * </li>
  * </ul>
@@ -126,6 +134,29 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *   &lt;property name=&quot;closingParens&quot; value=&quot;always&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code annotation.incorrect.style}
+ * </li>
+ * <li>
+ * {@code annotation.parens.missing}
+ * </li>
+ * <li>
+ * {@code annotation.parens.present}
+ * </li>
+ * <li>
+ * {@code annotation.trailing.comma.missing}
+ * </li>
+ * <li>
+ * {@code annotation.trailing.comma.present}
+ * </li>
+ * </ul>
  *
  * @since 5.0
  *
@@ -136,7 +167,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
     /**
      * Defines the styles for defining elements in an annotation.
      */
-    public enum ElementStyle {
+    public enum ElementStyleOption {
 
         /**
          * Expanded example
@@ -173,7 +204,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
      * elements in an annotation.
      *
      */
-    public enum TrailingArrayComma {
+    public enum TrailingArrayCommaOption {
 
         /**
          * With comma example
@@ -201,7 +232,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
      * elements in an annotation.
      *
      */
-    public enum ClosingParens {
+    public enum ClosingParensOption {
 
         /**
          * With parens example
@@ -269,18 +300,18 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
     /**
      * Define the annotation element styles.
      */
-    private ElementStyle elementStyle = ElementStyle.COMPACT_NO_ARRAY;
+    private ElementStyleOption elementStyle = ElementStyleOption.COMPACT_NO_ARRAY;
 
     // defaulting to NEVER because of the strange compiler behavior
     /**
      * Define the policy for trailing comma in arrays.
      */
-    private TrailingArrayComma trailingArrayComma = TrailingArrayComma.NEVER;
+    private TrailingArrayCommaOption trailingArrayComma = TrailingArrayCommaOption.NEVER;
 
     /**
      * Define the policy for ending parenthesis.
      */
-    private ClosingParens closingParens = ClosingParens.NEVER;
+    private ClosingParensOption closingParens = ClosingParensOption.NEVER;
 
     /**
      * Setter to define the annotation element styles.
@@ -288,7 +319,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
      * @param style string representation
      */
     public void setElementStyle(final String style) {
-        elementStyle = getOption(ElementStyle.class, style);
+        elementStyle = getOption(ElementStyleOption.class, style);
     }
 
     /**
@@ -297,7 +328,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
      * @param comma string representation
      */
     public void setTrailingArrayComma(final String comma) {
-        trailingArrayComma = getOption(TrailingArrayComma.class, comma);
+        trailingArrayComma = getOption(TrailingArrayCommaOption.class, comma);
     }
 
     /**
@@ -306,7 +337,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
      * @param parens string representation
      */
     public void setClosingParens(final String parens) {
-        closingParens = getOption(ClosingParens.class, parens);
+        closingParens = getOption(ClosingParensOption.class, parens);
     }
 
     /**
@@ -348,13 +379,13 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
     @Override
     public void visitToken(final DetailAST ast) {
         checkStyleType(ast);
-        checkCheckClosingParens(ast);
+        checkCheckClosingParensOption(ast);
         checkTrailingComma(ast);
     }
 
     /**
      * Checks to see if the
-     * {@link ElementStyle AnnotationElementStyle}
+     * {@link ElementStyleOption AnnotationElementStyleOption}
      * is correct.
      *
      * @param annotation the annotation token
@@ -386,7 +417,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
             annotation.getChildCount(TokenTypes.ANNOTATION_MEMBER_VALUE_PAIR);
 
         if (valuePairCount == 0 && hasArguments(annotation)) {
-            log(annotation, MSG_KEY_ANNOTATION_INCORRECT_STYLE, ElementStyle.EXPANDED);
+            log(annotation, MSG_KEY_ANNOTATION_INCORRECT_STYLE, ElementStyleOption.EXPANDED);
         }
     }
 
@@ -419,7 +450,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
             && ANNOTATION_ELEMENT_SINGLE_NAME.equals(
                 valuePair.getFirstChild().getText())) {
             log(annotation, MSG_KEY_ANNOTATION_INCORRECT_STYLE,
-                ElementStyle.COMPACT);
+                ElementStyleOption.COMPACT);
         }
     }
 
@@ -436,7 +467,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
         if (arrayInit != null
             && arrayInit.getChildCount(TokenTypes.EXPR) == 1) {
             log(annotation, MSG_KEY_ANNOTATION_INCORRECT_STYLE,
-                ElementStyle.COMPACT_NO_ARRAY);
+                ElementStyleOption.COMPACT_NO_ARRAY);
         }
         // in expanded style with pairs
         else {
@@ -447,7 +478,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
                 if (nestedArrayInit != null
                     && nestedArrayInit.getChildCount(TokenTypes.EXPR) == 1) {
                     log(annotation, MSG_KEY_ANNOTATION_INCORRECT_STYLE,
-                        ElementStyle.COMPACT_NO_ARRAY);
+                        ElementStyleOption.COMPACT_NO_ARRAY);
                 }
                 ast = ast.getNextSibling();
             }
@@ -461,7 +492,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
      * @param annotation the annotation token
      */
     private void checkTrailingComma(final DetailAST annotation) {
-        if (trailingArrayComma != TrailingArrayComma.IGNORE) {
+        if (trailingArrayComma != TrailingArrayCommaOption.IGNORE) {
             DetailAST child = annotation.getFirstChild();
 
             while (child != null) {
@@ -494,7 +525,7 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
         // comma can be null if array is empty
         final DetailAST comma = rCurly.getPreviousSibling();
 
-        if (trailingArrayComma == TrailingArrayComma.ALWAYS) {
+        if (trailingArrayComma == TrailingArrayCommaOption.ALWAYS) {
             if (comma == null || comma.getType() != TokenTypes.COMMA) {
                 log(rCurly, MSG_KEY_ANNOTATION_TRAILING_COMMA_MISSING);
             }
@@ -510,11 +541,11 @@ public final class AnnotationUseStyleCheck extends AbstractCheck {
      *
      * @param ast the annotation token
      */
-    private void checkCheckClosingParens(final DetailAST ast) {
-        if (closingParens != ClosingParens.IGNORE) {
+    private void checkCheckClosingParensOption(final DetailAST ast) {
+        if (closingParens != ClosingParensOption.IGNORE) {
             final DetailAST paren = ast.getLastChild();
 
-            if (closingParens == ClosingParens.ALWAYS) {
+            if (closingParens == ClosingParensOption.ALWAYS) {
                 if (paren.getType() != TokenTypes.RPAREN) {
                     log(ast, MSG_KEY_ANNOTATION_PARENS_MISSING);
                 }
