@@ -47,10 +47,13 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * <li>
  * Property {@code option} - Specify the policy on placement of a right curly brace
  * (<code>'}'</code>).
+ * Type is {@code com.puppycrawl.tools.checkstyle.checks.blocks.RightCurlyOption}.
  * Default value is {@code same}.
  * </li>
  * <li>
  * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
  * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#LITERAL_TRY">
  * LITERAL_TRY</a>,
@@ -203,6 +206,23 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  *   public void violate() { bar(); } // OK , because singleline
  * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code line.alone}
+ * </li>
+ * <li>
+ * {@code line.break.before}
+ * </li>
+ * <li>
+ * {@code line.same}
+ * </li>
+ * </ul>
  *
  * @since 3.0
  */
@@ -272,6 +292,8 @@ public class RightCurlyCheck extends AbstractCheck {
             TokenTypes.ANNOTATION_DEF,
             TokenTypes.ENUM_DEF,
             TokenTypes.INTERFACE_DEF,
+            TokenTypes.RECORD_DEF,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -484,6 +506,7 @@ public class RightCurlyCheck extends AbstractCheck {
             TokenTypes.ENUM_DEF,
             TokenTypes.ANNOTATION_DEF,
             TokenTypes.INTERFACE_DEF,
+            TokenTypes.RECORD_DEF,
         };
 
         /** Right curly. */
@@ -607,8 +630,8 @@ public class RightCurlyCheck extends AbstractCheck {
         }
 
         /**
-         * Collects validation details for CLASS_DEF, METHOD DEF, CTOR_DEF, STATIC_INIT,
-         * INSTANCE_INIT, ANNOTATION_DEF and ENUM_DEF.
+         * Collects validation details for CLASS_DEF, RECORD_DEF, METHOD DEF, CTOR_DEF, STATIC_INIT,
+         * INSTANCE_INIT, ANNOTATION_DEF, ENUM_DEF, and COMPACT_CTOR_DEF.
          *
          * @param ast a {@code DetailAST} value
          * @return an object containing all details to make a validation
