@@ -23,6 +23,7 @@ import com.puppycrawl.tools.checkstyle.StatelessCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * <p>
@@ -37,7 +38,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * };
  * </pre>
  * <p>
- * The check demands a comma at the end if neither left nor right curly braces
+ * By default, the check demands a comma at the end if neither left nor right curly braces
  * are on the same line as the last element of the array.
  * </p>
  * <pre>
@@ -65,7 +66,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * }
  * </pre>
  * <p>
- * If closing brace is on the same line as training comma, this benefit is gone
+ * If closing brace is on the same line as trailing comma, this benefit is gone
  * (as the check does not demand a certain location of curly braces the following
  * two cases will not produce a violation):
  * </p>
@@ -78,7 +79,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *  300000000000000000000,} // Added line
  * </pre>
  * <p>
- * If opening brace is on the same line as training comma there's also (more arguable) problem:
+ * If opening brace is on the same line as trailing comma there's also (more arguable) problem:
  * </p>
  * <pre>
  * {100000000000000000000, // Line cannot be just duplicated to slightly modify entry
@@ -88,6 +89,14 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *  100000000000000000001, // More work needed to duplicate
  * }
  * </pre>
+ * <ul>
+ * <li>
+ * Property {@code alwaysDemandTrailingComma} - Control whether to always check for a trailing
+ * comma, even when an array is inline.
+ * Type is {@code boolean}.
+ * Default value is {@code false}.
+ * </li>
+ * </ul>
  * <p>
  * To configure the check:
  * </p>
@@ -131,6 +140,58 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *   ,};        // no violation
  * </pre>
  *
+ * <p>To configure check to always validate trailing comma:</p>
+ * <pre>
+ * &lt;module name="ArrayTrailingComma"&gt;
+ *   &lt;property name="alwaysDemandTrailingComma" value="true"/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * int[] numbers = {1, 2, 3}; // violation
+ * boolean[] bools = {
+ * true,
+ * true,
+ * false // violation
+ * };
+ *
+ * String[][] text = {{},{},}; // OK
+ *
+ * double[][] decimals = {
+ * {0.5, 2.3, 1.1,}, // OK
+ * {1.7, 1.9, 0.6}, // violation
+ * {0.8, 7.4, 6.5} // violation
+ * }; // violation, previous line misses a comma
+ *
+ * char[] chars = {'a', 'b', 'c'  // violation
+ *   };
+ *
+ * String[] letters = {
+ *   "a", "b", "c"}; // violation
+ *
+ * int[] a1 = new int[]{
+ *   1,
+ *   2
+ *   ,
+ * }; // OK
+ *
+ * int[] a2 = new int[]{
+ *   1,
+ *   2
+ *   ,}; // OK
+ * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code array.trailing.comma}
+ * </li>
+ * </ul>
+ *
  * @since 3.2
  */
 @StatelessCheck
@@ -142,6 +203,20 @@ public class ArrayTrailingCommaCheck extends AbstractCheck {
      */
     public static final String MSG_KEY = "array.trailing.comma";
 
+    /**
+     * Control whether to always check for a trailing comma, even when an array is inline.
+     */
+    private boolean alwaysDemandTrailingComma;
+
+    /**
+     * Setter to control whether to always check for a trailing comma, even when an array is inline.
+     *
+     * @param alwaysDemandTrailingComma whether to always check for a trailing comma.
+     */
+    public void setAlwaysDemandTrailingComma(boolean alwaysDemandTrailingComma) {
+        this.alwaysDemandTrailingComma = alwaysDemandTrailingComma;
+    }
+
     @Override
     public int[] getDefaultTokens() {
         return getRequiredTokens();
@@ -163,10 +238,11 @@ public class ArrayTrailingCommaCheck extends AbstractCheck {
         final DetailAST previousSibling = rcurly.getPreviousSibling();
 
         if (arrayInit.getChildCount() != 1
-                && rcurly.getLineNo() != previousSibling.getLineNo()
-                && arrayInit.getLineNo() != previousSibling.getLineNo()
+                && (alwaysDemandTrailingComma
+                    || !TokenUtil.areOnSameLine(rcurly, previousSibling)
+                        && !TokenUtil.areOnSameLine(arrayInit, previousSibling))
                 && previousSibling.getType() != TokenTypes.COMMA) {
-            log(rcurly.getLineNo(), MSG_KEY);
+            log(previousSibling, MSG_KEY);
         }
     }
 
