@@ -33,7 +33,7 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
 
 /**
  * <p>
- * Checks that the parts of a class or interface declaration appear in the order
+ * Checks that the parts of a class, record, or interface declaration appear in the order
  * suggested by the
  * <a href="https://checkstyle.org/styleguides/sun-code-conventions-19990420/CodeConventions.doc2.html#a1852">
  * Code Conventions for the Java Programming Language</a>.
@@ -74,10 +74,12 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
  * <ul>
  * <li>
  * Property {@code ignoreConstructors} - control whether to ignore constructors.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code ignoreModifiers} - control whether to ignore modifiers (fields, ...).
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * </ul>
@@ -119,6 +121,26 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
  *   int b; &lt;-- &quot;Instance variable definition in wrong order&quot;
  * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code declaration.order.access}
+ * </li>
+ * <li>
+ * {@code declaration.order.constructor}
+ * </li>
+ * <li>
+ * {@code declaration.order.instance}
+ * </li>
+ * <li>
+ * {@code declaration.order.static}
+ * </li>
+ * </ul>
  *
  * @since 3.2
  */
@@ -193,6 +215,7 @@ public class DeclarationOrderCheck extends AbstractCheck {
             TokenTypes.MODIFIERS,
             TokenTypes.OBJBLOCK,
             TokenTypes.VARIABLE_DEF,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -217,6 +240,7 @@ public class DeclarationOrderCheck extends AbstractCheck {
                 }
                 break;
             case TokenTypes.CTOR_DEF:
+            case TokenTypes.COMPACT_CTOR_DEF:
                 if (parentType == TokenTypes.OBJBLOCK) {
                     processConstructor(ast);
                 }
