@@ -38,6 +38,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * <li>
  * Property {@code skipIfLastAndSharedWithCase} - Control whether to allow {@code default}
  * along with {@code case} if they are not last.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * </ul>
@@ -108,7 +109,28 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *   case 2:
  *     break;
  * }
+ *
+ * // Switch rules are not subject to fall through, so this is still a violation:
+ * switch (i) {
+ *   case 1 -&gt; x = 9;
+ *   default -&gt; x = 10; // violation
+ *   case 2 -&gt; x = 32;
+ * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code default.comes.last}
+ * </li>
+ * <li>
+ * {@code default.comes.last.in.casegroup}
+ * </li>
+ * </ul>
  *
  * @since 3.4
  */
@@ -161,7 +183,11 @@ public class DefaultComesLastCheck extends AbstractCheck {
     @Override
     public void visitToken(DetailAST ast) {
         final DetailAST defaultGroupAST = ast.getParent();
-        if (skipIfLastAndSharedWithCase) {
+
+        // Switch rules are not subject to fall through.
+        final boolean isSwitchRule = defaultGroupAST.getType() == TokenTypes.SWITCH_RULE;
+
+        if (skipIfLastAndSharedWithCase && !isSwitchRule) {
             if (Objects.nonNull(findNextSibling(ast, TokenTypes.LITERAL_CASE))) {
                 log(ast, MSG_KEY_SKIP_IF_LAST_AND_SHARED_WITH_CASE);
             }
@@ -172,7 +198,9 @@ public class DefaultComesLastCheck extends AbstractCheck {
             }
         }
         else if (Objects.nonNull(findNextSibling(defaultGroupAST,
-                                                 TokenTypes.CASE_GROUP))) {
+                                            TokenTypes.CASE_GROUP))
+                    || Objects.nonNull(findNextSibling(defaultGroupAST,
+                                            TokenTypes.SWITCH_RULE))) {
             log(ast, MSG_KEY);
         }
     }
