@@ -48,10 +48,13 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
  * Property {@code validateEnhancedForLoopVariable} - Control whether to check
  * <a href="https://docs.oracle.com/javase/specs/jls/se11/html/jls-14.html#jls-14.14.2">
  * enhanced for-loop</a> variable.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
  * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#VARIABLE_DEF">
  * VARIABLE_DEF</a>.
@@ -121,6 +124,17 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
  *   }
  * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code final.variable}
+ * </li>
+ * </ul>
  *
  * @since 3.2
  */
@@ -192,6 +206,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
      * Setter to control whether to check
      * <a href="https://docs.oracle.com/javase/specs/jls/se11/html/jls-14.html#jls-14.14.2">
      * enhanced for-loop</a> variable.
+     *
      * @param validateEnhancedForLoopVariable whether to check for-loop variable
      */
     public final void setValidateEnhancedForLoopVariable(boolean validateEnhancedForLoopVariable) {
@@ -208,6 +223,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
             TokenTypes.OBJBLOCK,
             TokenTypes.LITERAL_BREAK,
             TokenTypes.LITERAL_FOR,
+            TokenTypes.EXPR,
         };
     }
 
@@ -222,6 +238,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
             TokenTypes.LITERAL_BREAK,
             TokenTypes.LITERAL_FOR,
             TokenTypes.VARIABLE_DEF,
+            TokenTypes.EXPR,
         };
     }
 
@@ -237,6 +254,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
             TokenTypes.LITERAL_FOR,
             TokenTypes.VARIABLE_DEF,
             TokenTypes.PARAMETER_DEF,
+            TokenTypes.EXPR,
         };
     }
 
@@ -294,6 +312,14 @@ public class FinalLocalVariableCheck extends AbstractCheck {
             case TokenTypes.LITERAL_BREAK:
                 scopeStack.peek().containsBreak = true;
                 break;
+            case TokenTypes.EXPR:
+                // Switch labeled expression has no slist
+                if (ast.getParent().getType() == TokenTypes.SWITCH_RULE
+                    && ast.getParent().getParent().findFirstToken(TokenTypes.SWITCH_RULE)
+                        == ast.getParent()) {
+                    storePrevScopeUninitializedVariableData();
+                }
+                break;
             default:
                 throw new IllegalStateException("Incorrect token type");
         }
@@ -302,6 +328,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
     @Override
     public void leaveToken(DetailAST ast) {
         Map<String, FinalVariableCandidate> scope = null;
+        final Deque<DetailAST> prevScopeUninitializedVariableData;
         switch (ast.getType()) {
             case TokenTypes.OBJBLOCK:
             case TokenTypes.CTOR_DEF:
@@ -309,11 +336,17 @@ public class FinalLocalVariableCheck extends AbstractCheck {
             case TokenTypes.LITERAL_FOR:
                 scope = scopeStack.pop().scope;
                 break;
+            case TokenTypes.EXPR:
+                // Switch labeled expression has no slist
+                if (ast.getParent().getType() == TokenTypes.SWITCH_RULE) {
+                    prevScopeUninitializedVariableData = prevScopeUninitializedVariables.peek();
+                    if (shouldUpdateUninitializedVariables(ast.getParent())) {
+                        updateAllUninitializedVariables(prevScopeUninitializedVariableData);
+                    }
+                }
+                break;
             case TokenTypes.SLIST:
-                // -@cs[MoveVariableInsideIf] assignment value is modified later so it can't be
-                // moved
-                final Deque<DetailAST> prevScopeUninitializedVariableData =
-                    prevScopeUninitializedVariables.peek();
+                prevScopeUninitializedVariableData = prevScopeUninitializedVariables.peek();
                 boolean containsBreak = false;
                 if (ast.getParent().getType() != TokenTypes.CASE_GROUP
                     || findLastChildWhichContainsSpecifiedToken(ast.getParent().getParent(),
@@ -355,14 +388,19 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Determines identifier assignment conditions (assigned or already assigned).
+     *
      * @param ident identifier.
      * @param candidate final local variable candidate.
      */
     private static void determineAssignmentConditions(DetailAST ident,
                                                       FinalVariableCandidate candidate) {
         if (candidate.assigned) {
-            if (!isInSpecificCodeBlock(ident, TokenTypes.LITERAL_ELSE)
-                    && !isInSpecificCodeBlock(ident, TokenTypes.CASE_GROUP)) {
+            final int[] blockTypes = {
+                TokenTypes.LITERAL_ELSE,
+                TokenTypes.CASE_GROUP,
+                TokenTypes.SWITCH_RULE,
+            };
+            if (!isInSpecificCodeBlocks(ident, blockTypes)) {
                 candidate.alreadyAssigned = true;
             }
         }
@@ -372,18 +410,21 @@ public class FinalLocalVariableCheck extends AbstractCheck {
     }
 
     /**
-     * Checks whether the scope of a node is restricted to a specific code block.
+     * Checks whether the scope of a node is restricted to a specific code blocks.
+     *
      * @param node node.
-     * @param blockType block type.
-     * @return true if the scope of a node is restricted to a specific code block.
+     * @param blockTypes int array of all block types to check.
+     * @return true if the scope of a node is restricted to specific code block types.
      */
-    private static boolean isInSpecificCodeBlock(DetailAST node, int blockType) {
+    private static boolean isInSpecificCodeBlocks(DetailAST node, int... blockTypes) {
         boolean returnValue = false;
-        for (DetailAST token = node.getParent(); token != null; token = token.getParent()) {
-            final int type = token.getType();
-            if (type == blockType) {
-                returnValue = true;
-                break;
+        for (int blockType : blockTypes) {
+            for (DetailAST token = node.getParent(); token != null; token = token.getParent()) {
+                final int type = token.getType();
+                if (type == blockType) {
+                    returnValue = true;
+                    break;
+                }
             }
         }
         return returnValue;
@@ -391,6 +432,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Gets final variable candidate for ast.
+     *
      * @param ast ast.
      * @return Optional of {@link FinalVariableCandidate} for ast from scopeStack.
      */
@@ -417,6 +459,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Update current scope data uninitialized variable according to the whole scope data.
+     *
      * @param prevScopeUninitializedVariableData variable for previous stack of uninitialized
      *     variables
      * @noinspection MethodParameterNamingConvention
@@ -431,6 +474,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Update current scope data uninitialized variable according to the specific scope data.
+     *
      * @param scopeUninitializedVariableData variable for specific stack of uninitialized variables
      */
     private void updateUninitializedVariables(Deque<DetailAST> scopeUninitializedVariableData) {
@@ -461,8 +505,10 @@ public class FinalLocalVariableCheck extends AbstractCheck {
     }
 
     /**
-     * If token is LITERAL_IF and there is an {@code else} following or token is CASE_GROUP and
-     * there is another {@code case} following, then update the uninitialized variables.
+     * If token is LITERAL_IF and there is an {@code else} following or token is CASE_GROUP or
+     * SWITCH_RULE and there is another {@code case} following, then update the
+     * uninitialized variables.
+     *
      * @param ast token to be checked
      * @return true if should be updated, else false
      */
@@ -472,6 +518,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * If token is LITERAL_IF and there is an {@code else} following.
+     *
      * @param ast token to be checked
      * @return true if token is LITERAL_IF and there is an {@code else} following, else false
      */
@@ -481,19 +528,28 @@ public class FinalLocalVariableCheck extends AbstractCheck {
     }
 
     /**
-     * If token is CASE_GROUP and there is another {@code case} following.
+     * If token is CASE_GROUP or SWITCH_RULE and there is another {@code case} following.
+     *
      * @param ast token to be checked
-     * @return true if token is CASE_GROUP and there is another {@code case} following, else false
+     * @return true if token is CASE_GROUP or SWITCH_RULE and there is another {@code case}
+     *     following, else false
      */
     private static boolean isCaseTokenWithAnotherCaseFollowing(DetailAST ast) {
-        return ast.getType() == TokenTypes.CASE_GROUP
-                && findLastChildWhichContainsSpecifiedToken(
-                        ast.getParent(), TokenTypes.CASE_GROUP, TokenTypes.SLIST) != ast;
+        boolean result = false;
+        if (ast.getType() == TokenTypes.CASE_GROUP) {
+            result = findLastChildWhichContainsSpecifiedToken(
+                    ast.getParent(), TokenTypes.CASE_GROUP, TokenTypes.SLIST) != ast;
+        }
+        else if (ast.getType() == TokenTypes.SWITCH_RULE) {
+            result = ast.getNextSibling().getType() == TokenTypes.SWITCH_RULE;
+        }
+        return result;
     }
 
     /**
      * Returns the last child token that makes a specified type and contains containType in
      * its branch.
+     *
      * @param ast token to be tested
      * @param childType the token type to match
      * @param containType the token type which has to be present in the branch
@@ -514,6 +570,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Determines whether enhanced for-loop variable should be checked or not.
+     *
      * @param ast The ast to compare.
      * @return true if enhanced for-loop variable should be checked.
      */
@@ -524,6 +581,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Insert a parameter at the topmost scope stack.
+     *
      * @param ast the variable to insert.
      */
     private void insertParameter(DetailAST ast) {
@@ -534,6 +592,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Insert a variable at the topmost scope stack.
+     *
      * @param ast the variable to insert.
      */
     private void insertVariable(DetailAST ast) {
@@ -550,6 +609,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Check if VARIABLE_DEF is initialized or not.
+     *
      * @param ast VARIABLE_DEF to be checked
      * @return true if initialized
      */
@@ -559,6 +619,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Whether the ast is the first child of its parent.
+     *
      * @param ast the ast to check.
      * @return true if the ast is the first child of its parent.
      */
@@ -568,6 +629,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Removes the final variable candidate from the Stack.
+     *
      * @param ast variable to remove.
      */
     private void removeFinalVariableCandidateFromStack(DetailAST ast) {
@@ -591,6 +653,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Check if given parameter definition is a multiple type catch.
+     *
      * @param parameterDefAst parameter definition
      * @return true if it is a multiple type catch, false otherwise
      */
@@ -602,6 +665,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
     /**
      * Whether the final variable candidate should be removed from the list of final local variable
      * candidates.
+     *
      * @param scopeData the scope data of the variable.
      * @param ast the variable ast.
      * @return true, if the variable should be removed.
@@ -635,6 +699,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
      * }
      * }
      * </p>
+     *
      * @param variable variable.
      * @return true if a variable which is declared outside loop is used inside loop.
      */
@@ -649,6 +714,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Is Arithmetic operator.
+     *
      * @param parentType token AST
      * @return true is token type is in arithmetic operator
      */
@@ -665,6 +731,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
      * }
      * </p>
      * {@code i, j} are defined in {@link TokenTypes#FOR_INIT for-loop init}
+     *
      * @param variableDef variable definition node.
      * @return true if variable is defined in {@link TokenTypes#FOR_INIT for-loop init}
      */
@@ -674,6 +741,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Determines whether an AST is a descendant of an abstract or native method.
+     *
      * @param ast the AST to check.
      * @return true if ast is a descendant of an abstract or native method.
      */
@@ -694,6 +762,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Check if current param is lambda's param.
+     *
      * @param paramDef {@link TokenTypes#PARAMETER_DEF parameter def}.
      * @return true if current param is lambda's param.
      */
@@ -703,6 +772,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Find the Class, Constructor, Enum, Method, or Field in which it is defined.
+     *
      * @param ast Variable for which we want to find the scope in which it is defined
      * @return ast The Class or Constructor or Method in which it is defined.
      */
@@ -720,6 +790,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Check if both the Variables are same.
+     *
      * @param ast1 Variable to compare
      * @param ast2 Variable to compare
      * @return true if both the variables are same, otherwise false
@@ -734,6 +805,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Check if both the variables are in the same loop.
+     *
      * @param ast1 variable to compare.
      * @param ast2 variable to compare.
      * @return true if both the variables are in the same loop.
@@ -752,6 +824,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     /**
      * Checks whether the ast is a loop.
+     *
      * @param ast the ast to check.
      * @return true if the ast is a loop.
      */
@@ -775,6 +848,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
         /**
          * Searches for final local variable candidate for ast in the scope.
+         *
          * @param ast ast.
          * @return Optional of {@link FinalVariableCandidate}.
          */
@@ -794,7 +868,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
     }
 
-    /**Represents information about final local variable candidate. */
+    /** Represents information about final local variable candidate. */
     private static class FinalVariableCandidate {
 
         /** Identifier token. */
@@ -806,6 +880,7 @@ public class FinalLocalVariableCheck extends AbstractCheck {
 
         /**
          * Creates new instance.
+         *
          * @param variableIdent variable identifier.
          */
         /* package */ FinalVariableCandidate(DetailAST variableIdent) {
