@@ -80,36 +80,45 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * <ul>
  * <li>
  * Property {@code validateAbstractClassNames} - Control whether to validate abstract class names.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code illegalClassNames} - Specify classes that should not be used
  * as types in variable declarations, return values or parameters.
+ * Type is {@code java.lang.String[]}.
  * Default value is {@code HashMap, HashSet, LinkedHashMap, LinkedHashSet, TreeMap,
  * TreeSet, java.util.HashMap, java.util.HashSet, java.util.LinkedHashMap,
  * java.util.LinkedHashSet, java.util.TreeMap, java.util.TreeSet}.
  * </li>
  * <li>
  * Property {@code legalAbstractClassNames} - Define abstract classes that may be used as types.
- * Default value is {@code {}}.
+ * Type is {@code java.lang.String[]}.
+ * Default value is {@code ""}.
  * </li>
  * <li>
  * Property {@code ignoredMethodNames} - Specify methods that should not be checked.
+ * Type is {@code java.lang.String[]}.
  * Default value is {@code getEnvironment, getInitialContext}.
  * </li>
  * <li>
  * Property {@code illegalAbstractClassNameFormat} - Specify RegExp for illegal abstract class
  * names.
+ * Type is {@code java.util.regex.Pattern}.
  * Default value is {@code "^(.*[.])?Abstract.*$"}.
  * </li>
  * <li>
  * Property {@code memberModifiers} - Control whether to check only methods and fields with any
  * of the specified modifiers.
  * This property does not affect method calls nor method references.
- * Default value is no tokens.
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenTypesSet}.
+ * Default value is {@code no tokens}.
  * </li>
  * <li>
  * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
  * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#ANNOTATION_FIELD_DEF">
  * ANNOTATION_FIELD_DEF</a>,
@@ -126,17 +135,98 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#PARAMETER_DEF">
  * PARAMETER_DEF</a>,
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#VARIABLE_DEF">
- * VARIABLE_DEF</a>.
+ * VARIABLE_DEF</a>,
+ * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#PATTERN_VARIABLE_DEF">
+ * PATTERN_VARIABLE_DEF</a>,
+ * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#RECORD_DEF">
+ * RECORD_DEF</a>,
+ * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#RECORD_COMPONENT_DEF">
+ * RECORD_COMPONENT_DEF</a>.
  * </li>
  * </ul>
  * <p>
- * To configure the check so that it ignores getInstance() methods:
+ * To configure the default check:
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;IllegalType&quot;/&gt;
+ * </pre>
+ * <pre>
+ * public class Test extends TreeSet { // violation
+ *   public &lt;T extends java.util.HashSet&gt; void method() { // violation
+ *
+ *     LinkedHashMap&lt;Integer, String&gt; lhmap =
+ *     new LinkedHashMap&lt;Integer, String&gt;(); // violation
+ *     TreeMap&lt;Integer, String&gt; treemap =
+ *     new TreeMap&lt;Integer, String&gt;(); // violation
+ *     Test t; // OK
+ *     HashMap&lt;String, String&gt; hmap; // violation
+ *     Queue&lt;Integer&gt; intqueue; // OK
+ *
+ *     java.lang.IllegalArgumentException illegalex; // OK
+ *     java.util.TreeSet treeset; // violation
+ *   }
+ *
+ * }
+ * </pre>
+ * <p>
+ * To configure the Check so that particular tokens are checked:
+ * </p>
+ * <pre>
+ * &lt;module name="IllegalType"&gt;
+ *   &lt;property name="tokens" value="METHOD_DEF"/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <pre>
+ * public class Test extends TreeSet { // OK
+ *   public &lt;T extends java.util.HashSet&gt; void method() { // violation
+ *     LinkedHashMap&lt;Integer, String&gt; lhmap =
+ *     new LinkedHashMap&lt;Integer, String&gt;(); // OK
+ *
+ *     java.lang.IllegalArgumentException illegalex; // OK
+ *     java.util.TreeSet treeset; // Ok
+ *   }
+ *
+ *   public &lt;T extends java.util.HashSet&gt; void typeParam(T t) {} // violation
+ *
+ *   public void fullName(TreeSet a) {} // OK
+ *
+ * }
+ * </pre>
+ * <p>
+ * To configure the Check so that it ignores function() methods:
  * </p>
  * <pre>
  * &lt;module name=&quot;IllegalType&quot;&gt;
- *   &lt;property name=&quot;ignoredMethodNames&quot; value=&quot;getInstance&quot;/&gt;
+ *   &lt;property name=&quot;ignoredMethodNames&quot; value=&quot;function&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <pre>
+ * public class Test {
+ *   public HashMap&lt;String, String&gt; function() { // OK
+ *     // code
+ *   }
+ *
+ *   public HashMap&lt;String, String&gt; function1() { // violation
+ *     // code
+ *   }
+ * }
+ * </pre>
+ * <p>
+ * To configure the Check so that it validates abstract class names:
+ * </p>
+ * <pre>
+ *  &lt;module name=&quot;IllegalType&quot;&gt;
+ *    &lt;property name=&quot;validateAbstractClassNames&quot; value=&quot;true&quot;/&gt;
+ *    &lt;property name=&quot;illegalAbstractClassNameFormat&quot; value=&quot;Gitt&quot;/&gt;
+ *  &lt;/module&gt;
+ * </pre>
+ * <pre>
+ * class Test extends Gitter { // violation
+ * }
+ *
+ * class Test1 extends Github { // OK
+ * }
+ * </pre>
  * <p>
  * To configure the Check so that it verifies only public, protected or static methods and fields:
  * </p>
@@ -146,6 +236,26 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  *    LITERAL_PROTECTED, LITERAL_STATIC&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <pre>
+ * public class Test {
+ *   public HashMap&lt;String, String&gt; function1() { // violation
+ *     // code
+ *   }
+ *
+ *   private HashMap&lt;String, String&gt; function2() { // OK
+ *     // code
+ *   }
+ *
+ *   protected HashMap&lt;Integer, String&gt; function3() { // violation
+ *     // code
+ *   }
+ *
+ *   public static TreeMap&lt;Integer, String&gt; function4() { // violation
+ *     // code
+ *   }
+ *
+ * }
+ * </pre>
  * <p>
  * To configure the check so that it verifies usage of types Boolean and Foo:
  * </p>
@@ -177,6 +287,17 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  *
  * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code illegal.type}
+ * </li>
+ * </ul>
  *
  * @since 3.2
  *
@@ -245,6 +366,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Setter to specify RegExp for illegal abstract class names.
+     *
      * @param pattern a pattern.
      */
     public void setIllegalAbstractClassNameFormat(Pattern pattern) {
@@ -253,6 +375,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Setter to control whether to validate abstract class names.
+     *
      * @param validateAbstractClassNames whether abstract class names must be ignored.
      */
     public void setValidateAbstractClassNames(boolean validateAbstractClassNames) {
@@ -276,6 +399,9 @@ public final class IllegalTypeCheck extends AbstractCheck {
             TokenTypes.METHOD_REF,
             TokenTypes.PARAMETER_DEF,
             TokenTypes.VARIABLE_DEF,
+            TokenTypes.PATTERN_VARIABLE_DEF,
+            TokenTypes.RECORD_DEF,
+            TokenTypes.RECORD_COMPONENT_DEF,
         };
     }
 
@@ -300,6 +426,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
         switch (ast.getType()) {
             case TokenTypes.CLASS_DEF:
             case TokenTypes.INTERFACE_DEF:
+            case TokenTypes.RECORD_DEF:
                 visitTypeDef(ast);
                 break;
             case TokenTypes.METHOD_CALL:
@@ -311,6 +438,8 @@ public final class IllegalTypeCheck extends AbstractCheck {
                 break;
             case TokenTypes.VARIABLE_DEF:
             case TokenTypes.ANNOTATION_FIELD_DEF:
+            case TokenTypes.PATTERN_VARIABLE_DEF:
+            case TokenTypes.RECORD_COMPONENT_DEF:
                 visitVariableDef(ast);
                 break;
             case TokenTypes.PARAMETER_DEF:
@@ -327,6 +456,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
     /**
      * Checks if current method's return type or variable's type is verifiable
      * according to <b>memberModifiers</b> option.
+     *
      * @param methodOrVariableDef METHOD_DEF or VARIABLE_DEF ast node.
      * @return true if member is verifiable according to <b>memberModifiers</b> option.
      */
@@ -363,6 +493,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks the super type and implemented interfaces of a given type.
+     *
      * @param typeDef class or interface for check.
      */
     private void visitTypeDef(DetailAST typeDef) {
@@ -381,6 +512,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks return type of a given method.
+     *
      * @param methodDef method for check.
      */
     private void visitMethodDef(DetailAST methodDef) {
@@ -391,6 +523,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks type of parameters.
+     *
      * @param parameterDef parameter list for check.
      */
     private void visitParameterDef(DetailAST parameterDef) {
@@ -403,6 +536,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks type of given variable.
+     *
      * @param variableDef variable to check.
      */
     private void visitVariableDef(DetailAST variableDef) {
@@ -413,6 +547,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks the type arguments of given method call/reference.
+     *
      * @param methodCallOrRef method call/reference to check.
      */
     private void visitMethodCallOrRef(DetailAST methodCallOrRef) {
@@ -423,6 +558,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
      * Checks imported type (as static and star imports are not supported by Check,
      *  only type is in the consideration).<br>
      * If this type is illegal due to Check's options - puts violation on it.
+     *
      * @param importAst {@link TokenTypes#IMPORT Import}
      */
     private void visitImport(DetailAST importAst) {
@@ -439,6 +575,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
      * import java.util.*;
      * }
      * </p>
+     *
      * @param importAst {@link TokenTypes#IMPORT Import}
      * @return true if it is star import
      */
@@ -458,6 +595,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
     /**
      * Checks type and type arguments/parameters of given method, parameter, variable or
      * method call/reference.
+     *
      * @param ast node to check.
      */
     private void checkClassName(DetailAST ast) {
@@ -468,6 +606,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks the identifier of the given type.
+     *
      * @param type node to check.
      */
     private void checkIdent(DetailAST type) {
@@ -479,6 +618,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks the {@code extends} or {@code implements} statement.
+     *
      * @param clause DetailAST for either {@link TokenTypes#EXTENDS_CLAUSE} or
      *               {@link TokenTypes#IMPLEMENTS_CLAUSE}
      */
@@ -497,6 +637,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks the given type, its arguments and parameters.
+     *
      * @param type node to check.
      */
     private void checkType(DetailAST type) {
@@ -507,6 +648,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks the upper and lower bounds for the given type.
+     *
      * @param type node to check.
      */
     private void checkTypeBounds(DetailAST type) {
@@ -522,6 +664,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks the type parameters of the node.
+     *
      * @param node node to check.
      */
     private void checkTypeParameters(final DetailAST node) {
@@ -533,6 +676,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Checks the type arguments of the node.
+     *
      * @param node node to check.
      */
     private void checkTypeArguments(final DetailAST node) {
@@ -548,6 +692,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Returns true if given class name is one of illegal classes or else false.
+     *
      * @param className class name to check.
      * @return true if given class name is one of illegal classes
      *         or if it matches to abstract class names pattern.
@@ -563,6 +708,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Extends illegal class names set via imported short type name.
+     *
      * @param canonicalName
      *  <a href="https://docs.oracle.com/javase/specs/jls/se8/html/jls-6.html#jls-6.7">
      *  Canonical</a> name of imported type.
@@ -579,6 +725,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
      * Gets imported type's
      * <a href="https://docs.oracle.com/javase/specs/jls/se8/html/jls-6.html#jls-6.7">
      *  canonical name</a>.
+     *
      * @param importAst {@link TokenTypes#IMPORT Import}
      * @return Imported canonical type's name.
      */
@@ -600,6 +747,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
     /**
      * Gets the next node of a syntactical tree (child of a current node or
      * sibling of a current node, or sibling of a parent of a current node).
+     *
      * @param currentNodeAst Current node in considering
      * @param subTreeRootAst SubTree root
      * @return Current node after bypassing, if current node reached the root of a subtree
@@ -623,6 +771,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Returns true if method has to be checked or false.
+     *
      * @param ast method def to check.
      * @return true if we should check this method.
      */
@@ -636,6 +785,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
     /**
      * Setter to specify classes that should not be used as types in variable declarations,
      * return values or parameters.
+     *
      * @param classNames array of illegal variable types
      * @noinspection WeakerAccess
      */
@@ -646,6 +796,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Setter to specify methods that should not be checked.
+     *
      * @param methodNames array of ignored method names
      * @noinspection WeakerAccess
      */
@@ -656,6 +807,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
 
     /**
      * Setter to define abstract classes that may be used as types.
+     *
      * @param classNames array of legal abstract class names
      * @noinspection WeakerAccess
      */
@@ -667,6 +819,7 @@ public final class IllegalTypeCheck extends AbstractCheck {
      * Setter to control whether to check only methods and fields with any of
      * the specified modifiers.
      * This property does not affect method calls nor method references.
+     *
      * @param modifiers String contains modifiers.
      */
     public void setMemberModifiers(String modifiers) {
