@@ -53,28 +53,35 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * <ul>
  * <li>
  * Property {@code ignoreNumbers} - Specify non-magic numbers.
+ * Type is {@code double[]}.
  * Default value is {@code -1, 0, 1, 2}.
  * </li>
  * <li>
  * Property {@code ignoreHashCodeMethod} - Ignore magic numbers in hashCode methods.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code ignoreAnnotation} - Ignore magic numbers in annotation declarations.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code ignoreFieldDeclaration} - Ignore magic numbers in field declarations.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code ignoreAnnotationElementDefaults} -
  * Ignore magic numbers in annotation elements defaults.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * <li>
  * Property {@code constantWaiverParentToken} - Specify tokens that are allowed in the AST path
  * from the number literal to the enclosing constant definition.
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenTypesSet}.
  * Default value is
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#TYPECAST">
  * TYPECAST</a>,
@@ -105,6 +112,8 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * </li>
  * <li>
  * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
  * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#NUM_DOUBLE">
  * NUM_DOUBLE</a>,
@@ -134,6 +143,10 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  *     int i = i + 1; // no violation
  *     int j = j + 8; // violation
  *   }
+ *
+ *   public int hashCode() {
+ *     return 10;    // violation
+ *   }
  * }
  * &#64;interface anno {
  *   int value() default 10; // no violation
@@ -166,6 +179,27 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * }
  * </pre>
  * <p>
+ * To configure the check so that it ignores magic numbers in field declarations:
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;MagicNumber&quot;&gt;
+ *   &lt;property name=&quot;ignoreFieldDeclaration&quot; value=&quot;false&quot;/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>
+ * results in the following violations:
+ * </p>
+ * <pre>
+ * public record MyRecord() {
+ *     private static int myInt = 7; // ok, field declaration
+ *
+ *     void foo() {
+ *         int i = myInt + 1; // no violation, 1 is defined as non-magic
+ *         int j = myInt + 8; // violation
+ *     }
+ * }
+ * </pre>
+ * <p>
  * To configure the check to check annotation element defaults:
  * </p>
  * <pre>
@@ -212,6 +246,36 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * }
  * </pre>
  *
+ * <p>
+ * Config example of ignoreHashCodeMethod option:
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;MagicNumber&quot;&gt;
+ *   &lt;property name=&quot;ignoreHashCodeMethod&quot; value=&quot;true&quot;/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>
+ * result is no violation:
+ * </p>
+ * <pre>
+ * class TestHashCode {
+ *     public int hashCode() {
+ *         return 10;       // OK
+ *     }
+ * }
+ * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code magic.number}
+ * </li>
+ * </ul>
+ *
  * @since 3.1
  */
 @StatelessCheck
@@ -310,6 +374,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Checks if ast is annotation argument and should be checked.
+     *
      * @param ast token to check
      * @return true if element is skipped, false otherwise
      */
@@ -319,6 +384,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Checks if ast is annotation element default value and should be checked.
+     *
      * @param ast token to check
      * @return true if element is skipped, false otherwise
      */
@@ -328,6 +394,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Is magic number some where at ast tree.
+     *
      * @param ast ast token
      * @param constantDefAST constant ast
      * @return true if magic number is present
@@ -348,6 +415,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Finds the constant definition that contains aAST.
+     *
      * @param ast the AST
      * @return the constant def or null if ast is not contained in a constant definition.
      */
@@ -381,6 +449,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Reports aAST as a magic number, includes unary operators as needed.
+     *
      * @param ast the AST node that contains the number to report
      */
     private void reportMagicNumber(DetailAST ast) {
@@ -441,6 +510,7 @@ public class MagicNumberCheck extends AbstractCheck {
     /**
      * Decides whether the number of an AST is in the ignore list of this
      * check.
+     *
      * @param ast the AST to check
      * @return true if the number of ast is in the ignore list of this check.
      */
@@ -468,14 +538,16 @@ public class MagicNumberCheck extends AbstractCheck {
         }
 
         // contains variable declaration
-        // and it is directly inside class declaration
+        // and it is directly inside class or record declaration
         return varDefAST != null
-                && varDefAST.getParent().getParent().getType() == TokenTypes.CLASS_DEF;
+                && (varDefAST.getParent().getParent().getType() == TokenTypes.CLASS_DEF
+                || varDefAST.getParent().getParent().getType() == TokenTypes.RECORD_DEF);
     }
 
     /**
      * Setter to specify tokens that are allowed in the AST path from the
      * number literal to the enclosing constant definition.
+     *
      * @param tokens The string representation of the tokens interested in
      */
     public void setConstantWaiverParentToken(String... tokens) {
@@ -488,6 +560,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Setter to specify non-magic numbers.
+     *
      * @param list list of numbers to ignore.
      */
     public void setIgnoreNumbers(double... list) {
@@ -503,6 +576,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Setter to ignore magic numbers in hashCode methods.
+     *
      * @param ignoreHashCodeMethod decide whether to ignore
      *     hash code methods
      */
@@ -512,6 +586,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Setter to ignore magic numbers in annotation declarations.
+     *
      * @param ignoreAnnotation decide whether to ignore annotations
      */
     public void setIgnoreAnnotation(boolean ignoreAnnotation) {
@@ -520,6 +595,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Setter to ignore magic numbers in field declarations.
+     *
      * @param ignoreFieldDeclaration decide whether to ignore magic numbers
      *     in field declaration
      */
@@ -529,6 +605,7 @@ public class MagicNumberCheck extends AbstractCheck {
 
     /**
      * Setter to ignore magic numbers in annotation elements defaults.
+     *
      * @param ignoreAnnotationElementDefaults decide whether to ignore annotation elements defaults
      */
     public void setIgnoreAnnotationElementDefaults(boolean ignoreAnnotationElementDefaults) {
