@@ -24,6 +24,7 @@ import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CheckUtil;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * <p>
@@ -42,6 +43,20 @@ import com.puppycrawl.tools.checkstyle.utils.CheckUtil;
  * <pre>
  * &lt;module name="MultipleVariableDeclarations"/&gt;
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code multiple.variable.declarations}
+ * </li>
+ * <li>
+ * {@code multiple.variable.declarations.comma}
+ * </li>
+ * </ul>
  *
  * @since 3.4
  */
@@ -105,7 +120,7 @@ public class MultipleVariableDeclarationsCheck extends AbstractCheck {
                     final DetailAST lastNode = getLastNode(ast);
                     final DetailAST firstNextNode = CheckUtil.getFirstNode(nextNode);
 
-                    if (firstNextNode.getLineNo() == lastNode.getLineNo()) {
+                    if (TokenUtil.areOnSameLine(firstNextNode, lastNode)) {
                         log(firstNode, MSG_MULTIPLE);
                     }
                 }
@@ -115,6 +130,7 @@ public class MultipleVariableDeclarationsCheck extends AbstractCheck {
 
     /**
      * Finds sub-node for given node maximum (line, column) pair.
+     *
      * @param node the root of tree for search.
      * @return sub-node with maximum (line, column) pair.
      */
