@@ -68,15 +68,18 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * <ul>
  * <li>
  * Property {@code checkFields} - Control whether to check references to fields.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * <li>
  * Property {@code checkMethods} - Control whether to check references to methods.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * <li>
  * Property {@code validateOnlyOverlapping} - Control whether to check only
  * overlapping by variables or arguments.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * </ul>
@@ -127,6 +130,13 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  *     return field += "suffix"; // violation: Reference to instance variable "field" needs "this".
  *   }
  * }
+ *
+ * public static record C(int x) {
+ *     void getTwoX(int x) {
+ *         // Overlapping by method argument.
+ *         return x += x; // violation: Reference to instance variable "x" needs "this".
+ *     }
+ * }
  * </pre>
  * <p>
  * Please, be aware of the following logic, which is implemented in the check:
@@ -207,7 +217,27 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  *     s2 += s2; // Violation. Overlapping. Reference to instance variable 's2' needs "this.".
  *   }
  * }
+ *
+ * public static record D(int x) {
+ *     public D {
+ *         x = x; // violation: Reference to instance variable "x" needs "this".
+ *     }
+ * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code require.this.method}
+ * </li>
+ * <li>
+ * {@code require.this.variable}
+ * </li>
+ * </ul>
  *
  * @since 3.4
  */
@@ -238,6 +268,8 @@ public class RequireThisCheck extends AbstractCheck {
             TokenTypes.INTERFACE_DEF,
             TokenTypes.PARAMETER_DEF,
             TokenTypes.TYPE_ARGUMENT,
+            TokenTypes.RECORD_DEF,
+            TokenTypes.RECORD_COMPONENT_DEF,
         }).collect(Collectors.toSet()));
     /** Set of all assign tokens. */
     private static final Set<Integer> ASSIGN_TOKENS = Collections.unmodifiableSet(
@@ -282,6 +314,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Setter to control whether to check references to fields.
+     *
      * @param checkFields should we check fields usage or not.
      */
     public void setCheckFields(boolean checkFields) {
@@ -290,6 +323,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Setter to control whether to check references to methods.
+     *
      * @param checkMethods should we check methods usage or not.
      */
     public void setCheckMethods(boolean checkMethods) {
@@ -298,6 +332,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Setter to control whether to check only overlapping by variables or arguments.
+     *
      * @param validateOnlyOverlapping should we check only overlapping by variables or arguments.
      */
     public void setValidateOnlyOverlapping(boolean validateOnlyOverlapping) {
@@ -321,6 +356,8 @@ public class RequireThisCheck extends AbstractCheck {
             TokenTypes.LITERAL_FOR,
             TokenTypes.SLIST,
             TokenTypes.IDENT,
+            TokenTypes.RECORD_DEF,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -353,20 +390,21 @@ public class RequireThisCheck extends AbstractCheck {
     @Override
     public void visitToken(DetailAST ast) {
         switch (ast.getType()) {
-            case TokenTypes.IDENT :
+            case TokenTypes.IDENT:
                 processIdent(ast);
                 break;
-            case TokenTypes.CLASS_DEF :
-            case TokenTypes.INTERFACE_DEF :
-            case TokenTypes.ENUM_DEF :
-            case TokenTypes.ANNOTATION_DEF :
-            case TokenTypes.SLIST :
-            case TokenTypes.METHOD_DEF :
-            case TokenTypes.CTOR_DEF :
-            case TokenTypes.LITERAL_FOR :
+            case TokenTypes.CLASS_DEF:
+            case TokenTypes.INTERFACE_DEF:
+            case TokenTypes.ENUM_DEF:
+            case TokenTypes.ANNOTATION_DEF:
+            case TokenTypes.SLIST:
+            case TokenTypes.METHOD_DEF:
+            case TokenTypes.CTOR_DEF:
+            case TokenTypes.LITERAL_FOR:
+            case TokenTypes.RECORD_DEF:
                 current.push(frames.get(ast));
                 break;
-            default :
+            default:
                 // do nothing
         }
     }
@@ -374,17 +412,18 @@ public class RequireThisCheck extends AbstractCheck {
     @Override
     public void leaveToken(DetailAST ast) {
         switch (ast.getType()) {
-            case TokenTypes.CLASS_DEF :
-            case TokenTypes.INTERFACE_DEF :
-            case TokenTypes.ENUM_DEF :
-            case TokenTypes.ANNOTATION_DEF :
-            case TokenTypes.SLIST :
-            case TokenTypes.METHOD_DEF :
-            case TokenTypes.CTOR_DEF :
+            case TokenTypes.CLASS_DEF:
+            case TokenTypes.INTERFACE_DEF:
+            case TokenTypes.ENUM_DEF:
+            case TokenTypes.ANNOTATION_DEF:
+            case TokenTypes.SLIST:
+            case TokenTypes.METHOD_DEF:
+            case TokenTypes.CTOR_DEF:
             case TokenTypes.LITERAL_FOR:
+            case TokenTypes.RECORD_DEF:
                 current.pop();
                 break;
-            default :
+            default:
                 // do nothing
         }
     }
@@ -392,6 +431,7 @@ public class RequireThisCheck extends AbstractCheck {
     /**
      * Checks if a given IDENT is method call or field name which
      * requires explicit {@code this} qualifier.
+     *
      * @param ast IDENT to check.
      */
     private void processIdent(DetailAST ast) {
@@ -428,6 +468,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Helper method to log a LocalizedMessage.
+     *
      * @param ast a node to get line id column numbers associated with the message.
      * @param msgKey key to locale message format.
      * @param frame the class frame where the violation is found.
@@ -444,6 +485,7 @@ public class RequireThisCheck extends AbstractCheck {
     /**
      * Returns the frame where the field is declared, if the given field is used without
      * 'this', and null otherwise.
+     *
      * @param ast field definition ast token.
      * @param parentType type of the parent.
      * @return the frame where the field is declared, if the given field is used without
@@ -470,6 +512,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Parses the next AST for declarations.
+     *
      * @param frameStack stack containing the FrameTree being built.
      * @param ast AST to parse.
      */
@@ -477,10 +520,14 @@ public class RequireThisCheck extends AbstractCheck {
     private static void collectDeclarations(Deque<AbstractFrame> frameStack, DetailAST ast) {
         final AbstractFrame frame = frameStack.peek();
         switch (ast.getType()) {
-            case TokenTypes.VARIABLE_DEF :
+            case TokenTypes.VARIABLE_DEF:
                 collectVariableDeclarations(ast, frame);
                 break;
-            case TokenTypes.PARAMETER_DEF :
+            case TokenTypes.RECORD_COMPONENT_DEF:
+                final DetailAST componentIdent = ast.findFirstToken(TokenTypes.IDENT);
+                ((ClassFrame) frame).addInstanceMember(componentIdent);
+                break;
+            case TokenTypes.PARAMETER_DEF:
                 if (!CheckUtil.isReceiverParameter(ast)
                         && !isLambdaParameter(ast)
                         && ast.getParent().getType() != TokenTypes.LITERAL_CATCH) {
@@ -488,17 +535,18 @@ public class RequireThisCheck extends AbstractCheck {
                     frame.addIdent(parameterIdent);
                 }
                 break;
-            case TokenTypes.CLASS_DEF :
-            case TokenTypes.INTERFACE_DEF :
-            case TokenTypes.ENUM_DEF :
-            case TokenTypes.ANNOTATION_DEF :
+            case TokenTypes.CLASS_DEF:
+            case TokenTypes.INTERFACE_DEF:
+            case TokenTypes.ENUM_DEF:
+            case TokenTypes.ANNOTATION_DEF:
+            case TokenTypes.RECORD_DEF:
                 final DetailAST classFrameNameIdent = ast.findFirstToken(TokenTypes.IDENT);
                 frameStack.addFirst(new ClassFrame(frame, classFrameNameIdent));
                 break;
-            case TokenTypes.SLIST :
+            case TokenTypes.SLIST:
                 frameStack.addFirst(new BlockFrame(frame, ast));
                 break;
-            case TokenTypes.METHOD_DEF :
+            case TokenTypes.METHOD_DEF:
                 final DetailAST methodFrameNameIdent = ast.findFirstToken(TokenTypes.IDENT);
                 final DetailAST mods = ast.findFirstToken(TokenTypes.MODIFIERS);
                 if (mods.findFirstToken(TokenTypes.LITERAL_STATIC) == null) {
@@ -509,11 +557,12 @@ public class RequireThisCheck extends AbstractCheck {
                 }
                 frameStack.addFirst(new MethodFrame(frame, methodFrameNameIdent));
                 break;
-            case TokenTypes.CTOR_DEF :
+            case TokenTypes.CTOR_DEF:
+            case TokenTypes.COMPACT_CTOR_DEF:
                 final DetailAST ctorFrameNameIdent = ast.findFirstToken(TokenTypes.IDENT);
                 frameStack.addFirst(new ConstructorFrame(frame, ctorFrameNameIdent));
                 break;
-            case TokenTypes.ENUM_CONSTANT_DEF :
+            case TokenTypes.ENUM_CONSTANT_DEF:
                 final DetailAST ident = ast.findFirstToken(TokenTypes.IDENT);
                 ((ClassFrame) frame).addStaticMember(ident);
                 break;
@@ -540,6 +589,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Collects variable declarations.
+     *
      * @param ast variable token.
      * @param frame current frame.
      */
@@ -563,34 +613,38 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Ends parsing of the AST for declarations.
+     *
      * @param frameStack Stack containing the FrameTree being built.
      * @param ast AST that was parsed.
      */
     private void endCollectingDeclarations(Queue<AbstractFrame> frameStack, DetailAST ast) {
         switch (ast.getType()) {
-            case TokenTypes.CLASS_DEF :
-            case TokenTypes.INTERFACE_DEF :
-            case TokenTypes.ENUM_DEF :
-            case TokenTypes.ANNOTATION_DEF :
-            case TokenTypes.SLIST :
-            case TokenTypes.METHOD_DEF :
-            case TokenTypes.CTOR_DEF :
-            case TokenTypes.LITERAL_CATCH :
-            case TokenTypes.LITERAL_FOR :
+            case TokenTypes.CLASS_DEF:
+            case TokenTypes.INTERFACE_DEF:
+            case TokenTypes.ENUM_DEF:
+            case TokenTypes.ANNOTATION_DEF:
+            case TokenTypes.SLIST:
+            case TokenTypes.METHOD_DEF:
+            case TokenTypes.CTOR_DEF:
+            case TokenTypes.LITERAL_CATCH:
+            case TokenTypes.LITERAL_FOR:
+            case TokenTypes.RECORD_DEF:
+            case TokenTypes.COMPACT_CTOR_DEF:
                 frames.put(ast, frameStack.poll());
                 break;
-            case TokenTypes.LITERAL_NEW :
+            case TokenTypes.LITERAL_NEW:
                 if (isAnonymousClassDef(ast)) {
                     frames.put(ast, frameStack.poll());
                 }
                 break;
-            default :
+            default:
                 // do nothing
         }
     }
 
     /**
      * Whether the AST is a definition of an anonymous class.
+     *
      * @param ast the AST to process.
      * @return true if the AST is a definition of an anonymous class.
      */
@@ -603,6 +657,7 @@ public class RequireThisCheck extends AbstractCheck {
     /**
      * Returns the class frame where violation is found (where the field is used without 'this')
      * or null otherwise.
+     *
      * @param ast IDENT ast to check.
      * @return the class frame where violation is found or null otherwise.
      */
@@ -666,6 +721,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks whether user arranges 'this' for variable in method, constructor, or block on his own.
+     *
      * @param currentFrame current frame.
      * @param ident ident token.
      * @return true if user arranges 'this' for variable in method, constructor,
@@ -697,6 +753,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Returns the token which ends the code block.
+     *
      * @param blockNameIdent block name identifier.
      * @param blockStartToken token which starts the block.
      * @return the token which ends the code block.
@@ -712,7 +769,7 @@ public class RequireThisCheck extends AbstractCheck {
                     TokenTypes.RCURLY);
             for (DetailAST currentRcurly : rcurlyTokens) {
                 final DetailAST parent = currentRcurly.getParent();
-                if (blockStartToken.getLineNo() == parent.getLineNo()) {
+                if (TokenUtil.areOnSameLine(blockStartToken, parent)) {
                     blockEndToken = currentRcurly;
                 }
             }
@@ -722,6 +779,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks whether the current variable is returned from the method.
+     *
      * @param currentFrame current frame.
      * @param ident variable ident token.
      * @return true if the current variable is returned from the method.
@@ -747,6 +805,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks if the given {@code ast} is equal to the {@code tree} or a child of it.
+     *
      * @param tree The tree to search.
      * @param ast The AST to look for.
      * @return {@code true} if the {@code ast} was found.
@@ -769,6 +828,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks whether a field can be referenced from a static context.
+     *
      * @param ident ident token.
      * @return true if field can be referenced from a static context.
      */
@@ -811,6 +871,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Returns code block definition token for current identifier.
+     *
      * @param ident ident token.
      * @return code block definition token for current identifier or null if code block
      *         definition was not found.
@@ -830,6 +891,7 @@ public class RequireThisCheck extends AbstractCheck {
      * Checks whether a value can be assigned to a field.
      * A value can be assigned to a final field only in constructor block. If there is a method
      * block, value assignment can be performed only to non final field.
+     *
      * @param ast an identifier token.
      * @return true if a value can be assigned to a field.
      */
@@ -845,6 +907,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks whether a field usage frame is inside constructor frame.
+     *
      * @param frame frame, where field is used.
      * @return true if the field usage frame is inside constructor frame.
      */
@@ -864,6 +927,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks whether an overlapping by method or constructor argument takes place.
+     *
      * @param ast an identifier.
      * @return true if an overlapping by method or constructor argument takes place.
      */
@@ -886,6 +950,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks whether an overlapping by local variable takes place.
+     *
      * @param ast an identifier.
      * @return true if an overlapping by local variable takes place.
      */
@@ -903,6 +968,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Collects all tokens of specific type starting with the current ast node.
+     *
      * @param ast ast node.
      * @param tokenType token type.
      * @return a set of all tokens of specific type starting with the current ast node.
@@ -931,6 +997,7 @@ public class RequireThisCheck extends AbstractCheck {
     /**
      * Collects all tokens of specific type starting with the current ast node and which line
      * number is lower or equal to the end line number.
+     *
      * @param ast ast node.
      * @param tokenType token type.
      * @param endLineNumber end line number.
@@ -963,6 +1030,7 @@ public class RequireThisCheck extends AbstractCheck {
     /**
      * Collects all tokens which are equal to current token starting with the current ast node and
      * which line number is lower or equal to the end line number.
+     *
      * @param ast ast node.
      * @param token token.
      * @param endLineNumber end line number.
@@ -995,6 +1063,7 @@ public class RequireThisCheck extends AbstractCheck {
     /**
      * Returns the frame where the method is declared, if the given method is used without
      * 'this' and null otherwise.
+     *
      * @param ast the IDENT ast of the name to check.
      * @return the frame where the method is declared, if the given method is used without
      *         'this' and null otherwise.
@@ -1014,6 +1083,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Find the class frame containing declaration.
+     *
      * @param name IDENT ast of the declaration to find.
      * @param lookForMethod whether we are looking for a method name.
      * @return AbstractFrame containing declaration or null.
@@ -1036,6 +1106,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Find frame containing declaration.
+     *
      * @param name IDENT ast of the declaration to find.
      * @param lookForMethod whether we are looking for a method name.
      * @return AbstractFrame containing declaration or null.
@@ -1046,6 +1117,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Find frame containing declaration.
+     *
      * @param frame The parent frame to searching in.
      * @param name IDENT ast of the declaration to find.
      * @param lookForMethod whether we are looking for a method name.
@@ -1058,6 +1130,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Check that token is related to Definition tokens.
+     *
      * @param parentType token Type.
      * @return true if token is related to Definition Tokens.
      */
@@ -1067,6 +1140,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Check that token is related to assign tokens.
+     *
      * @param tokenType token type.
      * @return true if token is related to assign tokens.
      */
@@ -1076,6 +1150,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Check that token is related to compound assign tokens.
+     *
      * @param tokenType token type.
      * @return true if token is related to compound assign tokens.
      */
@@ -1085,6 +1160,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Gets the name of the nearest parent ClassFrame.
+     *
      * @return the name of the nearest parent ClassFrame.
      */
     private String getNearestClassFrameName() {
@@ -1097,6 +1173,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks if the token is a Lambda parameter.
+     *
      * @param ast the {@code DetailAST} value of the token to be checked
      * @return true if the token is a Lambda parameter
      */
@@ -1132,6 +1209,7 @@ public class RequireThisCheck extends AbstractCheck {
 
     /**
      * Checks if 2 AST are similar by their type and text.
+     *
      * @param left The first AST to check.
      * @param right The second AST to check.
      * @return {@code true} if they are similar.
@@ -1153,7 +1231,7 @@ public class RequireThisCheck extends AbstractCheck {
         BLOCK_FRAME,
         /** Catch frame type. */
         CATCH_FRAME,
-        /** Lambda frame type. */
+        /** For frame type. */
         FOR_FRAME,
 
     }
@@ -1174,6 +1252,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Constructor -- invocable only via super() from subclasses.
+         *
          * @param parent parent frame.
          * @param ident frame name ident.
          */
@@ -1185,12 +1264,14 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Get the type of the frame.
+         *
          * @return a FrameType.
          */
         protected abstract FrameType getType();
 
         /**
          * Add a name to the frame.
+         *
          * @param identToAdd the name we're adding.
          */
         private void addIdent(DetailAST identToAdd) {
@@ -1211,6 +1292,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Check whether the frame contains a field or a variable with the given name.
+         *
          * @param nameToFind the IDENT ast of the name we're looking for.
          * @return whether it was found.
          */
@@ -1220,6 +1302,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Check whether the frame contains a given name.
+         *
          * @param nameToFind IDENT ast of the name we're looking for.
          * @param lookForMethod whether we are looking for a method name.
          * @return whether it was found.
@@ -1240,6 +1323,7 @@ public class RequireThisCheck extends AbstractCheck {
         /**
          * Whether the set contains a declaration with the text of the specified
          * IDENT ast and it is declared in a proper position.
+         *
          * @param set the set of declarations.
          * @param ident the specified IDENT ast.
          * @return true if the set contains a declaration with the text of the specified
@@ -1258,6 +1342,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Whether the definition is correspondent to the IDENT.
+         *
          * @param ident the IDENT ast to check.
          * @param ast the IDENT ast of the definition to check.
          * @return true if ast is correspondent to ident.
@@ -1276,6 +1361,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Creates method frame.
+         *
          * @param parent parent frame.
          * @param ident method name identifier token.
          */
@@ -1297,6 +1383,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Creates a constructor frame.
+         *
          * @param parent parent frame.
          * @param ident frame name ident.
          */
@@ -1327,6 +1414,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Creates new instance of ClassFrame.
+         *
          * @param parent parent frame.
          * @param ident frame name ident.
          */
@@ -1345,6 +1433,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Adds static member's ident.
+         *
          * @param ident an ident of static member of the class.
          */
         public void addStaticMember(final DetailAST ident) {
@@ -1353,6 +1442,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Adds static method's name.
+         *
          * @param ident an ident of static method of the class.
          */
         public void addStaticMethod(final DetailAST ident) {
@@ -1361,6 +1451,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Adds instance member's ident.
+         *
          * @param ident an ident of instance member of the class.
          */
         public void addInstanceMember(final DetailAST ident) {
@@ -1369,6 +1460,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Adds instance method's name.
+         *
          * @param ident an ident of instance method of the class.
          */
         public void addInstanceMethod(final DetailAST ident) {
@@ -1377,6 +1469,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Checks if a given name is a known instance member of the class.
+         *
          * @param ident the IDENT ast of the name to check.
          * @return true is the given name is a name of a known
          *         instance member of the class.
@@ -1387,6 +1480,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Checks if a given name is a known instance method of the class.
+         *
          * @param ident the IDENT ast of the method call to check.
          * @return true if the given ast is correspondent to a known
          *         instance method of the class.
@@ -1397,6 +1491,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Checks if a given name is a known static method of the class.
+         *
          * @param ident the IDENT ast of the method call to check.
          * @return true is the given ast is correspondent to a known
          *         instance method of the class.
@@ -1407,6 +1502,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Checks whether given instance member has final modifier.
+         *
          * @param instanceMember an instance member of a class.
          * @return true if given instance member has final modifier.
          */
@@ -1451,6 +1547,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Check whether the frame contains a given method.
+         *
          * @param methodToFind the AST of the method to find.
          * @return true, if a method with the same name and number of parameters is found.
          */
@@ -1462,6 +1559,7 @@ public class RequireThisCheck extends AbstractCheck {
         /**
          * Whether the set contains a method definition with the
          *     same name and number of parameters.
+         *
          * @param set the set of definitions.
          * @param ident the specified method call IDENT ast.
          * @return true if the set contains a definition with the
@@ -1480,6 +1578,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Whether the method definition has the same name and number of parameters.
+         *
          * @param ident the specified method call IDENT ast.
          * @param ast the ast of a method definition to compare with.
          * @return true if a method definition has the same name and number of parameters
@@ -1509,6 +1608,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Creates anonymous class frame.
+         *
          * @param parent parent frame.
          * @param frameName name of the frame.
          */
@@ -1531,6 +1631,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Creates block frame.
+         *
          * @param parent parent frame.
          * @param ident ident frame name ident.
          */
@@ -1552,6 +1653,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Creates catch frame.
+         *
          * @param parent parent frame.
          * @param ident ident frame name ident.
          */
@@ -1573,6 +1675,7 @@ public class RequireThisCheck extends AbstractCheck {
 
         /**
          * Creates for frame.
+         *
          * @param parent parent frame.
          * @param ident ident frame name ident.
          */
