@@ -23,6 +23,7 @@ import java.util.AbstractMap.SimpleEntry;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map.Entry;
+import java.util.Optional;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -31,6 +32,7 @@ import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.FullIdent;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * <p>
@@ -88,24 +90,31 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * <li>
  * Property {@code allowedDistance} - Specify distance between declaration
  * of variable and its first usage. Values should be greater than 0.
+ * Type is {@code int}.
  * Default value is {@code 3}.
  * </li>
  * <li>
  * Property {@code ignoreVariablePattern} - Define RegExp to ignore distance calculation
  * for variables listed in this pattern.
+ * Type is {@code java.util.regex.Pattern}.
  * Default value is {@code ""}.
  * </li>
  * <li>
  * Property {@code validateBetweenScopes} - Allow to calculate the distance between
  * declaration of variable and its first usage in the different scopes.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code ignoreFinal} - Allow to ignore variables with a 'final' modifier.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * </ul>
  * <p>
+ * To configure the check:
+ * </p>
+ * <p>
  * Example #1:
  * </p>
  * <pre>
@@ -180,6 +189,20 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  *   &lt;property name=&quot;ignoreFinal&quot; value=&quot;false&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code variable.declaration.usage.distance}
+ * </li>
+ * <li>
+ * {@code variable.declaration.usage.distance.extend}
+ * </li>
+ * </ul>
  *
  * @since 5.8
  */
@@ -719,21 +742,18 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
      */
     private static DetailAST getFirstNodeInsideSwitchBlock(
             DetailAST block, DetailAST variable) {
-        DetailAST currentNode = block
-                .findFirstToken(TokenTypes.CASE_GROUP);
+        final DetailAST currentNode = getFirstCaseGroupOrSwitchRule(block);
         final List<DetailAST> variableUsageExpressions =
                 new ArrayList<>();
 
-        // Checking variable usage inside all CASE blocks.
-        while (currentNode.getType() == TokenTypes.CASE_GROUP) {
+        // Checking variable usage inside all CASE_GROUP and SWITCH_RULE ast's.
+        TokenUtil.forEachChild(block, currentNode.getType(), node -> {
             final DetailAST lastNodeInCaseGroup =
-                    currentNode.getLastChild();
-
+                node.getLastChild();
             if (isChild(lastNodeInCaseGroup, variable)) {
                 variableUsageExpressions.add(lastNodeInCaseGroup);
             }
-            currentNode = currentNode.getNextSibling();
-        }
+        });
 
         // If variable usage exists in several related blocks, then
         // firstNodeInsideBlock = null, otherwise if variable usage exists
@@ -747,6 +767,18 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
         return firstNodeInsideBlock;
     }
 
+    /**
+     * Helper method for getFirstNodeInsideSwitchBlock to return the first CASE_GROUP or
+     * SWITCH_RULE ast.
+     *
+     * @param block the switch block to check.
+     * @return DetailAST of the first CASE_GROUP or SWITCH_RULE.
+     */
+    private static DetailAST getFirstCaseGroupOrSwitchRule(DetailAST block) {
+        return Optional.ofNullable(block.findFirstToken(TokenTypes.CASE_GROUP))
+            .orElse(block.findFirstToken(TokenTypes.SWITCH_RULE));
+    }
+
     /**
      * Gets first Ast node inside TRY-CATCH-FINALLY blocks if variable usage is
      * met only inside the block (not in its declaration!).
