@@ -156,6 +156,7 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  * <li>
  * Property {@code ignoredAnnotations} - Specify annotations which allow the check to
  * skip the method from validation.
+ * Type is {@code java.lang.String[]}.
  * Default value is {@code After, AfterClass, Before, BeforeClass, Test}.
  * </li>
  * </ul>
@@ -205,7 +206,18 @@ import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
  *
  *   public int foo4() {return 4;} // violation
  * }
- *</pre>
+ * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code design.forExtension}
+ * </li>
+ * </ul>
  *
  * @since 3.1
  */
@@ -226,6 +238,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
 
     /**
      * Setter to specify annotations which allow the check to skip the method from validation.
+     *
      * @param ignoredAnnotations method annotations.
      */
     public void setIgnoredAnnotations(String... ignoredAnnotations) {
@@ -261,7 +274,8 @@ public class DesignForExtensionCheck extends AbstractCheck {
                 && canBeOverridden(ast)
                 && (isNativeMethod(ast)
                     || !hasEmptyImplementation(ast))
-                && !hasIgnoredAnnotation(ast, ignoredAnnotations)) {
+                && !hasIgnoredAnnotation(ast, ignoredAnnotations)
+                && !ScopeUtil.isInRecordBlock(ast)) {
             final DetailAST classDef = getNearestClassOrEnumDefinition(ast);
             if (canBeSubclassed(classDef)) {
                 final String className = classDef.findFirstToken(TokenTypes.IDENT).getText();
@@ -273,6 +287,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
 
     /**
      * Checks whether a method has a javadoc comment.
+     *
      * @param methodDef method definition token.
      * @return true if a method has a javadoc comment.
      */
@@ -326,6 +341,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
 
     /**
      * Checks whether a methods is native.
+     *
      * @param ast method definition token.
      * @return true if a methods is native.
      */
@@ -337,6 +353,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
     /**
      * Checks whether a method has only comments in the body (has an empty implementation).
      * Method is OK if its implementation is empty.
+     *
      * @param ast method definition token.
      * @return true if a method has only comments in the body.
      */
@@ -360,6 +377,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
      * Checks whether a method can be overridden.
      * Method can be overridden if it is not private, abstract, final or static.
      * Note that the check has nothing to do for interfaces.
+     *
      * @param methodDef method definition token.
      * @return true if a method can be overridden in a subclass.
      */
@@ -375,6 +393,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
 
     /**
      * Checks whether a method has any of ignored annotations.
+     *
      * @param methodDef method definition token.
      * @param annotations a set of ignored annotations.
      * @return true if a method has any of ignored annotations.
@@ -391,6 +410,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
 
     /**
      * Gets the name of the annotation.
+     *
      * @param annotation to get name of.
      * @return the name of the annotation.
      */
@@ -409,6 +429,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
     /**
      * Returns CLASS_DEF or ENUM_DEF token which is the nearest to the given ast node.
      * Searches the tree towards the root until it finds a CLASS_DEF or ENUM_DEF node.
+     *
      * @param ast the start node for searching.
      * @return the CLASS_DEF or ENUM_DEF token.
      */
@@ -423,6 +444,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
 
     /**
      * Checks if the given class (given CLASS_DEF node) can be subclassed.
+     *
      * @param classDef class definition token.
      * @return true if the containing class can be subclassed.
      */
@@ -435,6 +457,7 @@ public class DesignForExtensionCheck extends AbstractCheck {
 
     /**
      * Checks whether a class has default or explicit non-private constructor.
+     *
      * @param classDef class ast token.
      * @return true if a class has default or explicit non-private constructor.
      */
