@@ -135,29 +135,36 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * </p>
  * <ul>
  * <li>
- * Property {@code customImportOrderRules} - Specify list of order declaration customizing by user.
- * Default value is {@code {}}.
+ * Property {@code customImportOrderRules} - Specify format of order declaration
+ * customizing by user.
+ * Type is {@code java.lang.String}.
+ * Default value is {@code ""}.
  * </li>
  * <li>
  * Property {@code standardPackageRegExp} - Specify RegExp for STANDARD_JAVA_PACKAGE group imports.
+ * Type is {@code java.util.regex.Pattern}.
  * Default value is {@code "^(java|javax)\."}.
  * </li>
  * <li>
  * Property {@code thirdPartyPackageRegExp} - Specify RegExp for THIRD_PARTY_PACKAGE group imports.
+ * Type is {@code java.util.regex.Pattern}.
  * Default value is {@code ".*"}.
  * </li>
  * <li>
  * Property {@code specialImportsRegExp} - Specify RegExp for SPECIAL_IMPORTS group imports.
- * Default value is {@code "^$" (empty)}.
+ * Type is {@code java.util.regex.Pattern}.
+ * Default value is {@code "^$"}.
  * </li>
  * <li>
  * Property {@code separateLineBetweenGroups} - Force empty line separator between
  * import groups.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * <li>
  * Property {@code sortImportsInGroupAlphabetically} - Force grouping alphabetically,
  * in <a href="https://en.wikipedia.org/wiki/ASCII#Order">ASCII sort order</a>.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * </ul>
@@ -347,6 +354,32 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  *   &lt;property name=&quot;specialImportsRegExp&quot; value=&quot;^android\.&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code custom.import.order}
+ * </li>
+ * <li>
+ * {@code custom.import.order.lex}
+ * </li>
+ * <li>
+ * {@code custom.import.order.line.separator}
+ * </li>
+ * <li>
+ * {@code custom.import.order.nonGroup.expected}
+ * </li>
+ * <li>
+ * {@code custom.import.order.nonGroup.import}
+ * </li>
+ * <li>
+ * {@code custom.import.order.separated.internally}
+ * </li>
+ * </ul>
  *
  * @since 5.8
  */
@@ -410,12 +443,15 @@ public class CustomImportOrderCheck extends AbstractCheck {
     /** Pattern used to separate groups of imports. */
     private static final Pattern GROUP_SEPARATOR_PATTERN = Pattern.compile("\\s*###\\s*");
 
-    /** Specify list of order declaration customizing by user. */
-    private final List<String> customImportOrderRules = new ArrayList<>();
+    /** Processed list of import order rules. */
+    private final List<String> customOrderRules = new ArrayList<>();
 
     /** Contains objects with import attributes. */
     private final List<ImportDetails> importToGroupList = new ArrayList<>();
 
+    /** Specify format of order declaration customizing by user. */
+    private String customImportOrderRules = "";
+
     /** Specify RegExp for SAME_PACKAGE group imports. */
     private String samePackageDomainsRegExp = "";
 
@@ -442,6 +478,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Setter to specify RegExp for STANDARD_JAVA_PACKAGE group imports.
+     *
      * @param regexp
      *        user value.
      */
@@ -451,6 +488,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Setter to specify RegExp for THIRD_PARTY_PACKAGE group imports.
+     *
      * @param regexp
      *        user value.
      */
@@ -460,6 +498,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Setter to specify RegExp for SPECIAL_IMPORTS group imports.
+     *
      * @param regexp
      *        user value.
      */
@@ -469,6 +508,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Setter to force empty line separator between import groups.
+     *
      * @param value
      *        user value.
      */
@@ -479,6 +519,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
     /**
      * Setter to force grouping alphabetically, in
      * <a href="https://en.wikipedia.org/wiki/ASCII#Order">ASCII sort order</a>.
+     *
      * @param value
      *        user value.
      */
@@ -487,15 +528,19 @@ public class CustomImportOrderCheck extends AbstractCheck {
     }
 
     /**
-     * Setter to specify list of order declaration customizing by user.
+     * Setter to specify format of order declaration customizing by user.
+     *
      * @param inputCustomImportOrder
      *        user value.
      */
     public final void setCustomImportOrderRules(final String inputCustomImportOrder) {
-        for (String currentState : GROUP_SEPARATOR_PATTERN.split(inputCustomImportOrder)) {
-            addRulesToList(currentState);
+        if (!customImportOrderRules.equals(inputCustomImportOrder)) {
+            for (String currentState : GROUP_SEPARATOR_PATTERN.split(inputCustomImportOrder)) {
+                addRulesToList(currentState);
+            }
+            customOrderRules.add(NON_GROUP_RULE_GROUP);
         }
-        customImportOrderRules.add(NON_GROUP_RULE_GROUP);
+        customImportOrderRules = inputCustomImportOrder;
     }
 
     @Override
@@ -525,19 +570,14 @@ public class CustomImportOrderCheck extends AbstractCheck {
     @Override
     public void visitToken(DetailAST ast) {
         if (ast.getType() == TokenTypes.PACKAGE_DEF) {
-            if (customImportOrderRules.contains(SAME_PACKAGE_RULE_GROUP)) {
-                samePackageDomainsRegExp = createSamePackageRegexp(
-                        samePackageMatchingDepth, ast);
-            }
+            samePackageDomainsRegExp = createSamePackageRegexp(
+                    samePackageMatchingDepth, ast);
         }
         else {
             final String importFullPath = getFullImportIdent(ast);
-            final int lineNo = ast.getLineNo();
-            final int endLineNo = ast.getLastChild().getLineNo();
             final boolean isStatic = ast.getType() == TokenTypes.STATIC_IMPORT;
             importToGroupList.add(new ImportDetails(importFullPath,
-                    lineNo, endLineNo, getImportGroup(isStatic, importFullPath),
-                    isStatic));
+                    getImportGroup(isStatic, importFullPath), isStatic, ast));
         }
     }
 
@@ -551,7 +591,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
     /** Examine the order of all the imports and log any violations. */
     private void finishImportList() {
         String currentGroup = getFirstGroup();
-        int currentGroupNumber = customImportOrderRules.indexOf(currentGroup);
+        int currentGroupNumber = customOrderRules.indexOf(currentGroup);
         ImportDetails previousImportObjectFromCurrentGroup = null;
         String previousImportFromCurrentGroup = null;
 
@@ -563,7 +603,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
                 validateExtraEmptyLine(previousImportObjectFromCurrentGroup,
                         importObject, fullImportIdent);
                 if (isAlphabeticalOrderBroken(previousImportFromCurrentGroup, fullImportIdent)) {
-                    log(importObject.getStartLineNumber(), MSG_LEX,
+                    log(importObject.getImportAST(), MSG_LEX,
                             fullImportIdent, previousImportFromCurrentGroup);
                 }
                 else {
@@ -572,24 +612,24 @@ public class CustomImportOrderCheck extends AbstractCheck {
                 previousImportObjectFromCurrentGroup = importObject;
             }
             else {
-                //not the last group, last one is always NON_GROUP
-                if (customImportOrderRules.size() > currentGroupNumber + 1) {
+                // not the last group, last one is always NON_GROUP
+                if (customOrderRules.size() > currentGroupNumber + 1) {
                     final String nextGroup = getNextImportGroup(currentGroupNumber + 1);
                     if (importGroup.equals(nextGroup)) {
                         validateMissedEmptyLine(previousImportObjectFromCurrentGroup,
                                 importObject, fullImportIdent);
                         currentGroup = nextGroup;
-                        currentGroupNumber = customImportOrderRules.indexOf(nextGroup);
+                        currentGroupNumber = customOrderRules.indexOf(nextGroup);
                         previousImportFromCurrentGroup = fullImportIdent;
                     }
                     else {
-                        logWrongImportGroupOrder(importObject.getStartLineNumber(),
+                        logWrongImportGroupOrder(importObject.getImportAST(),
                                 importGroup, nextGroup, fullImportIdent);
                     }
                     previousImportObjectFromCurrentGroup = importObject;
                 }
                 else {
-                    logWrongImportGroupOrder(importObject.getStartLineNumber(),
+                    logWrongImportGroupOrder(importObject.getImportAST(),
                             importGroup, currentGroup, fullImportIdent);
                 }
             }
@@ -598,6 +638,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Log violation if empty line is missed.
+     *
      * @param previousImport previous import from current group.
      * @param importObject current import.
      * @param fullImportIdent full import identifier.
@@ -605,12 +646,13 @@ public class CustomImportOrderCheck extends AbstractCheck {
     private void validateMissedEmptyLine(ImportDetails previousImport,
                                          ImportDetails importObject, String fullImportIdent) {
         if (isEmptyLineMissed(previousImport, importObject)) {
-            log(importObject.getStartLineNumber(), MSG_LINE_SEPARATOR, fullImportIdent);
+            log(importObject.getImportAST(), MSG_LINE_SEPARATOR, fullImportIdent);
         }
     }
 
     /**
      * Log violation if extra empty line is present.
+     *
      * @param previousImport previous import from current group.
      * @param importObject current import.
      * @param fullImportIdent full import identifier.
@@ -618,7 +660,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
     private void validateExtraEmptyLine(ImportDetails previousImport,
                                         ImportDetails importObject, String fullImportIdent) {
         if (isSeparatedByExtraEmptyLine(previousImport, importObject)) {
-            log(importObject.getStartLineNumber(), MSG_SEPARATED_IN_GROUP, fullImportIdent);
+            log(importObject.getImportAST(), MSG_SEPARATED_IN_GROUP, fullImportIdent);
         }
     }
 
@@ -689,8 +731,9 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Log wrong import group order.
-     * @param currentImportLine
-     *        line number of current import current import.
+     *
+     * @param importAST
+     *        import ast.
      * @param importGroup
      *        import group.
      * @param currentGroupNumber
@@ -698,21 +741,22 @@ public class CustomImportOrderCheck extends AbstractCheck {
      * @param fullImportIdent
      *        full import name.
      */
-    private void logWrongImportGroupOrder(int currentImportLine, String importGroup,
+    private void logWrongImportGroupOrder(DetailAST importAST, String importGroup,
             String currentGroupNumber, String fullImportIdent) {
         if (NON_GROUP_RULE_GROUP.equals(importGroup)) {
-            log(currentImportLine, MSG_NONGROUP_IMPORT, fullImportIdent);
+            log(importAST, MSG_NONGROUP_IMPORT, fullImportIdent);
         }
         else if (NON_GROUP_RULE_GROUP.equals(currentGroupNumber)) {
-            log(currentImportLine, MSG_NONGROUP_EXPECTED, importGroup, fullImportIdent);
+            log(importAST, MSG_NONGROUP_EXPECTED, importGroup, fullImportIdent);
         }
         else {
-            log(currentImportLine, MSG_ORDER, importGroup, currentGroupNumber, fullImportIdent);
+            log(importAST, MSG_ORDER, importGroup, currentGroupNumber, fullImportIdent);
         }
     }
 
     /**
      * Get next import group.
+     *
      * @param currentGroupNumber
      *        current group number.
      * @return
@@ -721,17 +765,18 @@ public class CustomImportOrderCheck extends AbstractCheck {
     private String getNextImportGroup(int currentGroupNumber) {
         int nextGroupNumber = currentGroupNumber;
 
-        while (customImportOrderRules.size() > nextGroupNumber + 1) {
-            if (hasAnyImportInCurrentGroup(customImportOrderRules.get(nextGroupNumber))) {
+        while (customOrderRules.size() > nextGroupNumber + 1) {
+            if (hasAnyImportInCurrentGroup(customOrderRules.get(nextGroupNumber))) {
                 break;
             }
             nextGroupNumber++;
         }
-        return customImportOrderRules.get(nextGroupNumber);
+        return customOrderRules.get(nextGroupNumber);
     }
 
     /**
      * Checks if current group contains any import.
+     *
      * @param currentGroup
      *        current group.
      * @return
@@ -750,6 +795,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Get import valid group.
+     *
      * @param isStatic
      *        is static import.
      * @param importPath
@@ -758,11 +804,11 @@ public class CustomImportOrderCheck extends AbstractCheck {
      */
     private String getImportGroup(boolean isStatic, String importPath) {
         RuleMatchForImport bestMatch = new RuleMatchForImport(NON_GROUP_RULE_GROUP, 0, 0);
-        if (isStatic && customImportOrderRules.contains(STATIC_RULE_GROUP)) {
+        if (isStatic && customOrderRules.contains(STATIC_RULE_GROUP)) {
             bestMatch.group = STATIC_RULE_GROUP;
             bestMatch.matchLength = importPath.length();
         }
-        else if (customImportOrderRules.contains(SAME_PACKAGE_RULE_GROUP)) {
+        else if (customOrderRules.contains(SAME_PACKAGE_RULE_GROUP)) {
             final String importPathTrimmedToSamePackageDepth =
                     getFirstDomainsFromIdent(samePackageMatchingDepth, importPath);
             if (samePackageDomainsRegExp.equals(importPathTrimmedToSamePackageDepth)) {
@@ -770,20 +816,19 @@ public class CustomImportOrderCheck extends AbstractCheck {
                 bestMatch.matchLength = importPath.length();
             }
         }
-        if (bestMatch.group.equals(NON_GROUP_RULE_GROUP)) {
-            for (String group : customImportOrderRules) {
-                if (STANDARD_JAVA_PACKAGE_RULE_GROUP.equals(group)) {
-                    bestMatch = findBetterPatternMatch(importPath,
-                            STANDARD_JAVA_PACKAGE_RULE_GROUP, standardPackageRegExp, bestMatch);
-                }
-                if (SPECIAL_IMPORTS_RULE_GROUP.equals(group)) {
-                    bestMatch = findBetterPatternMatch(importPath,
-                            group, specialImportsRegExp, bestMatch);
-                }
+        for (String group : customOrderRules) {
+            if (STANDARD_JAVA_PACKAGE_RULE_GROUP.equals(group)) {
+                bestMatch = findBetterPatternMatch(importPath,
+                        STANDARD_JAVA_PACKAGE_RULE_GROUP, standardPackageRegExp, bestMatch);
+            }
+            if (SPECIAL_IMPORTS_RULE_GROUP.equals(group)) {
+                bestMatch = findBetterPatternMatch(importPath,
+                        group, specialImportsRegExp, bestMatch);
             }
         }
+
         if (bestMatch.group.equals(NON_GROUP_RULE_GROUP)
-                && customImportOrderRules.contains(THIRD_PARTY_PACKAGE_RULE_GROUP)
+                && customOrderRules.contains(THIRD_PARTY_PACKAGE_RULE_GROUP)
                 && thirdPartyPackageRegExp.matcher(importPath).find()) {
             bestMatch.group = THIRD_PARTY_PACKAGE_RULE_GROUP;
         }
@@ -822,6 +867,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Checks compare two import paths.
+     *
      * @param import1
      *        current import.
      * @param import2
@@ -851,6 +897,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Counts empty lines between given parameters.
+     *
      * @param fromLineNo
      *        One-based line number of previous import.
      * @param toLineNo
@@ -873,6 +920,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Forms import full path.
+     *
      * @param token
      *        current token.
      * @return full path or null.
@@ -887,6 +935,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Parses ordering rule and adds it to the list with rules.
+     *
      * @param ruleStr
      *        String with rule.
      * @throws IllegalArgumentException when SAME_PACKAGE rule parameter is not positive integer
@@ -897,7 +946,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
                 || THIRD_PARTY_PACKAGE_RULE_GROUP.equals(ruleStr)
                 || STANDARD_JAVA_PACKAGE_RULE_GROUP.equals(ruleStr)
                 || SPECIAL_IMPORTS_RULE_GROUP.equals(ruleStr)) {
-            customImportOrderRules.add(ruleStr);
+            customOrderRules.add(ruleStr);
         }
         else if (ruleStr.startsWith(SAME_PACKAGE_RULE_GROUP)) {
             final String rule = ruleStr.substring(ruleStr.indexOf('(') + 1,
@@ -907,7 +956,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
                 throw new IllegalArgumentException(
                         "SAME_PACKAGE rule parameter should be positive integer: " + ruleStr);
             }
-            customImportOrderRules.add(SAME_PACKAGE_RULE_GROUP);
+            customOrderRules.add(SAME_PACKAGE_RULE_GROUP);
         }
         else {
             throw new IllegalStateException("Unexpected rule: " + ruleStr);
@@ -916,6 +965,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Creates samePackageDomainsRegExp of the first package domains.
+     *
      * @param firstPackageDomainsCount
      *        number of first package domains.
      * @param packageNode
@@ -930,6 +980,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /**
      * Extracts defined amount of domains from the left side of package/import identifier.
+     *
      * @param firstPackageDomainsCount
      *        number of first package domains.
      * @param packageFullPath
@@ -959,46 +1010,38 @@ public class CustomImportOrderCheck extends AbstractCheck {
         /** Import full path. */
         private final String importFullPath;
 
-        /** Import start line number. */
-        private final int startLineNumber;
-
-        /**
-         * Import end line number.
-         * Note: It can be different from <b>startLineNumber</b> when import statement span
-         * multiple lines.
-         */
-        private final int endLineNumber;
-
         /** Import group. */
         private final String importGroup;
 
         /** Is static import. */
         private final boolean staticImport;
 
+        /** Import AST. */
+        private final DetailAST importAST;
+
         /**
-         * Initialise importFullPath, startLineNumber, endLineNumber, importGroup, staticImport.
+         * Initialise importFullPath, importGroup, staticImport, importAST.
+         *
          * @param importFullPath
          *        import full path.
-         * @param startLineNumber
-         *        import start line number.
-         * @param endLineNumber
-         *        import end line number.
          * @param importGroup
          *        import group.
          * @param staticImport
          *        if import is static.
+         * @param importAST
+         *        import ast
          */
-        /* package */ ImportDetails(String importFullPath, int startLineNumber, int endLineNumber,
-                                    String importGroup, boolean staticImport) {
+        /* package */ ImportDetails(String importFullPath, String importGroup, boolean staticImport,
+                                    DetailAST importAST) {
             this.importFullPath = importFullPath;
-            this.startLineNumber = startLineNumber;
-            this.endLineNumber = endLineNumber;
             this.importGroup = importGroup;
             this.staticImport = staticImport;
+            this.importAST = importAST;
         }
 
         /**
          * Get import full path variable.
+         *
          * @return import full path variable.
          */
         public String getImportFullPath() {
@@ -1006,23 +1049,30 @@ public class CustomImportOrderCheck extends AbstractCheck {
         }
 
         /**
-         * Get import start line number.
-         * @return import start line.
+         * Get import start line number from ast.
+         *
+         * @return import start line from ast.
          */
         public int getStartLineNumber() {
-            return startLineNumber;
+            return importAST.getLineNo();
         }
 
         /**
-         * Get import end line number.
-         * @return import end line.
+         * Get import end line number from ast.
+         * <p>
+         * <b>Note:</b> It can be different from <b>startLineNumber</b> when import statement span
+         * multiple lines.
+         * </p>
+         *
+         * @return import end line from ast.
          */
         public int getEndLineNumber() {
-            return endLineNumber;
+            return importAST.getLastChild().getLineNo();
         }
 
         /**
          * Get import group.
+         *
          * @return import group.
          */
         public String getImportGroup() {
@@ -1031,12 +1081,22 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
         /**
          * Checks if import is static.
+         *
          * @return true, if import is static.
          */
         public boolean isStaticImport() {
             return staticImport;
         }
 
+        /**
+         * Get import ast.
+         *
+         * @return import ast.
+         */
+        public DetailAST getImportAST() {
+            return importAST;
+        }
+
     }
 
     /**
