@@ -21,6 +21,7 @@ package com.puppycrawl.tools.checkstyle.checks.imports;
 
 /**
  * Represents the policy for checking import order statements.
+ *
  * @see ImportOrderCheck
  */
 public enum ImportOrderOption {
@@ -30,12 +31,12 @@ public enum ImportOrderOption {
      * For example:
      *
      * <pre>
-        import static java.awt.Button.ABORT;
-        import static java.io.File.createTempFile;
-        import static javax.swing.WindowConstants.*;
-
-        import java.awt.Button;
-        import java.awt.event.ActionEvent;
+     *  import static java.awt.Button.ABORT;
+     *  import static java.io.File.createTempFile;
+     *  import static javax.swing.WindowConstants.*;
+     *
+     *  import java.awt.Button;
+     *  import java.awt.event.ActionEvent;
      * </pre>
      */
     TOP,
@@ -45,14 +46,14 @@ public enum ImportOrderOption {
      * For example:
      *
      * <pre>
-        import static java.awt.Button.A;
-        import static javax.swing.WindowConstants.*;
-        import java.awt.Dialog;
-        import javax.swing.JComponent;
-
-        import static java.io.File.createTempFile;
-        import java.io.File;
-        import java.io.IOException;
+     *  import static java.awt.Button.A;
+     *  import static javax.swing.WindowConstants.*;
+     *  import java.awt.Dialog;
+     *  import javax.swing.JComponent;
+     *
+     *  import static java.io.File.createTempFile;
+     *  import java.io.File;
+     *  import java.io.IOException;
      * </pre>
      */
     ABOVE,
@@ -62,12 +63,12 @@ public enum ImportOrderOption {
      * imports. For example:
      *
      * <pre>
-        import java.awt.Button;
-        import static java.awt.Button.ABORT;
-        import java.awt.Dialog;
-
-        import static javax.swing.WindowConstants.HIDE_ON_CLOSE;
-        import javax.swing.JComponent;
+     *  import java.awt.Button;
+     *  import static java.awt.Button.ABORT;
+     *  import java.awt.Dialog;
+     *
+     *  import static javax.swing.WindowConstants.HIDE_ON_CLOSE;
+     *  import javax.swing.JComponent;
      * </pre>
      */
     INFLOW,
@@ -77,14 +78,14 @@ public enum ImportOrderOption {
      * For example:
      *
      * <pre>
-        import java.awt.Dialog;
-        import javax.swing.JComponent;
-        import static java.awt.Button.A;
-        import static javax.swing.WindowConstants.*;
-
-        import java.io.File;
-        import java.io.IOException;
-        import static java.io.File.createTempFile;
+     *  import java.awt.Dialog;
+     *  import javax.swing.JComponent;
+     *  import static java.awt.Button.A;
+     *  import static javax.swing.WindowConstants.*;
+     *
+     *  import java.io.File;
+     *  import java.io.IOException;
+     *  import static java.io.File.createTempFile;
      * </pre>
      */
     UNDER,
@@ -94,12 +95,12 @@ public enum ImportOrderOption {
      * For example:
      *
      * <pre>
-        import java.awt.Button;
-        import java.awt.event.ActionEvent;
-
-        import static java.awt.Button.ABORT;
-        import static java.io.File.createTempFile;
-        import static javax.swing.WindowConstants.*;
+     *  import java.awt.Button;
+     *  import java.awt.event.ActionEvent;
+     *
+     *  import static java.awt.Button.ABORT;
+     *  import static java.io.File.createTempFile;
+     *  import static javax.swing.WindowConstants.*;
      * </pre>
      */
     BOTTOM,
