@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -87,6 +87,7 @@ import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
  * <ul>
  * <li>
  * Property {@code processJavadoc} - Control whether to process Javadoc comments.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * </ul>
@@ -96,6 +97,17 @@ import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
  * <pre>
  * &lt;module name="UnusedImports"/&gt;
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code import.unused}
+ * </li>
+ * </ul>
  *
  * @since 3.0
  */
@@ -182,6 +194,8 @@ public class UnusedImportsCheck extends AbstractCheck {
             TokenTypes.METHOD_DEF,
             TokenTypes.CTOR_DEF,
             TokenTypes.VARIABLE_DEF,
+            TokenTypes.RECORD_DEF,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -213,6 +227,7 @@ public class UnusedImportsCheck extends AbstractCheck {
 
     /**
      * Checks whether an import is unused.
+     *
      * @param imprt an import.
      * @return true if an import is unused.
      */
@@ -224,6 +239,7 @@ public class UnusedImportsCheck extends AbstractCheck {
 
     /**
      * Collects references made by IDENT.
+     *
      * @param ast the IDENT node to process
      */
     private void processIdent(DetailAST ast) {
@@ -239,6 +255,7 @@ public class UnusedImportsCheck extends AbstractCheck {
 
     /**
      * Collects the details of imports.
+     *
      * @param ast node containing the import details
      */
     private void processImport(DetailAST ast) {
@@ -250,6 +267,7 @@ public class UnusedImportsCheck extends AbstractCheck {
 
     /**
      * Collects the details of static imports.
+     *
      * @param ast node containing the static import details
      */
     private void processStaticImport(DetailAST ast) {
@@ -263,6 +281,7 @@ public class UnusedImportsCheck extends AbstractCheck {
 
     /**
      * Collects references made in Javadoc comments.
+     *
      * @param ast node to inspect for Javadoc
      */
     private void collectReferencesFromJavadoc(DetailAST ast) {
@@ -277,6 +296,7 @@ public class UnusedImportsCheck extends AbstractCheck {
     /**
      * Process a javadoc {@link TextBlock} and return the set of classes
      * referenced within.
+     *
      * @param textBlock The javadoc block to parse
      * @return a set of classes referenced in the javadoc block
      */
@@ -298,6 +318,7 @@ public class UnusedImportsCheck extends AbstractCheck {
 
     /**
      * Returns the list of valid tags found in a javadoc {@link TextBlock}.
+     *
      * @param cmt The javadoc block to parse
      * @param tagType The type of tags we're interested in
      * @return the list of tags
@@ -309,6 +330,7 @@ public class UnusedImportsCheck extends AbstractCheck {
 
     /**
      * Returns a list of references found in a javadoc {@link JavadocTag}.
+     *
      * @param tag The javadoc tag to parse
      * @return A list of references found in this tag
      */
@@ -325,6 +347,7 @@ public class UnusedImportsCheck extends AbstractCheck {
     /**
      * Extracts a list of texts matching a {@link Pattern} from a
      * {@link String}.
+     *
      * @param identifier The String to match the pattern against
      * @param pattern The Pattern used to extract the texts
      * @return A list of texts which matched the pattern
@@ -342,6 +365,7 @@ public class UnusedImportsCheck extends AbstractCheck {
      * If the given type string contains "." (e.g. "Map.Entry"), returns the
      * top level type (e.g. "Map"), as that is what must be imported for the
      * type to resolve. Otherwise, returns the type as-is.
+     *
      * @param type A possibly qualified type name
      * @return The simple name of the top level type
      */
