@@ -428,11 +428,10 @@ public abstract class AbstractExpressionHandler {
     protected static DetailAST getFirstAst(DetailAST ast, DetailAST tree) {
         DetailAST realStart = ast;
 
-        if (tree.getLineNo() < realStart.getLineNo()) {
-            realStart = tree;
-        }
-        else if (tree.getLineNo() == realStart.getLineNo()
-                && tree.getColumnNo() < realStart.getColumnNo()) {
+        if (tree.getLineNo() < realStart.getLineNo()
+            || tree.getLineNo() == realStart.getLineNo()
+            && tree.getColumnNo() < realStart.getColumnNo()
+        ) {
             realStart = tree;
         }
 
