@@ -21,6 +21,7 @@ package com.puppycrawl.tools.checkstyle.checks.indentation;
 
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * Handler for else blocks.
@@ -55,7 +56,7 @@ public class ElseHandler extends BlockParentHandler {
         else {
             final DetailAST lcurly = slist.getLastChild();
             // indentation checked as part of LITERAL IF check
-            if (lcurly.getLineNo() != getMainAst().getLineNo()) {
+            if (!TokenUtil.areOnSameLine(lcurly, getMainAst())) {
                 super.checkTopLevelToken();
             }
         }
