@@ -23,6 +23,7 @@ import java.util.Arrays;
 
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * Handler for a list of statements.
@@ -46,6 +47,7 @@ public class SlistHandler extends BlockParentHandler {
         TokenTypes.LITERAL_TRY,
         TokenTypes.LITERAL_CATCH,
         TokenTypes.LITERAL_FINALLY,
+        TokenTypes.COMPACT_CTOR_DEF,
     };
 
     static {
@@ -132,12 +134,13 @@ public class SlistHandler extends BlockParentHandler {
 
     /**
      * Checks if SLIST node is placed at the same line as CASE_GROUP node.
+     *
      * @return true, if SLIST node is places at the same line as CASE_GROUP node.
      */
     private boolean isSameLineCaseGroup() {
         final DetailAST parentNode = getMainAst().getParent();
         return parentNode.getType() == TokenTypes.CASE_GROUP
-            && getMainAst().getLineNo() == parentNode.getLineNo();
+            && TokenUtil.areOnSameLine(getMainAst(), parentNode);
     }
 
 }
