@@ -48,7 +48,7 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
  * Checks the Javadoc of a method or constructor.
  * The scope to verify is specified using the {@code Scope} class and defaults
  * to {@code Scope.PRIVATE}. To verify another scope, set property scope to
- * a different <a href="https://checkstyle.org/property_types.html#scope">scope</a>.
+ * a different <a href="https://checkstyle.org/property_types.html#Scope">scope</a>.
  * </p>
  * <p>
  * Violates parameters and type parameters for which no param tags are present can
@@ -107,39 +107,50 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
  * <li>
  * Property {@code allowedAnnotations} - Specify the list of annotations
  * that allow missed documentation.
+ * Type is {@code java.lang.String[]}.
  * Default value is {@code Override}.
  * </li>
  * <li>
  * Property {@code validateThrows} - Control whether to validate {@code throws} tags.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code scope} - Specify the visibility scope where Javadoc comments are checked.
+ * Type is {@code com.puppycrawl.tools.checkstyle.api.Scope}.
  * Default value is {@code private}.
  * </li>
  * <li>
  * Property {@code excludeScope} - Specify the visibility scope where Javadoc comments
  * are not checked.
+ * Type is {@code com.puppycrawl.tools.checkstyle.api.Scope}.
  * Default value is {@code null}.
  * </li>
  * <li>
  * Property {@code allowMissingParamTags} - Control whether to ignore violations
  * when a method has parameters but does not have matching {@code param} tags in the javadoc.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code allowMissingReturnTag} - Control whether to ignore violations
  * when a method returns non-void type and does not have a {@code return} tag in the javadoc.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
- * Property {@code tokens} - tokens to check Default value is:
+ * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
+ * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#METHOD_DEF">
  * METHOD_DEF</a>,
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#CTOR_DEF">
  * CTOR_DEF</a>,
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#ANNOTATION_FIELD_DEF">
- * ANNOTATION_FIELD_DEF</a>.
+ * ANNOTATION_FIELD_DEF</a>,
+ * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#COMPACT_CTOR_DEF">
+ * COMPACT_CTOR_DEF</a>.
  * </li>
  * </ul>
  * <p>
@@ -253,6 +264,35 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
  *     };
  * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code javadoc.classInfo}
+ * </li>
+ * <li>
+ * {@code javadoc.duplicateTag}
+ * </li>
+ * <li>
+ * {@code javadoc.expectedTag}
+ * </li>
+ * <li>
+ * {@code javadoc.invalidInheritDoc}
+ * </li>
+ * <li>
+ * {@code javadoc.return.expected}
+ * </li>
+ * <li>
+ * {@code javadoc.unusedTag}
+ * </li>
+ * <li>
+ * {@code javadoc.unusedTagGeneral}
+ * </li>
+ * </ul>
  *
  * @since 3.0
  */
@@ -419,6 +459,7 @@ public class JavadocMethodCheck extends AbstractCheck {
             TokenTypes.CLASS_DEF,
             TokenTypes.INTERFACE_DEF,
             TokenTypes.ENUM_DEF,
+            TokenTypes.RECORD_DEF,
         };
     }
 
@@ -436,6 +477,8 @@ public class JavadocMethodCheck extends AbstractCheck {
             TokenTypes.METHOD_DEF,
             TokenTypes.CTOR_DEF,
             TokenTypes.ANNOTATION_FIELD_DEF,
+            TokenTypes.RECORD_DEF,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -448,7 +491,8 @@ public class JavadocMethodCheck extends AbstractCheck {
     public final void visitToken(DetailAST ast) {
         if (ast.getType() == TokenTypes.CLASS_DEF
                  || ast.getType() == TokenTypes.INTERFACE_DEF
-                 || ast.getType() == TokenTypes.ENUM_DEF) {
+                 || ast.getType() == TokenTypes.ENUM_DEF
+                 || ast.getType() == TokenTypes.RECORD_DEF) {
             processClass(ast);
         }
         else {
@@ -460,7 +504,8 @@ public class JavadocMethodCheck extends AbstractCheck {
     public final void leaveToken(DetailAST ast) {
         if (ast.getType() == TokenTypes.CLASS_DEF
             || ast.getType() == TokenTypes.INTERFACE_DEF
-            || ast.getType() == TokenTypes.ENUM_DEF) {
+            || ast.getType() == TokenTypes.ENUM_DEF
+            || ast.getType() == TokenTypes.RECORD_DEF) {
             // perhaps it was inner class
             final int dotIdx = currentClassName.lastIndexOf('$');
             currentClassName = currentClassName.substring(0, dotIdx);
@@ -525,13 +570,17 @@ public class JavadocMethodCheck extends AbstractCheck {
                 final boolean reportExpectedTags = !hasInheritDocTag
                     && !AnnotationUtil.containsAnnotation(ast, allowedAnnotations);
 
-                checkParamTags(tags, ast, reportExpectedTags);
+                // COMPACT_CTOR_DEF has no parameters
+                if (ast.getType() != TokenTypes.COMPACT_CTOR_DEF) {
+                    checkParamTags(tags, ast, reportExpectedTags);
+                }
                 final List<ExceptionInfo> throwed =
-                        combineExceptionInfo(getThrows(ast), getThrowed(ast));
+                    combineExceptionInfo(getThrows(ast), getThrowed(ast));
                 checkThrowsTags(tags, throwed, reportExpectedTags);
                 if (CheckUtil.isNonVoidMethod(ast)) {
                     checkReturnTag(tags, ast.getLineNo(), reportExpectedTags);
                 }
+
             }
 
             // Dump out all unused tags
@@ -789,6 +838,7 @@ public class JavadocMethodCheck extends AbstractCheck {
      * Checks if a 'throw' usage is contained within a block that should be ignored.
      * Such blocks consist of try (with catch) blocks, local classes, anonymous classes,
      * and lambda expressions. Note that a try block without catch is not considered.
+     *
      * @param methodBodyAst DetailAST node representing the method body
      * @param throwAst DetailAST node representing the 'throw' literal
      * @return true if throwAst is inside a block that should be ignored
