@@ -28,6 +28,7 @@ import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.Scope;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * This enum defines the various Javadoc tags and there properties.
@@ -39,7 +40,7 @@ import com.puppycrawl.tools.checkstyle.utils.ScopeUtil;
  *
  * and
  *
- * <a href="https://www.oracle.com/technetwork/java/javase/documentation/index-137868.html">
+ * <a href="https://www.oracle.com/technical-resources/articles/java/javadoc-tool.html">
  * how to write</a>.
  * </p>
  *
@@ -75,10 +76,7 @@ public enum JavadocTagInfo {
         public boolean isValidOn(final DetailAST ast) {
             final int astType = ast.getType();
             return astType == TokenTypes.PACKAGE_DEF
-                || astType == TokenTypes.CLASS_DEF
-                || astType == TokenTypes.INTERFACE_DEF
-                || astType == TokenTypes.ENUM_DEF
-                || astType == TokenTypes.ANNOTATION_DEF;
+                || TokenUtil.isTypeDeclaration(astType);
         }
 
     },
@@ -349,10 +347,7 @@ public enum JavadocTagInfo {
         public boolean isValidOn(final DetailAST ast) {
             final int astType = ast.getType();
             return astType == TokenTypes.PACKAGE_DEF
-                || astType == TokenTypes.CLASS_DEF
-                || astType == TokenTypes.INTERFACE_DEF
-                || astType == TokenTypes.ENUM_DEF
-                || astType == TokenTypes.ANNOTATION_DEF;
+                || TokenUtil.isTypeDeclaration(astType);
         }
 
     };
@@ -388,12 +383,12 @@ public enum JavadocTagInfo {
     private static final Map<String, JavadocTagInfo> NAME_TO_TAG;
 
     static {
-        TEXT_TO_TAG = Collections.unmodifiableMap(Arrays.stream(JavadocTagInfo.values())
+        TEXT_TO_TAG = Collections.unmodifiableMap(Arrays.stream(values())
             .collect(Collectors.toMap(JavadocTagInfo::getText, tagText -> tagText)));
-        NAME_TO_TAG = Collections.unmodifiableMap(Arrays.stream(JavadocTagInfo.values())
+        NAME_TO_TAG = Collections.unmodifiableMap(Arrays.stream(values())
             .collect(Collectors.toMap(JavadocTagInfo::getName, tagName -> tagName)));
 
-        //Arrays sorting for binary search
+        // Arrays sorting for binary search
         Arrays.sort(DEF_TOKEN_TYPES);
         Arrays.sort(DEF_TOKEN_TYPES_DEPRECATED);
     }
@@ -437,6 +432,7 @@ public enum JavadocTagInfo {
 
     /**
      * Gets the tag text.
+     *
      * @return the tag text
      */
     public String getText() {
@@ -445,6 +441,7 @@ public enum JavadocTagInfo {
 
     /**
      * Gets the tag name.
+     *
      * @return the tag name
      */
     public String getName() {
@@ -453,6 +450,7 @@ public enum JavadocTagInfo {
 
     /**
      * Gets the Tag type defined by {@link Type Type}.
+     *
      * @return the Tag type
      */
     public Type getType() {
@@ -461,6 +459,7 @@ public enum JavadocTagInfo {
 
     /**
      * Returns a JavadocTag from the tag text.
+     *
      * @param text String representing the tag text
      * @return Returns a JavadocTag type from a String representing the tag
      * @throws NullPointerException if the text is null
@@ -483,6 +482,7 @@ public enum JavadocTagInfo {
 
     /**
      * Returns a JavadocTag from the tag name.
+     *
      * @param name String name of the tag
      * @return Returns a JavadocTag type from a String representing the tag
      * @throws NullPointerException if the text is null
@@ -506,6 +506,7 @@ public enum JavadocTagInfo {
 
     /**
      * Returns whether the provided name is for a valid tag.
+     *
      * @param name the tag name to check.
      * @return whether the provided name is for a valid tag.
      */
