@@ -52,10 +52,14 @@ import com.puppycrawl.tools.checkstyle.utils.CheckUtil;
  * <li>
  * Property {@code max} - Specify the maximum number of boolean operations
  * allowed in one expression.
+ * Type is {@code int}.
  * Default value is {@code 3}.
  * </li>
  * <li>
- * Property {@code tokens} - tokens to check Default value is:
+ * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
+ * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#LAND">
  * LAND</a>,
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#BAND">
@@ -139,6 +143,17 @@ import com.puppycrawl.tools.checkstyle.utils.CheckUtil;
  *  }
  * </pre>
  *
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code booleanExpressionComplexity}
+ * </li>
+ * </ul>
  *
  * @since 3.4
  */
@@ -177,6 +192,7 @@ public final class BooleanExpressionComplexityCheck extends AbstractCheck {
             TokenTypes.LOR,
             TokenTypes.BOR,
             TokenTypes.BXOR,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -186,6 +202,7 @@ public final class BooleanExpressionComplexityCheck extends AbstractCheck {
             TokenTypes.CTOR_DEF,
             TokenTypes.METHOD_DEF,
             TokenTypes.EXPR,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -200,6 +217,7 @@ public final class BooleanExpressionComplexityCheck extends AbstractCheck {
             TokenTypes.LOR,
             TokenTypes.BOR,
             TokenTypes.BXOR,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -217,6 +235,7 @@ public final class BooleanExpressionComplexityCheck extends AbstractCheck {
         switch (ast.getType()) {
             case TokenTypes.CTOR_DEF:
             case TokenTypes.METHOD_DEF:
+            case TokenTypes.COMPACT_CTOR_DEF:
                 visitMethodDef(ast);
                 break;
             case TokenTypes.EXPR:
@@ -270,6 +289,7 @@ public final class BooleanExpressionComplexityCheck extends AbstractCheck {
         switch (ast.getType()) {
             case TokenTypes.CTOR_DEF:
             case TokenTypes.METHOD_DEF:
+            case TokenTypes.COMPACT_CTOR_DEF:
                 leaveMethodDef();
                 break;
             case TokenTypes.EXPR:
