@@ -22,11 +22,13 @@ package com.puppycrawl.tools.checkstyle.checks.metrics;
 import java.math.BigInteger;
 import java.util.ArrayDeque;
 import java.util.Deque;
+import java.util.concurrent.atomic.AtomicInteger;
 
 import com.puppycrawl.tools.checkstyle.FileStatefulCheck;
 import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * <p>
@@ -109,6 +111,7 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * <ul>
  * <li>
  * Property {@code max} - Specify the maximum threshold allowed.
+ * Type is {@code int}.
  * Default value is {@code 200}.
  * </li>
  * </ul>
@@ -215,6 +218,17 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * public abstract void print(String str);
  * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code npathComplexity}
+ * </li>
+ * </ul>
  *
  * @since 3.4
  */
@@ -298,6 +312,8 @@ public final class NPathComplexityCheck extends AbstractCheck {
             TokenTypes.QUESTION,
             TokenTypes.LITERAL_RETURN,
             TokenTypes.LITERAL_DEFAULT,
+            TokenTypes.COMPACT_CTOR_DEF,
+            TokenTypes.SWITCH_RULE,
         };
     }
 
@@ -332,6 +348,11 @@ public final class NPathComplexityCheck extends AbstractCheck {
                 branchVisited = true;
                 pushValue(caseNumber);
                 break;
+            case TokenTypes.SWITCH_RULE:
+                final int caseConstantNumber = countCaseConstants(ast);
+                branchVisited = true;
+                pushValue(caseConstantNumber);
+                break;
             case TokenTypes.LITERAL_ELSE:
                 branchVisited = true;
                 if (currentRangeValue.equals(BigInteger.ZERO)) {
@@ -348,6 +369,7 @@ public final class NPathComplexityCheck extends AbstractCheck {
             case TokenTypes.METHOD_DEF:
             case TokenTypes.INSTANCE_INIT:
             case TokenTypes.STATIC_INIT:
+            case TokenTypes.COMPACT_CTOR_DEF:
                 pushValue(0);
                 break;
             default:
@@ -380,6 +402,7 @@ public final class NPathComplexityCheck extends AbstractCheck {
                 break;
             case TokenTypes.LITERAL_ELSE:
             case TokenTypes.CASE_GROUP:
+            case TokenTypes.SWITCH_RULE:
                 leaveBranch();
                 branchVisited = false;
                 break;
@@ -387,6 +410,7 @@ public final class NPathComplexityCheck extends AbstractCheck {
             case TokenTypes.METHOD_DEF:
             case TokenTypes.INSTANCE_INIT:
             case TokenTypes.STATIC_INIT:
+            case TokenTypes.COMPACT_CTOR_DEF:
                 leaveMethodDef(ast);
                 break;
             default:
@@ -585,6 +609,22 @@ public final class NPathComplexityCheck extends AbstractCheck {
         return counter;
     }
 
+    /**
+     * Counts number of case constants (EXPR) tokens in a switch labeled rule.
+     *
+     * @param ast switch rule token.
+     * @return number of case constant (EXPR) tokens.
+     */
+    private static int countCaseConstants(DetailAST ast) {
+        final AtomicInteger counter = new AtomicInteger();
+        final DetailAST literalCase = ast.getFirstChild();
+
+        TokenUtil.forEachChild(literalCase,
+            TokenTypes.EXPR, node -> counter.getAndIncrement());
+
+        return counter.get();
+    }
+
     /**
      * Coordinates of token end. Used to prevent inline ternary
      * operator from being processed twice.
