@@ -53,19 +53,24 @@ import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
  * <ul>
  * <li>
  * Property {@code allowNoEmptyLineBetweenFields} - Allow no empty line between fields.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code allowMultipleEmptyLines} - Allow multiple empty lines between class members.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * <li>
  * Property {@code allowMultipleEmptyLinesInsideClassMembers} - Allow multiple
  * empty lines inside class members.
+ * Type is {@code boolean}.
  * Default value is {@code true}.
  * </li>
  * <li>
  * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
  * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#PACKAGE_DEF">
  * PACKAGE_DEF</a>,
@@ -88,10 +93,20 @@ import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#CTOR_DEF">
  * CTOR_DEF</a>,
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#VARIABLE_DEF">
- * VARIABLE_DEF</a>.
+ * VARIABLE_DEF</a>,
+ * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#RECORD_DEF">
+ * RECORD_DEF</a>,
+ * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#COMPACT_CTOR_DEF">
+ * COMPACT_CTOR_DEF</a>.
  * </li>
  * </ul>
  * <p>
+ * To configure the default check:
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;EmptyLineSeparator&quot;/&gt;
+ * </pre>
+ * <p>
  * Example of declarations without empty line separator:
  * </p>
  *
@@ -108,14 +123,6 @@ import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
  * </pre>
  *
  * <p>
- * To configure the check with default parameters:
- * </p>
- *
- * <pre>
- * &lt;module name=&quot;EmptyLineSeparator&quot;/&gt;
- * </pre>
- *
- * <p>
  * Example of declarations with empty line separator
  * that is expected by the Check by default:
  * </p>
@@ -259,6 +266,26 @@ import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
  *
  * }
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code empty.line.separator}
+ * </li>
+ * <li>
+ * {@code empty.line.separator.multiple.lines}
+ * </li>
+ * <li>
+ * {@code empty.line.separator.multiple.lines.after}
+ * </li>
+ * <li>
+ * {@code empty.line.separator.multiple.lines.inside}
+ * </li>
+ * </ul>
  *
  * @since 5.8
  */
@@ -358,6 +385,8 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
             TokenTypes.METHOD_DEF,
             TokenTypes.CTOR_DEF,
             TokenTypes.VARIABLE_DEF,
+            TokenTypes.RECORD_DEF,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -460,7 +489,8 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
         return astType == TokenTypes.STATIC_INIT
                 || astType == TokenTypes.INSTANCE_INIT
                 || astType == TokenTypes.METHOD_DEF
-                || astType == TokenTypes.CTOR_DEF;
+                || astType == TokenTypes.CTOR_DEF
+                || astType == TokenTypes.COMPACT_CTOR_DEF;
     }
 
     /**
@@ -795,7 +825,8 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
      */
     private static boolean isTypeField(DetailAST variableDef) {
         final int parentType = variableDef.getParent().getParent().getType();
-        return parentType == TokenTypes.CLASS_DEF;
+        return parentType == TokenTypes.CLASS_DEF
+                || parentType == TokenTypes.RECORD_DEF;
     }
 
 }
