@@ -24,6 +24,7 @@ import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * <p>Checks that chosen statements are not line-wrapped.
@@ -33,6 +34,8 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * <ul>
  * <li>
  * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
  * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#PACKAGE_DEF">
  * PACKAGE_DEF</a>,
@@ -42,19 +45,6 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * STATIC_IMPORT</a>.
  * </li>
  * </ul>
- * <p>Examples of line-wrapped statements (bad case):
- * </p>
- * <pre>
- * package com.puppycrawl. //violation
- *     tools.checkstyle.checks;
- *
- * import com.puppycrawl.tools. //violation
- *     checkstyle.api.AbstractCheck;
- *
- * import static java.math. //violation
- *     BigInteger.ZERO;
- * </pre>
- *
  * <p>
  * To configure the check to force no line-wrapping
  * in package and import statements (default values):
@@ -62,6 +52,41 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * <pre>
  * &lt;module name=&quot;NoLineWrap&quot;/&gt;
  * </pre>
+ * <p>Examples of line-wrapped statements (bad case):
+ * </p>
+ * <pre>
+ * package com.puppycrawl. // violation
+ *     tools.checkstyle.checks;
+ *
+ * import com.puppycrawl.tools. // violation
+ *     checkstyle.api.AbstractCheck;
+ *
+ * import static java.math. // violation
+ *     BigInteger.ZERO;
+ * </pre>
+ *
+ * <p>
+ * Examples:
+ * </p>
+ * <pre>
+ * package com.puppycrawl.tools.checkstyle. // violation
+ *   checks.whitespace;
+ *
+ * import java.lang.Object; // OK
+ * import java.lang. // violation
+ *   Integer;
+ *
+ * import static java.math. // violation
+ *   BigInteger.TEN;
+ * </pre>
+ * <pre>
+ * package com.puppycrawl.tools.checkstyle.checks.coding; // OK
+ *
+ * import java.lang. // violation
+ *   Boolean;
+ *
+ * import static java.math.BigInteger.ONE; // OK
+ * </pre>
  *
  * <p>
  * To configure the check to force no line-wrapping only
@@ -72,6 +97,54 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  *   &lt;property name="tokens" value="IMPORT"/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <p>
+ * Example:
+ * </p>
+ * <pre>
+ * package com.puppycrawl. // OK
+ *   tools.checkstyle.checks;
+ *
+ * import java.io.*; // OK
+ * import java.lang. // violation
+ *  Boolean;
+ *
+ * import static java.math. // OK
+ * BigInteger.ZERO;
+ * </pre>
+ * <p>
+ * To configure the check to force no line-wrapping only
+ * in class, method and constructor definitions:
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;NoLineWrap&quot;&gt;
+ *   &lt;property name="tokens" value="CLASS_DEF, METHOD_DEF, CTOR_DEF"/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>
+ * Example:
+ * </p>
+ * <pre>
+ * public class // violation, class definition not wrapped in a single line
+ *   Foo {
+ *
+ *   public Foo() { // OK
+ *   }
+ *
+ *   public static void // violation, method definition not wrapped in a single line
+ *     doSomething() {
+ *   }
+ * }
+ *
+ * public class Bar { // OK
+ *
+ *   public // violation, constructor definition not wrapped in a single line
+ *     Bar() {
+ *   }
+ *
+ *   public int fun() { // OK
+ *   }
+ * }
+ * </pre>
  *
  * <p>Examples of not line-wrapped statements (good case):
  * </p>
@@ -79,6 +152,17 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * import com.puppycrawl.tools.checkstyle.api.AbstractCheck;
  * import static java.math.BigInteger.ZERO;
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code no.line.wrap}
+ * </li>
+ * </ul>
  *
  * @since 5.8
  */
@@ -107,6 +191,8 @@ public class NoLineWrapCheck extends AbstractCheck {
             TokenTypes.CTOR_DEF,
             TokenTypes.ENUM_DEF,
             TokenTypes.INTERFACE_DEF,
+            TokenTypes.RECORD_DEF,
+            TokenTypes.COMPACT_CTOR_DEF,
         };
     }
 
@@ -117,8 +203,8 @@ public class NoLineWrapCheck extends AbstractCheck {
 
     @Override
     public void visitToken(DetailAST ast) {
-        if (ast.getLineNo() != ast.getLastChild().getLineNo()) {
-            log(ast.getLineNo(), MSG_KEY, ast.getText());
+        if (!TokenUtil.areOnSameLine(ast, ast.getLastChild())) {
+            log(ast, MSG_KEY, ast.getText());
         }
     }
 
