@@ -38,10 +38,13 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * <li>
  * Property {@code allowLineBreaks} - Control whether whitespace is allowed
  * if the token is at a linebreak.
+ * Type is {@code boolean}.
  * Default value is {@code false}.
  * </li>
  * <li>
  * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
  * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#COMMA">
  * COMMA</a>,
@@ -52,7 +55,9 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#POST_DEC">
  * POST_DEC</a>,
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#ELLIPSIS">
- * ELLIPSIS</a>.
+ * ELLIPSIS</a>,
+ * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#LABELED_STAT">
+ * LABELED_STAT</a>.
  * </li>
  * </ul>
  * <p>
@@ -61,15 +66,98 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * <pre>
  * &lt;module name=&quot;NoWhitespaceBefore&quot;/&gt;
  * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * int foo;
+ * foo ++; // violation, whitespace before '++' is not allowed
+ * foo++; // OK
+ * for (int i = 0 ; i &lt; 5; i++) {}  // violation
+ *            // ^ whitespace before ';' is not allowed
+ * for (int i = 0; i &lt; 5; i++) {} // OK
+ * int[][] array = { { 1, 2 }
+ *                 , { 3, 4 } }; // violation, whitespace before ',' is not allowed
+ * int[][] array2 = { { 1, 2 },
+ *                    { 3, 4 } }; // OK
+ * Lists.charactersOf("foo").listIterator()
+ *        .forEachRemaining(System.out::print)
+ *        ; // violation, whitespace before ';' is not allowed
+ *   {
+ *     label1 : // violation, whitespace before ':' is not allowed
+ *     for (int i = 0; i &lt; 10; i++) {}
+ *   }
+ *
+ *   {
+ *     label2: // OK
+ *     while (true) {}
+ *   }
+ * </pre>
+ * <p>To configure the check to allow linebreaks before default tokens:</p>
+ * <pre>
+ * &lt;module name=&quot;NoWhitespaceBefore&quot;&gt;
+ *   &lt;property name=&quot;allowLineBreaks&quot; value=&quot;true&quot;/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * int[][] array = { { 1, 2 }
+ *                 , { 3, 4 } }; // OK, linebreak is allowed before ','
+ * int[][] array2 = { { 1, 2 },
+ *                    { 3, 4 } }; // OK, ideal code
+ * void ellipsisExample(String ...params) {}; // violation, whitespace before '...' is not allowed
+ * void ellipsisExample2(String
+ *                         ...params) {}; //OK, linebreak is allowed before '...'
+ * Lists.charactersOf("foo")
+ *        .listIterator()
+ *        .forEachRemaining(System.out::print); // OK
+ * </pre>
  * <p>
- * To configure the check to allow linebreaks before a DOT token:
+ *     To Configure the check to restrict the use of whitespace before METHOD_REF and DOT tokens:
  * </p>
  * <pre>
  * &lt;module name=&quot;NoWhitespaceBefore&quot;&gt;
+ *   &lt;property name=&quot;tokens&quot; value=&quot;METHOD_REF&quot;/&gt;
+ *   &lt;property name=&quot;tokens&quot; value=&quot;DOT&quot;/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * Lists.charactersOf("foo").listIterator()
+ *        .forEachRemaining(System.out::print); // violation, whitespace before '.' is not allowed
+ * Lists.charactersOf("foo").listIterator().forEachRemaining(System.out ::print); // violation,
+ *                           // whitespace before '::' is not allowed  ^
+ * Lists.charactersOf("foo").listIterator().forEachRemaining(System.out::print); // OK
+ * </pre>
+ * <p>
+ *     To configure the check to allow linebreak before METHOD_REF and DOT tokens:
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;NoWhitespaceBefore&quot;&gt;
+ *   &lt;property name=&quot;tokens&quot; value=&quot;METHOD_REF&quot;/&gt;
  *   &lt;property name=&quot;tokens&quot; value=&quot;DOT&quot;/&gt;
  *   &lt;property name=&quot;allowLineBreaks&quot; value=&quot;true&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * Lists .charactersOf("foo") //violation, whitespace before '.' is not allowed
+ *         .listIterator()
+ *         .forEachRemaining(System.out ::print); // violation,
+ *                                  // ^ whitespace before '::' is not allowed
+ * Lists.charactersOf("foo")
+ *        .listIterator()
+ *        .forEachRemaining(System.out::print); // OK
+ * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code ws.preceded}
+ * </li>
+ * </ul>
  *
  * @since 3.0
  */
@@ -94,6 +182,7 @@ public class NoWhitespaceBeforeCheck
             TokenTypes.POST_INC,
             TokenTypes.POST_DEC,
             TokenTypes.ELLIPSIS,
+            TokenTypes.LABELED_STAT,
         };
     }
 
@@ -108,6 +197,7 @@ public class NoWhitespaceBeforeCheck
             TokenTypes.GENERIC_START,
             TokenTypes.GENERIC_END,
             TokenTypes.ELLIPSIS,
+            TokenTypes.LABELED_STAT,
             TokenTypes.METHOD_REF,
         };
     }
@@ -140,6 +230,7 @@ public class NoWhitespaceBeforeCheck
 
     /**
      * Checks that semicolon is in empty for initializer or condition.
+     *
      * @param semicolonAst DetailAST of semicolon.
      * @return true if semicolon is in empty for initializer or condition.
      */
@@ -157,6 +248,7 @@ public class NoWhitespaceBeforeCheck
 
     /**
      * Setter to control whether whitespace is allowed if the token is at a linebreak.
+     *
      * @param allowLineBreaks whether whitespace should be
      *     flagged at line breaks.
      */
