@@ -24,6 +24,7 @@ import java.util.Arrays;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * <p>
@@ -44,10 +45,13 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * <ul>
  * <li>
  * Property {@code option} - Specify policy on how to pad parentheses.
+ * Type is {@code com.puppycrawl.tools.checkstyle.checks.whitespace.PadOption}.
  * Default value is {@code nospace}.
  * </li>
  * <li>
  * Property {@code tokens} - tokens to check
+ * Type is {@code java.lang.String[]}.
+ * Validation type is {@code tokenSet}.
  * Default value is:
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#ANNOTATION">
  * ANNOTATION</a>,
@@ -90,7 +94,9 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#SUPER_CTOR_CALL">
  * SUPER_CTOR_CALL</a>,
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#LAMBDA">
- * LAMBDA</a>.
+ * LAMBDA</a>,
+ * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#RECORD_DEF">
+ * RECORD_DEF</a>.
  * </li>
  * </ul>
  * <p>
@@ -100,24 +106,113 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * &lt;module name=&quot;ParenPad&quot;/&gt;
  * </pre>
  * <p>
+ * Example:
+ * </p>
+ * <pre>
+ * class Foo {
+ *
+ *   int n;
+ *
+ *   public void fun() {  // OK
+ *     bar( 1);  // violation, space after left parenthesis
+ *   }
+ *
+ *   public void bar(int k ) {  // violation, space before right parenthesis
+ *     while (k &gt; 0) {  // OK
+ *     }
+ *
+ *     Test obj = new Test(k);  // OK
+ *   }
+ *
+ *   public void fun2() {  // OK
+ *     switch( n) {  // violation, space after left parenthesis
+ *       case 2:
+ *         bar(n);  // OK
+ *       default:
+ *         break;
+ *     }
+ *   }
+ *
+ * }
+ * </pre>
+ * <p>
  * To configure the check to require spaces for the
  * parentheses of constructor, method, and super constructor calls:
  * </p>
  * <pre>
  * &lt;module name=&quot;ParenPad&quot;&gt;
- *   &lt;property name=&quot;tokens&quot; value=&quot;CTOR_CALL, METHOD_CALL,
+ *   &lt;property name=&quot;tokens&quot; value=&quot;LITERAL_FOR, LITERAL_CATCH,
  *     SUPER_CTOR_CALL&quot;/&gt;
  *   &lt;property name=&quot;option&quot; value=&quot;space&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
  * <p>
- * The following cases not checked:
+ * Example:
+ * </p>
+ * <pre>
+ * class Foo {
+ *
+ *   int x;
+ *
+ *   public Foo(int n) {
+ *   }
+ *
+ *   public void fun() {
+ *     try {
+ *       System.out.println(x);
+ *     } catch( IOException e) {  // violation, no space before right parenthesis
+ *     } catch( Exception e ) {  // OK
+ *     }
+ *
+ *     for ( int i = 0; i &lt; x; i++ ) {  // OK
+ *     }
+ *   }
+ *
+ * }
+ *
+ * class Bar extends Foo {
+ *
+ *   public Bar() {
+ *     super(1 );  // violation, no space after left parenthesis
+ *   }
+ *
+ *   public Bar(int k) {
+ *     super( k ); // OK
+ *
+ *     for ( int i = 0; i &lt; k; i++) {  // violation, no space before right parenthesis
+ *     }
+ *   }
+ *
+ * }
+ * </pre>
+ * <p>
+ * The following cases are not checked:
  * </p>
  * <pre>
  * for ( ; i &lt; j; i++, j--) // no check after left parenthesis
  * for (Iterator it = xs.iterator(); it.hasNext(); ) // no check before right parenthesis
  * try (Closeable resource = acquire(); ) // no check before right parenthesis
  * </pre>
+ * <p>
+ * Parent is {@code com.puppycrawl.tools.checkstyle.TreeWalker}
+ * </p>
+ * <p>
+ * Violation Message Keys:
+ * </p>
+ * <ul>
+ * <li>
+ * {@code ws.followed}
+ * </li>
+ * <li>
+ * {@code ws.notFollowed}
+ * </li>
+ * <li>
+ * {@code ws.notPreceded}
+ * </li>
+ * <li>
+ * {@code ws.preceded}
+ * </li>
+ * </ul>
  *
  * @since 3.0
  */
@@ -187,6 +282,7 @@ public class ParenPadCheck extends AbstractParenPadCheck {
      * {@link TokenTypes#ENUM_CONSTANT_DEF}, {@link TokenTypes#ANNOTATION}
      * {@link TokenTypes#LITERAL_SYNCHRONIZED}, {@link TokenTypes#LITERAL_NEW} and
      * {@link TokenTypes#LAMBDA}.
+     *
      * @param ast the token to check.
      */
     private void visitTokenWithOptionalParentheses(DetailAST ast) {
@@ -199,6 +295,7 @@ public class ParenPadCheck extends AbstractParenPadCheck {
 
     /**
      * Checks parens in {@link TokenTypes#RESOURCE_SPECIFICATION}.
+     *
      * @param ast the token to check.
      */
     private void visitResourceSpecification(DetailAST ast) {
@@ -211,6 +308,7 @@ public class ParenPadCheck extends AbstractParenPadCheck {
 
     /**
      * Checks that a token is preceded by a semi-colon.
+     *
      * @param ast the token to check
      * @return whether a token is preceded by a semi-colon
      */
@@ -220,6 +318,7 @@ public class ParenPadCheck extends AbstractParenPadCheck {
 
     /**
      * Checks parens in {@link TokenTypes#LITERAL_FOR}.
+     *
      * @param ast the token to check.
      */
     private void visitLiteralFor(DetailAST ast) {
@@ -236,6 +335,7 @@ public class ParenPadCheck extends AbstractParenPadCheck {
     /**
      * Checks parens inside {@link TokenTypes#EXPR}, {@link TokenTypes#QUESTION}
      * and {@link TokenTypes#METHOD_CALL}.
+     *
      * @param ast the token to check.
      */
     private void processExpression(DetailAST ast) {
@@ -248,8 +348,8 @@ public class ParenPadCheck extends AbstractParenPadCheck {
                 processRight(childAst);
             }
             else if (!isAcceptableToken(childAst)) {
-                //Traverse all subtree tokens which will never be configured
-                //to be launched in visitToken()
+                // Traverse all subtree tokens which will never be configured
+                // to be launched in visitToken()
                 processExpression(childAst);
             }
             childAst = childAst.getNextSibling();
@@ -258,6 +358,7 @@ public class ParenPadCheck extends AbstractParenPadCheck {
 
     /**
      * Checks whether AcceptableTokens contains the given ast.
+     *
      * @param ast the token to check.
      * @return true if the ast is in AcceptableTokens.
      */
@@ -271,6 +372,7 @@ public class ParenPadCheck extends AbstractParenPadCheck {
 
     /**
      * Returns array of acceptable tokens.
+     *
      * @return acceptableTokens.
      */
     private static int[] makeAcceptableTokens() {
@@ -295,12 +397,14 @@ public class ParenPadCheck extends AbstractParenPadCheck {
             TokenTypes.RESOURCE_SPECIFICATION,
             TokenTypes.SUPER_CTOR_CALL,
             TokenTypes.LAMBDA,
+            TokenTypes.RECORD_DEF,
         };
     }
 
     /**
      * Checks whether {@link TokenTypes#RPAREN} is a closing paren
      * of a {@link TokenTypes#TYPECAST}.
+     *
      * @param ast of a {@link TokenTypes#RPAREN} to check.
      * @return true if ast is a closing paren of a {@link TokenTypes#TYPECAST}.
      */
@@ -308,7 +412,7 @@ public class ParenPadCheck extends AbstractParenPadCheck {
         boolean result = false;
         if (ast.getParent().getType() == TokenTypes.TYPECAST) {
             final DetailAST firstRparen = ast.getParent().findFirstToken(TokenTypes.RPAREN);
-            if (firstRparen.getLineNo() == ast.getLineNo()
+            if (TokenUtil.areOnSameLine(firstRparen, ast)
                     && firstRparen.getColumnNo() == ast.getColumnNo()) {
                 result = true;
             }
@@ -318,13 +422,14 @@ public class ParenPadCheck extends AbstractParenPadCheck {
 
     /**
      * Checks that a token follows an empty for iterator.
+     *
      * @param ast the token to check
      * @return whether a token follows an empty for iterator
      */
     private static boolean isFollowsEmptyForIterator(DetailAST ast) {
         boolean result = false;
         final DetailAST parent = ast.getParent();
-        //Only traditional for statements are examined, not for-each statements
+        // Only traditional for statements are examined, not for-each statements
         if (parent.findFirstToken(TokenTypes.FOR_EACH_CLAUSE) == null) {
             final DetailAST forIterator =
                 parent.findFirstToken(TokenTypes.FOR_ITERATOR);
@@ -335,13 +440,14 @@ public class ParenPadCheck extends AbstractParenPadCheck {
 
     /**
      * Checks that a token precedes an empty for initializer.
+     *
      * @param ast the token to check
      * @return whether a token precedes an empty for initializer
      */
     private static boolean isPrecedingEmptyForInit(DetailAST ast) {
         boolean result = false;
         final DetailAST parent = ast.getParent();
-        //Only traditional for statements are examined, not for-each statements
+        // Only traditional for statements are examined, not for-each statements
         if (parent.findFirstToken(TokenTypes.FOR_EACH_CLAUSE) == null) {
             final DetailAST forIterator =
                     parent.findFirstToken(TokenTypes.FOR_INIT);
