@@ -269,4 +269,44 @@ public final class TokenUtil {
         return ast1.getLineNo() == ast2.getLineNo();
     }
 
+    /**
+     * Is type declaration token type (CLASS_DEF, INTERFACE_DEF,
+     * ANNOTATION_DEF, ENUM_DEF, RECORD_DEF).
+     *
+     * @param type
+     *        token type.
+     * @return true if type is type declaration token type.
+     */
+    public static boolean isTypeDeclaration(int type) {
+        return type == TokenTypes.CLASS_DEF
+                || type == TokenTypes.INTERFACE_DEF
+                || type == TokenTypes.ANNOTATION_DEF
+                || type == TokenTypes.ENUM_DEF
+                || type == TokenTypes.RECORD_DEF;
+    }
+
+    /**
+     * Determines if the token type belongs to the given types.
+     *
+     * @param type the Token Type to check
+     * @param types the acceptable types
+     *
+     * @return true if type matches one of the given types.
+     */
+    public static boolean isOfType(int type, int... types) {
+        return Arrays.stream(types).anyMatch(tokenType -> tokenType == type);
+    }
+
+    /**
+     * Determines if the AST belongs to the given types.
+     *
+     * @param ast the AST node to check
+     * @param types the acceptable types
+     *
+     * @return true if type matches one of the given types.
+     */
+    public static boolean isOfType(DetailAST ast, int... types) {
+        return ast != null && isOfType(ast.getType(), types);
+    }
+
 }
