@@ -59,6 +59,18 @@ public class RootNode extends AbstractNode {
         createChildren();
     }
 
+    /**
+     * Compares current object with specified for order.
+     * Throws {@code UnsupportedOperationException} because functionality not required here.
+     *
+     * @param nodeInfo another {@code NodeInfo} object
+     * @return number representing order of current object to specified one
+     */
+    @Override
+    public int compareOrder(NodeInfo nodeInfo) {
+        throw throwUnsupportedOperationException();
+    }
+
     /**
      * Iterates siblings of the current node and
      * recursively creates new Xpath-nodes.
@@ -75,6 +87,7 @@ public class RootNode extends AbstractNode {
     /**
      * Returns attribute value. Throws {@code UnsupportedOperationException} because root node
      * has no attributes.
+     *
      * @param namespace namespace
      * @param localPart actual name of the attribute
      * @return attribute value
@@ -86,6 +99,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Returns local part.
+     *
      * @return local part
      */
     @Override
@@ -95,6 +109,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Returns type of the node.
+     *
      * @return node kind
      */
     @Override
@@ -104,6 +119,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Returns parent.
+     *
      * @return parent
      */
     @Override
@@ -113,6 +129,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Returns root of the tree.
+     *
      * @return root of the tree
      */
     @Override
@@ -120,18 +137,10 @@ public class RootNode extends AbstractNode {
         return this;
     }
 
-    /**
-     * Returns string value.
-     * @return string value
-     */
-    @Override
-    public String getStringValue() {
-        return ROOT_NAME;
-    }
-
     /**
      * Determines axis iteration algorithm. Throws {@code UnsupportedOperationException} in case,
      * when there is no axis iterator for given axisNumber.
+     *
      * @param axisNumber element from {@code AxisInfo}
      * @return {@code AxisIterator} object
      */
@@ -190,6 +199,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Returns line number.
+     *
      * @return line number
      */
     @Override
@@ -199,6 +209,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Returns column number.
+     *
      * @return column number
      */
     @Override
@@ -208,6 +219,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Getter method for token type.
+     *
      * @return token type
      */
     @Override
@@ -217,6 +229,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Returns underlying node.
+     *
      * @return underlying node
      */
     @Override
@@ -226,6 +239,7 @@ public class RootNode extends AbstractNode {
 
     /**
      * Returns UnsupportedOperationException exception.
+     *
      * @return UnsupportedOperationException exception
      */
     private static UnsupportedOperationException throwUnsupportedOperationException() {
