@@ -92,6 +92,7 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
 
 /**
  * CheckerTest.
+ *
  * @noinspection ClassWithTooManyDependencies
  */
 public class CheckerTest extends AbstractModuleTestSupport {
@@ -354,7 +355,6 @@ public class CheckerTest extends AbstractModuleTestSupport {
     public void testSetters() {
         // all  that is set by reflection, so just make code coverage be happy
         final Checker checker = new Checker();
-        checker.setClassLoader(null);
         checker.setBasedir("some");
         checker.setSeverity("ignore");
 
@@ -416,7 +416,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
         checker.finishLocalSetup();
 
         final Context context = Whitebox.getInternalState(checker, "childContext");
-        final String encoding = System.getProperty("file.encoding", StandardCharsets.UTF_8.name());
+        final String encoding = StandardCharsets.UTF_8.name();
         assertEquals(encoding, context.get("charset"), "Charset was different than expected");
         assertEquals("error", context.get("severity"), "Severity is set to unexpected value");
         assertEquals("testBaseDir", context.get("basedir"), "Basedir is set to unexpected value");
@@ -668,6 +668,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
     /**
      * Test doesn't need to be serialized.
+     *
      * @noinspection SerializableInnerClassWithNonSerializableOuterClass
      */
     @Test
@@ -682,6 +683,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
             /**
              * Test is checking catch clause when exception is thrown.
+             *
              * @noinspection ProhibitedExceptionThrown
              */
             @Override
@@ -710,6 +712,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
     /**
      * Test doesn't need to be serialized.
+     *
      * @noinspection SerializableInnerClassWithNonSerializableOuterClass
      */
     @Test
@@ -724,6 +727,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
             /**
              * Test is checking catch clause when exception is thrown.
+             *
              * @noinspection ProhibitedExceptionThrown
              */
             @Override
@@ -982,6 +986,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
     /**
      * Test doesn't need to be serialized.
+     *
      * @noinspection SerializableInnerClassWithNonSerializableOuterClass
      */
     @Test
@@ -1006,6 +1011,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
             /**
              * Test is checking catch clause when exception is thrown.
+             *
              * @noinspection ProhibitedExceptionThrown
              */
             @Override
@@ -1045,6 +1051,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
     /**
      * Test doesn't need to be serialized.
+     *
      * @noinspection SerializableInnerClassWithNonSerializableOuterClass
      */
     @Test
@@ -1064,6 +1071,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
             /**
              * Test is checking catch clause when exception is thrown.
+             *
              * @noinspection ProhibitedExceptionThrown
              */
             @Override
@@ -1102,6 +1110,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
     /**
      * Test doesn't need to be serialized.
+     *
      * @noinspection SerializableInnerClassWithNonSerializableOuterClass
      */
     @Test
@@ -1114,6 +1123,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
             /**
              * Test is checking catch clause when exception is thrown.
+             *
              * @noinspection ProhibitedExceptionThrown
              */
             @Override
@@ -1139,6 +1149,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
     /**
      * Test doesn't need to be serialized.
+     *
      * @noinspection SerializableInnerClassWithNonSerializableOuterClass
      */
     @Test
@@ -1157,6 +1168,7 @@ public class CheckerTest extends AbstractModuleTestSupport {
 
             /**
              * Test is checking catch clause when exception is thrown.
+             *
              * @noinspection ProhibitedExceptionThrown
              */
             @Override
