@@ -180,6 +180,26 @@ public class JavaParserTest extends AbstractModuleTestSupport {
                 counter.blockComments.toArray(), "Invalid block comments");
     }
 
+    @Test
+    public void testJava14TextBlocks() throws Exception {
+        final DetailAST root =
+            JavaParser.parseFile(new File(
+                    getNonCompilablePath("InputJavaParserTextBlocks.java")),
+                JavaParser.Options.WITHOUT_COMMENTS);
+
+        final Optional<DetailAST> textBlockContent = TestUtil.findTokenInAstByPredicate(root,
+            ast -> ast.getType() == TokenTypes.TEXT_BLOCK_CONTENT);
+
+        assertTrue(textBlockContent.isPresent(), "Text block content should be present");
+
+        final DetailAST content = textBlockContent.get();
+        final String expectedContents = "\n                 string";
+
+        assertEquals(5, content.getLineNo(), "Unexpected line number");
+        assertEquals(32, content.getColumnNo(), "Unexpected column number");
+        assertEquals(expectedContents, content.getText(), "Unexpected text block content");
+    }
+
     private static final class CountComments {
         private final List<String> lineComments = new ArrayList<>();
         private final List<String> blockComments = new ArrayList<>();
