@@ -56,6 +56,7 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
                     + "  -h, --help        Show this help message and exit.%n"
                     + "  -V, --version     Print version information and exit.%n");
     private static final File DESTFILE = new File("target/tokentypes.properties");
+    private static final String DESTFILE_ABSOLUTE_PATH = DESTFILE.getAbsolutePath();
 
     @Override
     protected String getPackageLocation() {
@@ -103,8 +104,9 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
             throws Exception {
         JavadocPropertiesGenerator.main("--nonexistent-argument");
 
-        final String expected = String.format(Locale.ROOT, "Missing required options "
-                + "[--destfile=<outputFile>, params[0]=<inputFile>]%n")
+        final String expected = String.format(Locale.ROOT,
+                "Missing required options and parameters: "
+                + "'--destfile=<outputFile>', '<inputFile>'%n")
                 + USAGE;
         assertEquals(expected, systemErr.getCapturedData(), "Unexpected error log");
         assertEquals("", systemOut.getCapturedData(), "Unexpected output log");
@@ -116,7 +118,7 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
         JavadocPropertiesGenerator.main(getPath("InputMain.java"));
 
         final String expected = String.format(Locale.ROOT,
-                "Missing required option '--destfile=<outputFile>'%n") + USAGE;
+                "Missing required option: '--destfile=<outputFile>'%n") + USAGE;
         assertEquals(expected, systemErr.getCapturedData(), "Unexpected error log");
         assertEquals("", systemOut.getCapturedData(), "Unexpected output log");
     }
@@ -124,10 +126,10 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
     @Test
     public void testNoInputSpecified(@SysErr Capturable systemErr,
             @SysOut Capturable systemOut) throws Exception {
-        JavadocPropertiesGenerator.main("--destfile", DESTFILE.getAbsolutePath());
+        JavadocPropertiesGenerator.main("--destfile", DESTFILE_ABSOLUTE_PATH);
 
         final String expected = String.format(Locale.ROOT,
-                "Missing required parameter: <inputFile>%n") + USAGE;
+                "Missing required parameter: '<inputFile>'%n") + USAGE;
         assertEquals(expected, systemErr.getCapturedData(), "Unexpected error log");
         assertEquals("", systemOut.getCapturedData(), "Unexpected output log");
     }
@@ -135,7 +137,7 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
     @Test
     public void testNotClass(@SysErr Capturable systemErr, @SysOut Capturable systemOut)
             throws Exception {
-        JavadocPropertiesGenerator.main("--destfile", DESTFILE.getAbsolutePath(),
+        JavadocPropertiesGenerator.main("--destfile", DESTFILE_ABSOLUTE_PATH,
             getPath("InputJavadocPropertiesGeneratorNotClass.java"));
         assertEquals("", systemErr.getCapturedData(), "Unexpected error log");
         assertEquals("", systemOut.getCapturedData(), "Unexpected output log");
@@ -146,13 +148,13 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
             @SysOut Capturable systemOut) {
         try {
             JavadocPropertiesGenerator.main(
-                "--destfile", DESTFILE.getAbsolutePath(), "NotExistent.java");
+                "--destfile", DESTFILE_ABSOLUTE_PATH, "NotExistent.java");
             fail("Exception was expected");
         }
         catch (CheckstyleException ex) {
             assertEquals(
                     "Failed to write javadoc properties of 'NotExistent.java' to '"
-                    + DESTFILE.getAbsolutePath() + "'",
+                    + DESTFILE_ABSOLUTE_PATH + "'",
                 ex.getMessage(), "Invalid error message");
 
             final Throwable cause = ex.getCause();
@@ -197,7 +199,7 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
             + "DEPRECATED_LITERAL='@deprecated' literal in @deprecated Javadoc tag?" + EOL;
 
         JavadocPropertiesGenerator.main(getPath("InputJavadocPropertiesGeneratorCorrect.java"),
-            "--destfile", DESTFILE.getAbsolutePath());
+            "--destfile", DESTFILE_ABSOLUTE_PATH);
         assertEquals("", systemErr.getCapturedData(), "Unexpected error log");
         assertEquals("", systemOut.getCapturedData(), "Unexpected output log");
         final String fileContent = FileUtils.readFileToString(DESTFILE, StandardCharsets.UTF_8);
@@ -208,7 +210,7 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
     public void testEmptyJavadoc(@SysErr Capturable systemErr, @SysOut Capturable systemOut)
             throws Exception {
         JavadocPropertiesGenerator.main(getPath("InputJavadocPropertiesGeneratorEmptyJavadoc.java"),
-            "--destfile", DESTFILE.getAbsolutePath());
+            "--destfile", DESTFILE_ABSOLUTE_PATH);
         assertEquals("", systemErr.getCapturedData(), "Unexpected error log");
         assertEquals("", systemOut.getCapturedData(), "Unexpected output log");
         final long size = FileUtils.sizeOf(DESTFILE);
@@ -219,7 +221,7 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
     public void testNotConstants(@SysErr Capturable systemErr, @SysOut Capturable systemOut)
             throws Exception {
         JavadocPropertiesGenerator.main(getPath("InputJavadocPropertiesGeneratorNotConstants.java"),
-            "--destfile", DESTFILE.getAbsolutePath());
+            "--destfile", DESTFILE_ABSOLUTE_PATH);
         assertEquals("", systemErr.getCapturedData(), "Unexpected error log");
         assertEquals("", systemOut.getCapturedData(), "Unexpected output log");
         final long size = FileUtils.sizeOf(DESTFILE);
@@ -236,10 +238,9 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
 
     @Test
     public void testJavadocParseError() throws Exception {
+        final String path = getPath("InputJavadocPropertiesGeneratorJavadocParseError.java");
         try {
-            JavadocPropertiesGenerator.main(
-                getPath("InputJavadocPropertiesGeneratorJavadocParseError.java"),
-                "--destfile", DESTFILE.getAbsolutePath());
+            JavadocPropertiesGenerator.main(path, "--destfile", DESTFILE_ABSOLUTE_PATH);
             fail("Exception was expected");
         }
         catch (IllegalArgumentException ex) {
@@ -253,10 +254,9 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
 
     @Test
     public void testNotImplementedTag() throws Exception {
+        final String path = getPath("InputJavadocPropertiesGeneratorNotImplementedTag.java");
         try {
-            JavadocPropertiesGenerator.main(
-                getPath("InputJavadocPropertiesGeneratorNotImplementedTag.java"),
-                "--destfile", DESTFILE.getAbsolutePath());
+            JavadocPropertiesGenerator.main(path, "--destfile", DESTFILE_ABSOLUTE_PATH);
             fail("Exception was expected");
         }
         catch (CheckstyleException ex) {
@@ -269,10 +269,9 @@ public class JavadocPropertiesGeneratorTest extends AbstractPathTestSupport {
 
     @Test
     public void testParseError() throws Exception {
+        final String path = getNonCompilablePath("InputJavadocPropertiesGeneratorParseError.java");
         try {
-            JavadocPropertiesGenerator.main(
-                getNonCompilablePath("InputJavadocPropertiesGeneratorParseError.java"),
-                "--destfile", DESTFILE.getAbsolutePath());
+            JavadocPropertiesGenerator.main(path, "--destfile", DESTFILE_ABSOLUTE_PATH);
             fail("Exception was expected");
         }
         catch (CheckstyleException ex) {
