@@ -402,8 +402,6 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
     @Test
     public void testFinishLocalSetupFullyInitialized() {
         final TreeWalker treeWalker = new TreeWalker();
-        final ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();
-        treeWalker.setClassLoader(contextClassLoader);
         treeWalker.setSeverity("error");
         treeWalker.setTabWidth(100);
         treeWalker.finishLocalSetup();
