@@ -19,6 +19,7 @@
 
 package com.puppycrawl.tools.checkstyle.api;
 
+import static com.google.common.truth.Truth.assertWithMessage;
 import static com.puppycrawl.tools.checkstyle.utils.CommonUtil.EMPTY_OBJECT_ARRAY;
 import static org.hamcrest.CoreMatchers.hasItem;
 import static org.hamcrest.CoreMatchers.not;
@@ -52,6 +53,7 @@ import nl.jqno.equalsverifier.EqualsVerifierReport;
  * Custom class loader is needed to pass URLs to pretend these are loaded from the classpath
  * though we can't add/change the files for testing. The class loader is nested in this class,
  * so the custom class loader we are using is safe.
+ *
  * @noinspection ClassLoaderInstantiation
  */
 public class LocalizedMessageTest {
@@ -100,7 +102,9 @@ public class LocalizedMessageTest {
     public void testEqualsAndHashCode() {
         final EqualsVerifierReport ev = EqualsVerifier.forClass(LocalizedMessage.class)
                 .usingGetClass().report();
-        assertEquals(EqualsVerifierReport.SUCCESS, ev, "Error: " + ev.getMessage());
+        assertWithMessage("Error: " + ev.getMessage())
+                .that(ev.isSuccessful())
+                .isTrue();
     }
 
     @Test
@@ -146,6 +150,7 @@ public class LocalizedMessageTest {
 
     /**
      * Ignore resource errors for testing.
+     *
      * @noinspection resource, IOResourceOpenedButNotSafelyClosed
      */
     @Test
@@ -193,6 +198,7 @@ public class LocalizedMessageTest {
 
     /**
      * Ignore resource errors for testing.
+     *
      * @noinspection resource, IOResourceOpenedButNotSafelyClosed
      */
     @Test
@@ -394,6 +400,7 @@ public class LocalizedMessageTest {
     /**
      * Custom class loader is needed to pass URLs to pretend these are loaded from the classpath
      * though we can't add/change the files for testing.
+     *
      * @noinspection CustomClassloader
      */
     private static class TestUrlsClassLoader extends ClassLoader {
