@@ -48,6 +48,7 @@ import com.puppycrawl.tools.checkstyle.api.Configuration;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.LocalizedMessage;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
+import com.puppycrawl.tools.checkstyle.checks.naming.AbstractNameCheck;
 import com.puppycrawl.tools.checkstyle.checks.naming.MemberNameCheck;
 import com.puppycrawl.tools.checkstyle.checks.whitespace.AbstractParenPadCheck;
 import com.puppycrawl.tools.checkstyle.checks.whitespace.TypecastParenPadCheck;
@@ -437,4 +438,32 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         return new AuditEvent(source, "filename", message);
     }
 
+    @Test
+    public void testSuppressWarningsTextBlocks() throws Exception {
+        final Configuration checkConfig = createModuleConfig(SuppressWarningsHolder.class);
+        final DefaultConfiguration treeWalker = createModuleConfig(TreeWalker.class);
+        final Configuration filter = createModuleConfig(SuppressWarningsFilter.class);
+        final DefaultConfiguration violationCheck = createModuleConfig(MemberNameCheck.class);
+
+        treeWalker.addChild(checkConfig);
+        treeWalker.addChild(violationCheck);
+
+        final DefaultConfiguration root = createRootConfig(treeWalker);
+        root.addChild(filter);
+
+        final String pattern = "^[a-z][a-zA-Z0-9]*$";
+
+        final String[] expected = {
+            "15:12: " + getCheckMessage(MemberNameCheck.class,
+                AbstractNameCheck.MSG_INVALID_PATTERN, "STRING3", pattern),
+            "17:12: " + getCheckMessage(MemberNameCheck.class,
+                AbstractNameCheck.MSG_INVALID_PATTERN, "STRING4", pattern),
+            "46:12: " + getCheckMessage(MemberNameCheck.class,
+                AbstractNameCheck.MSG_INVALID_PATTERN, "STRING8", pattern),
+            };
+
+        verify(root,
+            getNonCompilablePath("InputSuppressWarningsHolderTextBlocks.java"), expected);
+    }
+
 }
