@@ -412,6 +412,65 @@ public class HiddenFieldCheckTest
         verify(checkConfig, getPath("InputHiddenFieldReceiver.java"), expected);
     }
 
+    @Test
+    public void testHiddenFieldEnhancedInstanceof() throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(HiddenFieldCheck.class);
+        checkConfig.addAttribute("tokens", "PATTERN_VARIABLE_DEF");
+
+        final String[] expected = {
+            "22:39: " + getCheckMessage(MSG_KEY, "price"),
+            "33:35: " + getCheckMessage(MSG_KEY, "hiddenStaticField"),
+        };
+        verify(checkConfig,
+                getNonCompilablePath("InputHiddenFieldEnhancedInstanceof.java"), expected);
+    }
+
+    @Test
+    public void testHiddenFieldSwitchExpression() throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(HiddenFieldCheck.class);
+
+        final String[] expected = {
+            "25:13: " + getCheckMessage(MSG_KEY, "x"),
+            "29:30: " + getCheckMessage(MSG_KEY, "word"),
+            "30:35: " + getCheckMessage(MSG_KEY, "otherWord"),
+            "31:21: " + getCheckMessage(MSG_KEY, "y"),
+            "35:21: " + getCheckMessage(MSG_KEY, "z"),
+            "39:21: " + getCheckMessage(MSG_KEY, "a"),
+            "43:21: " + getCheckMessage(MSG_KEY, "b"),
+            "50:13: " + getCheckMessage(MSG_KEY, "x"),
+            "54:30: " + getCheckMessage(MSG_KEY, "word"),
+            "55:35: " + getCheckMessage(MSG_KEY, "otherWord"),
+            "56:21: " + getCheckMessage(MSG_KEY, "y"),
+            "60:21: " + getCheckMessage(MSG_KEY, "z"),
+            "64:21: " + getCheckMessage(MSG_KEY, "a"),
+            "68:21: " + getCheckMessage(MSG_KEY, "b"),
+        };
+        verify(checkConfig,
+                getNonCompilablePath("InputHiddenFieldSwitchExpression.java"), expected);
+    }
+
+    @Test
+    public void testHiddenFieldRecords() throws Exception {
+        final DefaultConfiguration checkConfig =
+            createModuleConfig(HiddenFieldCheck.class);
+
+        final String[] expected = {
+            "20:17: " + getCheckMessage(MSG_KEY, "myHiddenInt"),
+            "25:17: " + getCheckMessage(MSG_KEY, "myHiddenInt"),
+            "33:17: " + getCheckMessage(MSG_KEY, "hiddenField"),
+            "41:39: " + getCheckMessage(MSG_KEY, "hiddenStaticField"),
+            "55:39: " + getCheckMessage(MSG_KEY, "price"),
+            "64:21: " + getCheckMessage(MSG_KEY, "x"),
+            "68:20: " + getCheckMessage(MSG_KEY, "string"),
+            "78:21: " + getCheckMessage(MSG_KEY, "x"),
+            "82:20: " + getCheckMessage(MSG_KEY, "string"),
+            };
+        verify(checkConfig,
+            getNonCompilablePath("InputHiddenFieldRecords.java"), expected);
+    }
+
     /**
      * We cannot reproduce situation when visitToken is called and leaveToken is not.
      * So, we have to use reflection to be sure that even in such situation
