@@ -525,6 +525,84 @@ public class AbbreviationAsWordInNameCheckTest extends AbstractModuleTestSupport
                 expected);
     }
 
+    @Test
+    public void testAbbreviationAsWordInNameCheckEnhancedInstanceof()
+            throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(AbbreviationAsWordInNameCheck.class);
+
+        final int expectedCapitalCount = 4;
+
+        final String[] expected = {
+            "19:36: " + getWarningMessage("STRING", expectedCapitalCount),
+            "20:43: " + getWarningMessage("INTEGER", expectedCapitalCount),
+            "29:41: " + getWarningMessage("ssSTRING", expectedCapitalCount),
+            "32:35: " + getWarningMessage("XMLHTTP", expectedCapitalCount),
+        };
+
+        verify(checkConfig,
+                getNonCompilablePath(
+                        "InputAbbreviationAsWordInNameCheckEnhancedInstanceof.java"),
+                expected);
+    }
+
+    @Test
+    public void testAbbreviationAsWordInNameCheckEnhancedInstanceofAllowXmlLength1()
+            throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(AbbreviationAsWordInNameCheck.class);
+        checkConfig.addAttribute("allowedAbbreviations", "XML");
+        checkConfig.addAttribute("allowedAbbreviationLength", "1");
+
+        final int expectedCapitalCount = 2;
+
+        final String[] expected = {
+            "19:36: " + getWarningMessage("STRING", expectedCapitalCount),
+            "20:43: " + getWarningMessage("INTEGER", expectedCapitalCount),
+            "28:39: " + getWarningMessage("aTXT", expectedCapitalCount),
+            "29:41: " + getWarningMessage("ssSTRING", expectedCapitalCount),
+            "32:35: " + getWarningMessage("XMLHTTP", expectedCapitalCount),
+        };
+
+        verify(checkConfig,
+                getNonCompilablePath(
+                        "InputAbbreviationAsWordInNameCheckEnhanced"
+                                + "InstanceofAllowXmlLength1.java"),
+                expected);
+    }
+
+    @Test
+    public void testAbbreviationAsWordInNameCheckRecords()
+            throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(AbbreviationAsWordInNameCheck.class);
+
+        final int expectedCapitalCount = 4;
+
+        final String[] expected = {
+            "19:11: " + getWarningMessage("myCLASS", expectedCapitalCount),
+            "20:13: " + getWarningMessage("INTEGER", expectedCapitalCount),
+            "21:14: " + getWarningMessage("METHOD", expectedCapitalCount),
+            "23:31: " + getWarningMessage("STRING", expectedCapitalCount),
+            "24:17: " + getWarningMessage("INTEGER", expectedCapitalCount),
+            "30:12: " + getWarningMessage("myRECORD1", expectedCapitalCount),
+            "30:29: " + getWarningMessage("STRING", expectedCapitalCount),
+            "32:14: " + getWarningMessage("METHOD", expectedCapitalCount),
+            "37:17: " + getWarningMessage("INTEGER", expectedCapitalCount),
+            "42:12: " + getWarningMessage("myRECORD2", expectedCapitalCount),
+            "47:17: " + getWarningMessage("INTEGER", expectedCapitalCount),
+            "51:12: " + getWarningMessage("myRECORD3", expectedCapitalCount),
+            "51:29: " + getWarningMessage("STRING", expectedCapitalCount),
+            "51:41: " + getWarningMessage("INTEGER", expectedCapitalCount),
+            "51:57: " + getWarningMessage("NODES", expectedCapitalCount),
+        };
+
+        verify(checkConfig,
+                getNonCompilablePath(
+                        "InputAbbreviationAsWordInNameCheckRecords.java"),
+                expected);
+    }
+
     private String getWarningMessage(String typeName, int expectedCapitalCount) {
         return getCheckMessage(MSG_KEY, typeName, expectedCapitalCount);
     }
