@@ -69,4 +69,27 @@ public class NoLineWrapCheckTest
         verify(checkConfig, getPath("InputNoLineWrapBad.java"), expected);
     }
 
+    @Test
+    public void testNoLineWrapRecordsAndCompactCtors()
+            throws Exception {
+        final DefaultConfiguration checkConfig = createModuleConfig(NoLineWrapCheck.class);
+        checkConfig.addAttribute(
+                "tokens", "RECORD_DEF, CLASS_DEF, CTOR_DEF, COMPACT_CTOR_DEF");
+
+        final String[] expected = {
+            "10:9: " + getCheckMessage(MSG_KEY, "CTOR_DEF"),
+            "16:5: " + getCheckMessage(MSG_KEY, "RECORD_DEF"),
+            "25:9: " + getCheckMessage(MSG_KEY, "CTOR_DEF"),
+            "31:5: " + getCheckMessage(MSG_KEY, "RECORD_DEF"),
+            "33:9: " + getCheckMessage(MSG_KEY, "COMPACT_CTOR_DEF"),
+            "37:5: " + getCheckMessage(MSG_KEY, "RECORD_DEF"),
+            "39:9: " + getCheckMessage(MSG_KEY, "COMPACT_CTOR_DEF"),
+            "44:9: " + getCheckMessage(MSG_KEY, "RECORD_DEF"),
+            "46:13: " + getCheckMessage(MSG_KEY, "COMPACT_CTOR_DEF"),
+        };
+        verify(checkConfig,
+                getNonCompilablePath("InputNoLineWrapRecordsAndCompactCtors.java"),
+                expected);
+    }
+
 }
