@@ -19,6 +19,7 @@
 
 package com.puppycrawl.tools.checkstyle.filters;
 
+import static com.google.common.truth.Truth.assertWithMessage;
 import static com.puppycrawl.tools.checkstyle.checks.naming.AbstractNameCheck.MSG_INVALID_PATTERN;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -117,7 +118,7 @@ public class SuppressionCommentFilterTest
         verifySuppressed(filterConfig, suppressed);
     }
 
-    //Suppress all checks between default comments
+    // Suppress all checks between default comments
     @Test
     public void testDefault() throws Exception {
         final DefaultConfiguration filterConfig =
@@ -171,7 +172,7 @@ public class SuppressionCommentFilterTest
         verifySuppressed(filterConfig, suppressed);
     }
 
-    //Suppress all checks between CS_OFF and CS_ON
+    // Suppress all checks between CS_OFF and CS_ON
     @Test
     public void testOffFormat() throws Exception {
         final DefaultConfiguration filterConfig =
@@ -195,8 +196,8 @@ public class SuppressionCommentFilterTest
         verifySuppressed(filterConfig, suppressed);
     }
 
-    //Test suppression of checks of only one type
-    //Suppress only ConstantNameCheck between CS_OFF and CS_ON
+    // Test suppression of checks of only one type
+    //  Suppress only ConstantNameCheck between CS_OFF and CS_ON
     @Test
     public void testOffFormatCheck() throws Exception {
         final DefaultConfiguration filterConfig =
@@ -306,7 +307,9 @@ public class SuppressionCommentFilterTest
         final Object tag = getTagsAfterExecutionOnDefaultFilter("//CHECKSTYLE:OFF").get(0);
         final EqualsVerifierReport ev = EqualsVerifier.forClass(tag.getClass())
                 .usingGetClass().report();
-        assertEquals(EqualsVerifierReport.SUCCESS, ev, "Error: " + ev.getMessage());
+        assertWithMessage("Error: " + ev.getMessage())
+                .that(ev.isSuccessful())
+                .isTrue();
     }
 
     @Test
