@@ -26,6 +26,7 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.io.InputStream;
+import java.io.Reader;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
@@ -134,6 +135,12 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
                 getPath("InputRegressionJavaTypecast.java"));
     }
 
+    @Test
+    public void testJava14InstanceofWithPatternMatching() throws Exception {
+        verifyAst(getPath("java14/InputJava14InstanceofWithPatternMatchingAST.txt"),
+                getNonCompilablePath("java14/InputJava14InstanceofWithPatternMatching.java"));
+    }
+
     @Test
     public void testCharLiteralSurrogatePair() throws Exception {
         verifyAst(getPath("InputCharLiteralSurrogatePair.txt"),
@@ -168,6 +175,15 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
                 "TokenBuffer should not be null");
     }
 
+    @Test
+    public void testUnusedConstructors4() throws Exception {
+        final Class<?> clss = GeneratedTextBlockLexer.class;
+        final Constructor<?> constructor = clss.getDeclaredConstructor(Reader.class);
+
+        assertNotNull(constructor.newInstance(new Object[] {null}),
+                "Reader should not be null");
+    }
+
     @Test
     public void testCustomAstTree() throws Exception {
         verifyAstRaw(getPath("InputRegressionEmptyAst.txt"), "\t");
@@ -197,6 +213,36 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
                 JavaParser.Options.WITH_COMMENTS);
     }
 
+    @Test
+    public void testJava14Records() throws Exception {
+        verifyAst(getPath("java14/InputJava14Records.txt"),
+                getNonCompilablePath("java14/InputJava14Records.java"));
+    }
+
+    @Test
+    public void testJava14RecordsTopLevel() throws Exception {
+        verifyAst(getPath("java14/InputJava14RecordsTopLevel.txt"),
+                getNonCompilablePath("java14/InputJava14RecordsTopLevel.java"));
+    }
+
+    @Test
+    public void testJava14TextBlocks() throws Exception {
+        verifyAst(getPath("java14/InputJava14TextBlocks.txt"),
+                getNonCompilablePath("java14/InputJava14TextBlocks.java"));
+    }
+
+    @Test
+    public void testJava14TextBlocksEscapes() throws Exception {
+        verifyAst(getPath("java14/InputJava14TextBlocksEscapesAreOneChar.txt"),
+                getNonCompilablePath("java14/InputJava14TextBlocksEscapesAreOneChar.java"));
+    }
+
+    @Test
+    public void testJava14SwitchExpression() throws Exception {
+        verifyAst(getPath("java14/InputJava14SwitchExpression.txt"),
+                getNonCompilablePath("java14/InputJava14SwitchExpression.java"));
+    }
+
     @Test
     public void testImpossibleExceptions() throws Exception {
         AssertGeneratedJavaLexer.verifyFail("mSTD_ESC", 'a');
@@ -246,6 +292,30 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
                 '4', '4', '.', '4', 'P', '4', 'D', ';');
     }
 
+    @Test
+    public void testImpossibleExceptionsTextBlockLexer() throws Exception {
+        AssertGenTextBlockLexer.verifyFail("mSTD_ESC", '\\', '*', (char) 0xFFFF);
+        AssertGenTextBlockLexer.verifyFail("mONE_DOUBLE_QUOTE", '"', '"');
+        AssertGenTextBlockLexer.verifyFail("mNEWLINE", '*');
+        AssertGenTextBlockLexer.verifyFail("mTEXT_BLOCK_CONTENT", (char) 0xFFFF);
+    }
+
+    @Test
+    public void testImpossibleValidTextBlockLexer() throws Exception {
+        AssertGenTextBlockLexer.verifyPass("mSTD_ESC", '\\', '\\', 'n');
+        AssertGenTextBlockLexer.verifyPass("mNEWLINE", '\r', '\n');
+        AssertGenTextBlockLexer.verifyPass("mNEWLINE", '\r', '1');
+        AssertGenTextBlockLexer.verifyPass("mTEXT_BLOCK_CONTENT", '\\', (char) 0xFFFF);
+        AssertGenTextBlockLexer.verifyPass("mTEXT_BLOCK_CONTENT", '\r', (char) 0xFFFF);
+        AssertGenTextBlockLexer.verifyPass("mONE_DOUBLE_QUOTE", '"', 'a');
+        AssertGenTextBlockLexer.verifyPass("mTWO_DOUBLE_QUOTES", '"', '"', 'a');
+        AssertGenTextBlockLexer.verifyPass("mONE_DOUBLE_QUOTE", '"', '\r', '\r');
+        AssertGenTextBlockLexer
+                .verifyPass("mTWO_DOUBLE_QUOTES", '"', '"', '\r', '\r');
+        AssertGenTextBlockLexer
+                .verifyPass("mTEXT_BLOCK_LITERAL_END", '"', '"', '"', (char) 0xFFFF);
+    }
+
     private static void verifyAstRaw(String expectedTextPrintFileName, String actualJava)
             throws Exception {
         verifyAstRaw(expectedTextPrintFileName, actualJava, JavaParser.Options.WITHOUT_COMMENTS);
@@ -267,6 +337,80 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
                 "Generated AST from Java code should match pre-defined AST");
     }
 
+    private static final class AssertGenTextBlockLexer
+            extends GeneratedTextBlockLexer {
+
+        private int laPosition;
+        private char[] laResults;
+
+        private AssertGenTextBlockLexer() {
+            super((InputStream) null);
+        }
+
+        public static void verifyPass(String methodName, char... laResults) throws Exception {
+            verify(methodName, true, 1, laResults);
+        }
+
+        public static void verifyFail(String methodName, char... laResults) throws Exception {
+            verify(methodName, false, 1, laResults);
+        }
+
+        private static void verify(String methodName, boolean expectPass, int guessing,
+                                   char... laResults) throws Exception {
+            final AssertGenTextBlockLexer instance =
+                    new AssertGenTextBlockLexer();
+            instance.laPosition = 0;
+            instance.laResults = laResults.clone();
+            instance.inputState.guessing = guessing;
+
+            final Method method = GeneratedTextBlockLexer.class.getDeclaredMethod(methodName,
+                    boolean.class);
+            boolean exception;
+
+            try {
+                method.invoke(instance, true);
+                exception = false;
+            }
+            catch (InvocationTargetException ex) {
+                if (expectPass) {
+                    throw ex;
+                }
+
+                final Class<?> clss = ex.getTargetException().getClass();
+                if (clss != NoViableAltForCharException.class
+                        && clss != SemanticException.class) {
+                    throw ex;
+                }
+                exception = true;
+            }
+
+            if (expectPass) {
+                assertFalse(exception, "Call to GeneratedTextBlockLexer." + methodName
+                        + " resulted in an exception");
+            }
+            else {
+                assertTrue(exception, "Call to GeneratedTextBlockLexer." + methodName
+                        + " did not result in an exception");
+            }
+        }
+
+        @Override
+        public char LA(int i) {
+            return laResults[laPosition + i - 1];
+        }
+
+        @Override
+        public void consume() {
+            laPosition++;
+        }
+
+        @Override
+        public int mark() {
+            return 1;
+        }
+
+    }
+
     private static final class AssertGeneratedJavaLexer extends GeneratedJavaLexer {
 
         private int laPosition;
