@@ -253,8 +253,20 @@ public class GeneratedJavaTokenTypesTest {
         assertEquals(195, GeneratedJavaTokenTypes.HEX_DOUBLE_LITERAL, message);
         assertEquals(196, GeneratedJavaTokenTypes.SIGNED_INTEGER, message);
         assertEquals(197, GeneratedJavaTokenTypes.BINARY_EXPONENT, message);
+        assertEquals(198, GeneratedJavaTokenTypes.PATTERN_VARIABLE_DEF, message);
+        assertEquals(199, GeneratedJavaTokenTypes.RECORD_DEF, message);
+        assertEquals(200, GeneratedJavaTokenTypes.LITERAL_record, message);
+        assertEquals(201, GeneratedJavaTokenTypes.RECORD_COMPONENTS, message);
+        assertEquals(202, GeneratedJavaTokenTypes.RECORD_COMPONENT_DEF, message);
+        assertEquals(203, GeneratedJavaTokenTypes.COMPACT_CTOR_DEF, message);
+        assertEquals(204, GeneratedJavaTokenTypes.TEXT_BLOCK_LITERAL_BEGIN, message);
+        assertEquals(205, GeneratedJavaTokenTypes.TEXT_BLOCK_CONTENT, message);
+        assertEquals(206, GeneratedJavaTokenTypes.TEXT_BLOCK_LITERAL_END, message);
+        assertEquals(207, GeneratedJavaTokenTypes.LITERAL_yield, message);
+        assertEquals(208, GeneratedJavaTokenTypes.SWITCH_RULE, message);
+
         // Read JavaDoc before changing
-        assertEquals(196, GeneratedJavaTokenTypes.class.getDeclaredFields().length,
+        assertEquals(207, GeneratedJavaTokenTypes.class.getDeclaredFields().length,
                 "all tokens must be added to list in"
                         + " 'GeneratedJavaTokenTypesTest' and verified"
                         + " that their old numbering didn't change");
