@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,13 +19,15 @@
 
 package com.puppycrawl.tools.checkstyle.grammar.comments;
 
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 import java.util.LinkedHashSet;
 import java.util.Set;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
@@ -54,10 +56,10 @@ public class AllBlockCommentsTest extends AbstractModuleTestSupport {
         lineSeparator = CheckUtil.getLineSeparatorForFile(path, StandardCharsets.UTF_8);
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig, path, expected);
-        Assert.assertTrue("All comments should be empty", ALL_COMMENTS.isEmpty());
+        assertTrue(ALL_COMMENTS.isEmpty(), "All comments should be empty");
     }
 
-    private static class BlockCommentListenerCheck extends AbstractCheck {
+    public static class BlockCommentListenerCheck extends AbstractCheck {
 
         @Override
         public boolean isCommentNodesRequired() {
@@ -96,7 +98,7 @@ public class AllBlockCommentsTest extends AbstractModuleTestSupport {
         public void visitToken(DetailAST ast) {
             final String commentContent = ast.getFirstChild().getText();
             if (!ALL_COMMENTS.remove(commentContent)) {
-                Assert.fail("Unexpected comment: " + commentContent);
+                fail("Unexpected comment: " + commentContent);
             }
         }
 
