@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,8 +19,11 @@
 
 package com.puppycrawl.tools.checkstyle.grammar.comments;
 
-import org.junit.Assert;
-import org.junit.Test;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
+import org.junit.jupiter.api.Test;
 
 import com.puppycrawl.tools.checkstyle.AbstractTreeTestSupport;
 import com.puppycrawl.tools.checkstyle.JavaParser;
@@ -48,9 +51,9 @@ public class CommentsTest extends AbstractTreeTestSupport {
     @Test
     public void testToString() {
         final Comment comment = new Comment(new String[] {"value"}, 1, 2, 3);
-        Assert.assertEquals("Invalid toString result",
+        assertEquals(
                 "Comment[text=[value], startLineNo=2, endLineNo=2, startColNo=1, endColNo=3]",
-                comment.toString());
+                comment.toString(), "Invalid toString result");
     }
 
     @Test
@@ -64,10 +67,10 @@ public class CommentsTest extends AbstractTreeTestSupport {
             "     */"};
         final Comment comment = new Comment(commentText, 5, 49, 66);
 
-        Assert.assertEquals("Invalid comment start line number", 43, comment.getStartLineNo());
-        Assert.assertEquals("Invalid comment start column number", 5, comment.getStartColNo());
-        Assert.assertEquals("Invalid comment end line number", 49, comment.getEndLineNo());
-        Assert.assertEquals("Invalid comment end column number", 66, comment.getEndColNo());
+        assertEquals(43, comment.getStartLineNo(), "Invalid comment start line number");
+        assertEquals(5, comment.getStartColNo(), "Invalid comment start column number");
+        assertEquals(49, comment.getEndLineNo(), "Invalid comment end line number");
+        assertEquals(66, comment.getEndColNo(), "Invalid comment end column number");
     }
 
     @Test
@@ -76,11 +79,11 @@ public class CommentsTest extends AbstractTreeTestSupport {
             "// to simplify conditional logic"};
         final Comment comment = new Comment(commentText, 9, 89, 53);
 
-        Assert.assertTrue("Invalid intersection result", comment.intersects(89, 9, 89, 41));
-        Assert.assertTrue("Invalid intersection result", comment.intersects(89, 53, 90, 50));
-        Assert.assertTrue("Invalid intersection result", comment.intersects(87, 7, 88, 9));
-        Assert.assertFalse("Invalid intersection result", comment.intersects(90, 7, 91, 20));
-        Assert.assertFalse("Invalid intersection result", comment.intersects(89, 56, 89, 80));
+        assertTrue(comment.intersects(89, 9, 89, 41), "Invalid intersection result");
+        assertTrue(comment.intersects(89, 53, 90, 50), "Invalid intersection result");
+        assertTrue(comment.intersects(87, 7, 88, 9), "Invalid intersection result");
+        assertFalse(comment.intersects(90, 7, 91, 20), "Invalid intersection result");
+        assertFalse(comment.intersects(89, 56, 89, 80), "Invalid intersection result");
     }
 
 }
