@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,11 +19,18 @@
 
 package com.puppycrawl.tools.checkstyle.gui;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import java.io.File;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import com.puppycrawl.tools.checkstyle.AbstractPathTestSupport;
 import com.puppycrawl.tools.checkstyle.DetailAstImpl;
@@ -44,7 +51,7 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         return "com/puppycrawl/tools/checkstyle/gui/parsetreetablepresentation";
     }
 
-    @Before
+    @BeforeEach
     public void loadTree() throws Exception {
         tree = JavaParser.parseFile(new File(getPath("InputParseTreeTablePresentation.java")),
             JavaParser.Options.WITH_COMMENTS).getNextSibling();
@@ -54,13 +61,13 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
     public void testRoot() {
         final Object root = new ParseTreeTablePresentation(tree).getRoot();
         final int childCount = new ParseTreeTablePresentation(null).getChildCount(root);
-        Assert.assertEquals("Invalid child count", 1, childCount);
+        assertEquals(1, childCount, "Invalid child count");
     }
 
     @Test
     public void testChildCount() {
         final int childCount = new ParseTreeTablePresentation(null).getChildCount(tree);
-        Assert.assertEquals("Invalid child count", 5, childCount);
+        assertEquals(5, childCount, "Invalid child count");
     }
 
     @Test
@@ -68,15 +75,15 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         parseTree.setParseMode(ParseMode.JAVA_WITH_JAVADOC_AND_COMMENTS);
         final int childCount = parseTree.getChildCount(tree);
-        Assert.assertEquals("Invalid child count", 5, childCount);
+        assertEquals(5, childCount, "Invalid child count");
     }
 
     @Test
     public void testChild() {
         final Object child = new ParseTreeTablePresentation(null).getChild(tree, 1);
-        Assert.assertTrue("Invalid child type", child instanceof DetailAST);
-        Assert.assertEquals("Invalid child token type",
-                TokenTypes.BLOCK_COMMENT_BEGIN, ((DetailAST) child).getType());
+        assertTrue(child instanceof DetailAST, "Invalid child type");
+        final int type = ((DetailAST) child).getType();
+        assertEquals(TokenTypes.BLOCK_COMMENT_BEGIN, type, "Invalid child token type");
     }
 
     @Test
@@ -84,9 +91,9 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         parseTree.setParseMode(ParseMode.JAVA_WITH_JAVADOC_AND_COMMENTS);
         final Object child = parseTree.getChild(tree, 1);
-        Assert.assertTrue("Invalid child type", child instanceof DetailAST);
-        Assert.assertEquals("Invalid child token type",
-                TokenTypes.BLOCK_COMMENT_BEGIN, ((DetailAST) child).getType());
+        assertTrue(child instanceof DetailAST, "Invalid child type");
+        final int type = ((DetailAST) child).getType();
+        assertEquals(TokenTypes.BLOCK_COMMENT_BEGIN, type, "Invalid child token type");
     }
 
     @Test
@@ -95,7 +102,7 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         parseTree.setParseMode(ParseMode.JAVA_WITH_COMMENTS);
         final int javadocCommentChildCount = parseTree.getChildCount(commentContentNode);
-        Assert.assertEquals("Invalid child count", 0, javadocCommentChildCount);
+        assertEquals(0, javadocCommentChildCount, "Invalid child count");
     }
 
     @Test
@@ -105,7 +112,7 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final DetailAST commentContentNode = tree.getLastChild().getLastChild()
                 .getPreviousSibling().getLastChild().getFirstChild().getFirstChild();
         final int commentChildCount = parseTree.getChildCount(commentContentNode);
-        Assert.assertEquals("Invalid child count", 0, commentChildCount);
+        assertEquals(0, commentChildCount, "Invalid child count");
     }
 
     @Test
@@ -115,7 +122,7 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final DetailAST commentContentNode = tree.getLastChild().getLastChild()
                 .getPreviousSibling().getLastChild().getFirstChild().getFirstChild();
         final Object commentChild = parseTree.getChild(commentContentNode, 0);
-        Assert.assertNull("Child must be null", commentChild);
+        assertNull(commentChild, "Child must be null");
     }
 
     @Test
@@ -123,10 +130,10 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final DetailAST commentContentNode = tree.getFirstChild().getNextSibling().getFirstChild();
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         final int commentChildCount = parseTree.getChildCount(commentContentNode);
-        Assert.assertEquals("Invalid child count", 0, commentChildCount);
+        assertEquals(0, commentChildCount, "Invalid child count");
         parseTree.setParseMode(ParseMode.JAVA_WITH_JAVADOC_AND_COMMENTS);
         final int javadocCommentChildCount = parseTree.getChildCount(commentContentNode);
-        Assert.assertEquals("Invalid child count", 1, javadocCommentChildCount);
+        assertEquals(1, javadocCommentChildCount, "Invalid child count");
     }
 
     @Test
@@ -135,14 +142,14 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         parseTree.setParseMode(ParseMode.JAVA_WITH_JAVADOC_AND_COMMENTS);
         final Object child = parseTree.getChild(commentContentNode, 0);
-        Assert.assertTrue("Invalid child type", child instanceof DetailNode);
-        Assert.assertEquals("Invalid child token type",
-                JavadocTokenTypes.JAVADOC, ((DetailNode) child).getType());
+        assertTrue(child instanceof DetailNode, "Invalid child type");
+        final int type = ((DetailNode) child).getType();
+        assertEquals(JavadocTokenTypes.JAVADOC, type, "Invalid child token type");
         // get Child one more time to test cache of PModel
         final Object childSame = parseTree.getChild(commentContentNode, 0);
-        Assert.assertTrue("Invalid child type", childSame instanceof DetailNode);
-        Assert.assertEquals("Invalid child token type",
-                JavadocTokenTypes.JAVADOC, ((DetailNode) childSame).getType());
+        assertTrue(childSame instanceof DetailNode, "Invalid child type");
+        final int sameType = ((DetailNode) childSame).getType();
+        assertEquals(JavadocTokenTypes.JAVADOC, sameType, "Invalid child token type");
     }
 
     @Test
@@ -151,11 +158,11 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         parseTree.setParseMode(ParseMode.JAVA_WITH_JAVADOC_AND_COMMENTS);
         final Object javadoc = parseTree.getChild(commentContentNode, 0);
-        Assert.assertTrue("Invalid child type", javadoc instanceof DetailNode);
-        Assert.assertEquals("Invalid child token type",
-                JavadocTokenTypes.JAVADOC, ((DetailNode) javadoc).getType());
+        assertTrue(javadoc instanceof DetailNode, "Invalid child type");
+        final int type = ((DetailNode) javadoc).getType();
+        assertEquals(JavadocTokenTypes.JAVADOC, type, "Invalid child token type");
         final int javadocChildCount = parseTree.getChildCount(javadoc);
-        Assert.assertEquals("Invalid child count", 5, javadocChildCount);
+        assertEquals(5, javadocChildCount, "Invalid child count");
     }
 
     @Test
@@ -164,30 +171,30 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         parseTree.setParseMode(ParseMode.JAVA_WITH_JAVADOC_AND_COMMENTS);
         final Object javadoc = parseTree.getChild(commentContentNode, 0);
-        Assert.assertTrue("Invalid child type", javadoc instanceof DetailNode);
-        Assert.assertEquals("Invalid child token type",
-                JavadocTokenTypes.JAVADOC, ((DetailNode) javadoc).getType());
+        assertTrue(javadoc instanceof DetailNode, "Invalid child type");
+        final int type = ((DetailNode) javadoc).getType();
+        assertEquals(JavadocTokenTypes.JAVADOC, type, "Invalid child token type");
         final Object javadocChild = parseTree.getChild(javadoc, 2);
-        Assert.assertTrue("Invalid child type", javadocChild instanceof DetailNode);
-        Assert.assertEquals("Invalid child token type",
-                JavadocTokenTypes.TEXT, ((DetailNode) javadocChild).getType());
+        assertTrue(javadocChild instanceof DetailNode, "Invalid child type");
+        final int childType = ((DetailNode) javadocChild).getType();
+        assertEquals(JavadocTokenTypes.TEXT, childType, "Invalid child token type");
     }
 
     @Test
     public void testGetIndexOfChild() {
         DetailAST ithChild = tree.getFirstChild();
-        Assert.assertNotNull("Child must not be null", ithChild);
+        assertNotNull(ithChild, "Child must not be null");
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         int index = 0;
         while (ithChild != null) {
-            Assert.assertEquals("Invalid child index",
-                    index, parseTree.getIndexOfChild(tree, ithChild));
+            final int indexOfChild = parseTree.getIndexOfChild(tree, ithChild);
+            assertEquals(index, indexOfChild, "Invalid child index");
             ithChild = ithChild.getNextSibling();
             index++;
         }
 
-        Assert.assertEquals("Invalid child index",
-                -1, parseTree.getIndexOfChild(tree, new DetailAstImpl()));
+        final int indexOfChild = parseTree.getIndexOfChild(tree, new DetailAstImpl());
+        assertEquals(-1, indexOfChild, "Invalid child index");
     }
 
     /**
@@ -209,9 +216,8 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
             .getNextSibling()
             .getNextSibling();
 
-        Assert.assertNotNull("Expected a non-null identifier node here", node);
-        Assert.assertEquals("Expected identifier token",
-            TokenTypes.IDENT, node.getType());
+        assertNotNull(node, "Expected a non-null identifier node here");
+        assertEquals(TokenTypes.IDENT, node.getType(), "Expected identifier token");
 
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         final Object treeModel = parseTree.getValueAt(node, 0);
@@ -220,36 +226,35 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final int column = (int) parseTree.getValueAt(node, 3);
         final String text = (String) parseTree.getValueAt(node, 4);
 
-        Assert.assertEquals("Node should be an Identifier", "IDENT", type);
-        Assert.assertEquals("Class identifier should start on line 6", 6, line);
-        Assert.assertEquals("Class name should start from column 6", 6, column);
-        Assert.assertEquals("Wrong class name", "InputParseTreeTablePresentation", text);
-        Assert.assertNull("Root node should have null value", treeModel);
+        assertEquals("IDENT", type, "Node should be an Identifier");
+        assertEquals(6, line, "Class identifier should start on line 6");
+        assertEquals(6, column, "Class name should start from column 6");
+        assertEquals("InputParseTreeTablePresentation", text, "Wrong class name");
+        assertNull(treeModel, "Root node should have null value");
 
         try {
             parseTree.getValueAt(node, parseTree.getColumnCount());
-            Assert.fail("IllegalStateException expected");
+            fail("IllegalStateException expected");
         }
         catch (IllegalStateException ex) {
-            Assert.assertEquals("Invalid error message", "Unknown column", ex.getMessage());
+            assertEquals("Unknown column", ex.getMessage(), "Invalid error message");
         }
     }
 
     @Test
     public void testGetValueAtDetailNode() {
         final DetailAST commentContentNode = tree.getFirstChild().getNextSibling().getFirstChild();
-        Assert.assertNotNull("Comment node cannot be null", commentContentNode);
+        assertNotNull(commentContentNode, "Comment node cannot be null");
         final int nodeType = commentContentNode.getType();
-        Assert.assertTrue("Comment node should be a comment type",
-            TokenUtil.isCommentType(nodeType));
-        Assert.assertEquals("This should be a javadoc comment",
-            "/*", commentContentNode.getParent().getText());
+        assertTrue(TokenUtil.isCommentType(nodeType), "Comment node should be a comment type");
+        assertEquals("/*", commentContentNode.getParent().getText(),
+                "This should be a javadoc comment");
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
         parseTree.setParseMode(ParseMode.JAVA_WITH_JAVADOC_AND_COMMENTS);
         final Object child = parseTree.getChild(commentContentNode, 0);
 
-        Assert.assertFalse("Child has not to be leaf", parseTree.isLeaf(child));
-        Assert.assertTrue("Child has to be leaf", parseTree.isLeaf(tree.getFirstChild()));
+        assertFalse(parseTree.isLeaf(child), "Child has not to be leaf");
+        assertTrue(parseTree.isLeaf(tree.getFirstChild()), "Child has to be leaf");
 
         final Object treeModel = parseTree.getValueAt(child, 0);
         final String type = (String) parseTree.getValueAt(child, 1);
@@ -258,46 +263,50 @@ public class ParseTreeTablePresentationTest extends AbstractPathTestSupport {
         final String text = (String) parseTree.getValueAt(child, 4);
         final String expectedText = "JAVADOC";
 
-        Assert.assertNull("Tree model must be null", treeModel);
-        Assert.assertEquals("Invalid type", "JAVADOC", type);
-        Assert.assertEquals("Invalid line", 3, line);
-        Assert.assertEquals("Invalid column", 3, column);
-        Assert.assertEquals("Invalid text", expectedText, text);
+        assertNull(treeModel, "Tree model must be null");
+        assertEquals("JAVADOC", type, "Invalid type");
+        assertEquals(3, line, "Invalid line");
+        assertEquals(3, column, "Invalid column");
+        assertEquals(expectedText, text, "Invalid text");
 
         try {
             parseTree.getValueAt(child, parseTree.getColumnCount());
-            Assert.fail("IllegalStateException expected");
+            fail("IllegalStateException expected");
         }
         catch (IllegalStateException ex) {
-            Assert.assertEquals("Invalid error message", "Unknown column", ex.getMessage());
+            assertEquals("Unknown column", ex.getMessage(), "Invalid error message");
         }
     }
 
     @Test
     public void testColumnMethods() {
         final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
-        Assert.assertSame("Invalid type", ParseTreeTableModel.class, parseTree.getColumnClass(0));
-        Assert.assertSame("Invalid type", String.class, parseTree.getColumnClass(1));
-        Assert.assertSame("Invalid type", Integer.class, parseTree.getColumnClass(2));
-        Assert.assertSame("Invalid type", Integer.class, parseTree.getColumnClass(3));
-        Assert.assertSame("Invalid type", String.class, parseTree.getColumnClass(4));
+        assertSame(ParseTreeTableModel.class, parseTree.getColumnClass(0), "Invalid type");
+        assertSame(String.class, parseTree.getColumnClass(1), "Invalid type");
+        assertSame(Integer.class, parseTree.getColumnClass(2), "Invalid type");
+        assertSame(Integer.class, parseTree.getColumnClass(3), "Invalid type");
+        assertSame(String.class, parseTree.getColumnClass(4), "Invalid type");
 
         try {
             parseTree.getColumnClass(parseTree.getColumnCount());
-            Assert.fail("IllegalStateException expected");
+            fail("IllegalStateException expected");
         }
         catch (IllegalStateException ex) {
-            Assert.assertEquals("Invalid error message", "Unknown column", ex.getMessage());
+            assertEquals("Unknown column", ex.getMessage(), "Invalid error message");
         }
 
-        Assert.assertFalse("Invalid cell editable status", parseTree.isCellEditable(1));
+        assertFalse(parseTree.isCellEditable(1), "Invalid cell editable status");
+    }
 
-        Assert.assertEquals("Invalid column count", 5, parseTree.getColumnCount());
-        Assert.assertEquals("Invalid column name", "Tree", parseTree.getColumnName(0));
-        Assert.assertEquals("Invalid column name", "Type", parseTree.getColumnName(1));
-        Assert.assertEquals("Invalid column name", "Line", parseTree.getColumnName(2));
-        Assert.assertEquals("Invalid column name", "Column", parseTree.getColumnName(3));
-        Assert.assertEquals("Invalid column name", "Text", parseTree.getColumnName(4));
+    @Test
+    public void testColumnNames() {
+        final ParseTreeTablePresentation parseTree = new ParseTreeTablePresentation(null);
+        assertEquals(5, parseTree.getColumnCount(), "Invalid column count");
+        assertEquals("Tree", parseTree.getColumnName(0), "Invalid column name");
+        assertEquals("Type", parseTree.getColumnName(1), "Invalid column name");
+        assertEquals("Line", parseTree.getColumnName(2), "Invalid column name");
+        assertEquals("Column", parseTree.getColumnName(3), "Invalid column name");
+        assertEquals("Text", parseTree.getColumnName(4), "Invalid column name");
     }
 
 }
