@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,12 +25,12 @@ import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.hamcrest.CoreMatchers.nullValue;
 import static org.hamcrest.CoreMatchers.startsWith;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertThat;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.hamcrest.MatcherAssert.assertThat;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.Closeable;
 import java.io.File;
@@ -42,7 +42,7 @@ import java.util.Dictionary;
 import java.util.regex.Pattern;
 
 import org.apache.commons.io.IOUtils;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.puppycrawl.tools.checkstyle.AbstractPathTestSupport;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
@@ -60,8 +60,8 @@ public class CommonUtilTest extends AbstractPathTestSupport {
 
     @Test
     public void testIsProperUtilsClass() throws ReflectiveOperationException {
-        assertTrue("Constructor is not private",
-                isUtilsClassHasPrivateConstructor(CommonUtil.class, true));
+        assertTrue(isUtilsClassHasPrivateConstructor(CommonUtil.class, true),
+                "Constructor is not private");
     }
 
     /**
@@ -70,36 +70,36 @@ public class CommonUtilTest extends AbstractPathTestSupport {
     @Test
     public void testLengthExpandedTabs() {
         final String s1 = "\t";
-        assertEquals("Invalid expanded tabs length", 8,
-            CommonUtil.lengthExpandedTabs(s1, s1.length(), 8));
+        assertEquals(8, CommonUtil.lengthExpandedTabs(s1, s1.length(), 8),
+                "Invalid expanded tabs length");
 
         final String s2 = "  \t";
-        assertEquals("Invalid expanded tabs length", 8,
-            CommonUtil.lengthExpandedTabs(s2, s2.length(), 8));
+        assertEquals(8, CommonUtil.lengthExpandedTabs(s2, s2.length(), 8),
+                "Invalid expanded tabs length");
 
         final String s3 = "\t\t";
-        assertEquals("Invalid expanded tabs length", 16,
-            CommonUtil.lengthExpandedTabs(s3, s3.length(), 8));
+        assertEquals(16, CommonUtil.lengthExpandedTabs(s3, s3.length(), 8),
+                "Invalid expanded tabs length");
 
         final String s4 = " \t ";
-        assertEquals("Invalid expanded tabs length", 9,
-            CommonUtil.lengthExpandedTabs(s4, s4.length(), 8));
+        assertEquals(9, CommonUtil.lengthExpandedTabs(s4, s4.length(), 8),
+                "Invalid expanded tabs length");
 
-        assertEquals("Invalid expanded tabs length", 0,
-            CommonUtil.lengthMinusTrailingWhitespace(""));
-        assertEquals("Invalid expanded tabs length", 0,
-            CommonUtil.lengthMinusTrailingWhitespace(" \t "));
-        assertEquals("Invalid expanded tabs length", 3,
-            CommonUtil.lengthMinusTrailingWhitespace(" 23"));
-        assertEquals("Invalid expanded tabs length", 3,
-            CommonUtil.lengthMinusTrailingWhitespace(" 23 \t "));
+        assertEquals(0, CommonUtil.lengthMinusTrailingWhitespace(""),
+                "Invalid expanded tabs length");
+        assertEquals(0, CommonUtil.lengthMinusTrailingWhitespace(" \t "),
+                "Invalid expanded tabs length");
+        assertEquals(3, CommonUtil.lengthMinusTrailingWhitespace(" 23"),
+                "Invalid expanded tabs length");
+        assertEquals(3, CommonUtil.lengthMinusTrailingWhitespace(" 23 \t "),
+                "Invalid expanded tabs length");
     }
 
     @Test
     public void testCreatePattern() {
-        assertEquals("invalid pattern", "Test", CommonUtil.createPattern("Test").pattern());
-        assertEquals("invalid pattern", ".*Pattern.*", CommonUtil.createPattern(".*Pattern.*")
-                .pattern());
+        assertEquals("Test", CommonUtil.createPattern("Test").pattern(), "invalid pattern");
+        assertEquals(".*Pattern.*", CommonUtil.createPattern(".*Pattern.*")
+                .pattern(), "invalid pattern");
     }
 
     @Test
@@ -109,8 +109,8 @@ public class CommonUtilTest extends AbstractPathTestSupport {
             fail("exception expected");
         }
         catch (IllegalArgumentException ex) {
-            assertEquals("Invalid exception message",
-                "Failed to initialise regular expression [", ex.getMessage());
+            assertEquals("Failed to initialise regular expression [", ex.getMessage(),
+                    "Invalid exception message");
         }
     }
 
@@ -121,8 +121,8 @@ public class CommonUtilTest extends AbstractPathTestSupport {
             fail("exception expected");
         }
         catch (IllegalArgumentException ex) {
-            assertEquals("Invalid exception message",
-                "Failed to initialise regular expression [", ex.getMessage());
+            assertEquals("Failed to initialise regular expression [", ex.getMessage(),
+                    "Invalid exception message");
         }
     }
 
@@ -130,79 +130,71 @@ public class CommonUtilTest extends AbstractPathTestSupport {
     public void testCreationOfFakeCommentBlock() {
         final DetailAST testCommentBlock =
                 CommonUtil.createBlockCommentNode("test_comment");
-        assertEquals("Invalid token type",
-                TokenTypes.BLOCK_COMMENT_BEGIN, testCommentBlock.getType());
-        assertEquals("Invalid text", "/*", testCommentBlock.getText());
-        assertEquals("Invalid line number", 0, testCommentBlock.getLineNo());
+        assertEquals(TokenTypes.BLOCK_COMMENT_BEGIN, testCommentBlock.getType(),
+                "Invalid token type");
+        assertEquals("/*", testCommentBlock.getText(), "Invalid text");
+        assertEquals(0, testCommentBlock.getLineNo(), "Invalid line number");
 
         final DetailAST contentCommentBlock = testCommentBlock.getFirstChild();
-        assertEquals("Invalid token type",
-                TokenTypes.COMMENT_CONTENT, contentCommentBlock.getType());
-        assertEquals("Invalid text", "*test_comment", contentCommentBlock.getText());
-        assertEquals("Invalid line number", 0, contentCommentBlock.getLineNo());
-        assertEquals("Invalid column number", -1, contentCommentBlock.getColumnNo());
+        assertEquals(TokenTypes.COMMENT_CONTENT, contentCommentBlock.getType(),
+                "Invalid token type");
+        assertEquals("*test_comment", contentCommentBlock.getText(), "Invalid text");
+        assertEquals(0, contentCommentBlock.getLineNo(), "Invalid line number");
+        assertEquals(-1, contentCommentBlock.getColumnNo(), "Invalid column number");
 
         final DetailAST endCommentBlock = contentCommentBlock.getNextSibling();
-        assertEquals("Invalid token type", TokenTypes.BLOCK_COMMENT_END, endCommentBlock.getType());
-        assertEquals("Invalid text", "*/", endCommentBlock.getText());
+        assertEquals(TokenTypes.BLOCK_COMMENT_END, endCommentBlock.getType(), "Invalid token type");
+        assertEquals("*/", endCommentBlock.getText(), "Invalid text");
     }
 
     @Test
     public void testFileExtensions() {
         final String[] fileExtensions = {"java"};
         final File pdfFile = new File("file.pdf");
-        assertFalse("Invalid file extension",
-            CommonUtil.matchesFileExtension(pdfFile, fileExtensions));
-        assertTrue("Invalid file extension",
-            CommonUtil.matchesFileExtension(pdfFile));
-        assertTrue("Invalid file extension",
-            CommonUtil.matchesFileExtension(pdfFile, (String[]) null));
+        assertFalse(CommonUtil.matchesFileExtension(pdfFile, fileExtensions),
+                "Invalid file extension");
+        assertTrue(CommonUtil.matchesFileExtension(pdfFile), "Invalid file extension");
+        assertTrue(CommonUtil.matchesFileExtension(pdfFile, (String[]) null),
+                "Invalid file extension");
         final File javaFile = new File("file.java");
-        assertTrue("Invalid file extension",
-            CommonUtil.matchesFileExtension(javaFile, fileExtensions));
+        assertTrue(CommonUtil.matchesFileExtension(javaFile, fileExtensions),
+                "Invalid file extension");
         final File emptyExtensionFile = new File("file.");
-        assertTrue("Invalid file extension",
-            CommonUtil.matchesFileExtension(emptyExtensionFile, ""));
-        assertFalse("Invalid file extension",
-            CommonUtil.matchesFileExtension(pdfFile, ".noMatch"));
-        assertTrue("Invalid file extension",
-            CommonUtil.matchesFileExtension(pdfFile, ".pdf"));
+        assertTrue(CommonUtil.matchesFileExtension(emptyExtensionFile, ""),
+                "Invalid file extension");
+        assertFalse(CommonUtil.matchesFileExtension(pdfFile, ".noMatch"), "Invalid file extension");
+        assertTrue(CommonUtil.matchesFileExtension(pdfFile, ".pdf"), "Invalid file extension");
     }
 
     @Test
     public void testHasWhitespaceBefore() {
-        assertTrue("Invalid result",
-            CommonUtil.hasWhitespaceBefore(0, "a"));
-        assertTrue("Invalid result",
-            CommonUtil.hasWhitespaceBefore(4, "    a"));
-        assertFalse("Invalid result",
-            CommonUtil.hasWhitespaceBefore(5, "    a"));
+        assertTrue(CommonUtil.hasWhitespaceBefore(0, "a"), "Invalid result");
+        assertTrue(CommonUtil.hasWhitespaceBefore(4, "    a"), "Invalid result");
+        assertFalse(CommonUtil.hasWhitespaceBefore(5, "    a"), "Invalid result");
     }
 
     @Test
     public void testBaseClassNameForCanonicalName() {
-        assertEquals("Invalid base class name", "List",
-            CommonUtil.baseClassName("java.util.List"));
+        assertEquals("List", CommonUtil.baseClassName("java.util.List"), "Invalid base class name");
     }
 
     @Test
     public void testBaseClassNameForSimpleName() {
-        assertEquals("Invalid base class name", "Set",
-            CommonUtil.baseClassName("Set"));
+        assertEquals("Set", CommonUtil.baseClassName("Set"), "Invalid base class name");
     }
 
     @Test
     public void testRelativeNormalizedPath() {
         final String relativePath = CommonUtil.relativizeAndNormalizePath("/home", "/home/test");
 
-        assertEquals("Invalid relative path", "test", relativePath);
+        assertEquals("test", relativePath, "Invalid relative path");
     }
 
     @Test
     public void testRelativeNormalizedPathWithNullBaseDirectory() {
         final String relativePath = CommonUtil.relativizeAndNormalizePath(null, "/tmp");
 
-        assertEquals("Invalid relative path", "/tmp", relativePath);
+        assertEquals("/tmp", relativePath, "Invalid relative path");
     }
 
     @Test
@@ -214,27 +206,26 @@ public class CommonUtilTest extends AbstractPathTestSupport {
         final String relativePath = CommonUtil.relativizeAndNormalizePath(basePath,
             absoluteFilePath);
 
-        assertEquals("Invalid relative path", "SampleFile.java", relativePath);
+        assertEquals("SampleFile.java", relativePath, "Invalid relative path");
     }
 
     @Test
     public void testPattern() {
         final boolean result = CommonUtil.isPatternValid("someValidPattern");
-        assertTrue("Should return true when pattern is valid", result);
+        assertTrue(result, "Should return true when pattern is valid");
     }
 
     @Test
     public void testInvalidPattern() {
         final boolean result = CommonUtil.isPatternValid("some[invalidPattern");
-        assertFalse("Should return false when pattern is invalid", result);
+        assertFalse(result, "Should return false when pattern is invalid");
     }
 
     @Test
     public void testGetExistingConstructor() throws NoSuchMethodException {
         final Constructor<?> constructor = CommonUtil.getConstructor(String.class, String.class);
 
-        assertEquals("Invalid constructor",
-            String.class.getConstructor(String.class), constructor);
+        assertEquals(String.class.getConstructor(String.class), constructor, "Invalid constructor");
     }
 
     @Test
@@ -244,8 +235,8 @@ public class CommonUtilTest extends AbstractPathTestSupport {
             fail("IllegalStateException is expected");
         }
         catch (IllegalStateException expected) {
-            assertSame("Invalid exception cause",
-                NoSuchMethodException.class, expected.getCause().getClass());
+            assertSame(NoSuchMethodException.class, expected.getCause().getClass(),
+                    "Invalid exception cause");
         }
     }
 
@@ -255,7 +246,7 @@ public class CommonUtilTest extends AbstractPathTestSupport {
 
         final String constructedString = CommonUtil.invokeConstructor(constructor, "string");
 
-        assertEquals("Invalid construction result", "string", constructedString);
+        assertEquals("string", constructedString, "Invalid construction result");
     }
 
     @SuppressWarnings("rawtypes")
@@ -268,8 +259,8 @@ public class CommonUtilTest extends AbstractPathTestSupport {
             fail("IllegalStateException is expected");
         }
         catch (IllegalStateException expected) {
-            assertSame("Invalid exception cause", InstantiationException.class,
-                expected.getCause().getClass());
+            assertSame(InstantiationException.class,
+                expected.getCause().getClass(), "Invalid exception cause");
         }
     }
 
@@ -280,7 +271,7 @@ public class CommonUtilTest extends AbstractPathTestSupport {
         CommonUtil.close(null);
         CommonUtil.close(closeable);
 
-        assertTrue("Should be closed", closeable.closed);
+        assertTrue(closeable.closed, "Should be closed");
     }
 
     @Test
@@ -292,167 +283,158 @@ public class CommonUtilTest extends AbstractPathTestSupport {
             fail("exception expected");
         }
         catch (IllegalStateException ex) {
-            assertEquals("Invalid exception message",
-                "Cannot close the stream", ex.getMessage());
+            assertEquals("Cannot close the stream", ex.getMessage(), "Invalid exception message");
         }
     }
 
     @Test
     public void testFillTemplateWithStringsByRegexp() {
-        assertEquals("invalid result", "template", CommonUtil.fillTemplateWithStringsByRegexp(
-                "template", "lineToPlaceInTemplate", Pattern.compile("NO MATCH")));
-        assertEquals(
-                "invalid result",
-                "before word after",
+        assertEquals("template", CommonUtil.fillTemplateWithStringsByRegexp("template",
+                "lineToPlaceInTemplate", Pattern.compile("NO MATCH")), "invalid result");
+        assertEquals("before word after",
                 CommonUtil.fillTemplateWithStringsByRegexp("before $0 after", "word",
-                        Pattern.compile("\\w+")));
-        assertEquals("invalid result", "before word 123 after1 word after2 123 after3",
+                        Pattern.compile("\\w+")), "invalid result");
+        assertEquals("before word 123 after1 word after2 123 after3",
                 CommonUtil.fillTemplateWithStringsByRegexp("before $0 after1 $1 after2 $2 after3",
-                        "word 123", Pattern.compile("(\\w+) (\\d+)")));
+                        "word 123", Pattern.compile("(\\w+) (\\d+)")), "invalid result");
     }
 
     @Test
     public void testGetFileNameWithoutExtension() {
-        assertEquals("invalid result", "filename",
-                CommonUtil.getFileNameWithoutExtension("filename"));
-        assertEquals("invalid result", "filename",
-                CommonUtil.getFileNameWithoutExtension("filename.extension"));
-        assertEquals("invalid result", "filename.subext",
-                CommonUtil.getFileNameWithoutExtension("filename.subext.extension"));
+        assertEquals("filename", CommonUtil.getFileNameWithoutExtension("filename"),
+                "invalid result");
+        assertEquals("filename", CommonUtil.getFileNameWithoutExtension("filename.extension"),
+                "invalid result");
+        assertEquals("filename.subext",
+                CommonUtil.getFileNameWithoutExtension("filename.subext.extension"),
+                "invalid result");
     }
 
     @Test
     public void testGetFileExtension() {
-        assertEquals("Invalid extension", "", CommonUtil.getFileExtension("filename"));
-        assertEquals("Invalid extension", "extension",
-                CommonUtil.getFileExtension("filename.extension"));
-        assertEquals("Invalid extension", "extension",
-                CommonUtil.getFileExtension("filename.subext.extension"));
+        assertEquals("", CommonUtil.getFileExtension("filename"), "Invalid extension");
+        assertEquals("extension", CommonUtil.getFileExtension("filename.extension"),
+                "Invalid extension");
+        assertEquals("extension", CommonUtil.getFileExtension("filename.subext.extension"),
+                "Invalid extension");
     }
 
     @Test
     public void testIsIdentifier() {
-        assertTrue("Should return true when valid identifier is passed",
-            CommonUtil.isIdentifier("aValidIdentifier"));
+        assertTrue(CommonUtil.isIdentifier("aValidIdentifier"),
+                "Should return true when valid identifier is passed");
     }
 
     @Test
     public void testIsIdentifierEmptyString() {
-        assertFalse("Should return false when empty string is passed",
-            CommonUtil.isIdentifier(""));
+        assertFalse(CommonUtil.isIdentifier(""), "Should return false when empty string is passed");
     }
 
     @Test
     public void testIsIdentifierInvalidFirstSymbol() {
-        assertFalse("Should return false when invalid identifier is passed",
-            CommonUtil.isIdentifier("1InvalidIdentifier"));
+        assertFalse(CommonUtil.isIdentifier("1InvalidIdentifier"),
+                "Should return false when invalid identifier is passed");
     }
 
     @Test
     public void testIsIdentifierInvalidSymbols() {
-        assertFalse("Should return false when invalid identifier is passed",
-            CommonUtil.isIdentifier("invalid#Identifier"));
+        assertFalse(CommonUtil.isIdentifier("invalid#Identifier"),
+                "Should return false when invalid identifier is passed");
     }
 
     @Test
     public void testIsName() {
-        assertTrue("Should return true when valid name is passed",
-            CommonUtil.isName("a.valid.Nam3"));
+        assertTrue(CommonUtil.isName("a.valid.Nam3"),
+                "Should return true when valid name is passed");
     }
 
     @Test
     public void testIsNameEmptyString() {
-        assertFalse("Should return false when empty string is passed",
-            CommonUtil.isName(""));
+        assertFalse(CommonUtil.isName(""), "Should return false when empty string is passed");
     }
 
     @Test
     public void testIsNameInvalidFirstSymbol() {
-        assertFalse("Should return false when invalid name is passed",
-            CommonUtil.isName("1.invalid.name"));
+        assertFalse(CommonUtil.isName("1.invalid.name"),
+                "Should return false when invalid name is passed");
     }
 
     @Test
     public void testIsNameEmptyPart() {
-        assertFalse("Should return false when name has empty part",
-            CommonUtil.isName("invalid..name"));
+        assertFalse(CommonUtil.isName("invalid..name"),
+                "Should return false when name has empty part");
     }
 
     @Test
     public void testIsNameEmptyLastPart() {
-        assertFalse("Should return false when name has empty part",
-            CommonUtil.isName("invalid.name."));
+        assertFalse(CommonUtil.isName("invalid.name."),
+                "Should return false when name has empty part");
     }
 
     @Test
     public void testIsNameInvalidSymbol() {
-        assertFalse("Should return false when invalid name is passed",
-            CommonUtil.isName("invalid.name#42"));
+        assertFalse(CommonUtil.isName("invalid.name#42"),
+                "Should return false when invalid name is passed");
     }
 
     @Test
     public void testIsBlank() {
-        assertFalse("Should return false when string is not empty",
-            CommonUtil.isBlank("string"));
+        assertFalse(CommonUtil.isBlank("string"), "Should return false when string is not empty");
     }
 
     @Test
     public void testIsBlankAheadWhitespace() {
-        assertFalse("Should return false when string is not empty",
-            CommonUtil.isBlank("  string"));
+        assertFalse(CommonUtil.isBlank("  string"), "Should return false when string is not empty");
     }
 
     @Test
     public void testIsBlankBehindWhitespace() {
-        assertFalse("Should return false when string is not empty",
-            CommonUtil.isBlank("string    "));
+        assertFalse(CommonUtil.isBlank("string    "),
+                "Should return false when string is not empty");
     }
 
     @Test
     public void testIsBlankWithWhitespacesAround() {
-        assertFalse("Should return false when string is not empty",
-            CommonUtil.isBlank("    string    "));
+        assertFalse(CommonUtil.isBlank("    string    "),
+                "Should return false when string is not empty");
     }
 
     @Test
     public void testIsBlankWhitespaceInside() {
-        assertFalse("Should return false when string is not empty",
-            CommonUtil.isBlank("str    ing"));
+        assertFalse(CommonUtil.isBlank("str    ing"),
+                "Should return false when string is not empty");
     }
 
     @Test
     public void testIsBlankNullString() {
-        assertTrue("Should return true when string is null",
-            CommonUtil.isBlank(null));
+        assertTrue(CommonUtil.isBlank(null), "Should return true when string is null");
     }
 
     @Test
     public void testIsBlankWithEmptyString() {
-        assertTrue("Should return true when string is empty",
-            CommonUtil.isBlank(""));
+        assertTrue(CommonUtil.isBlank(""), "Should return true when string is empty");
     }
 
     @Test
     public void testIsBlankWithWhitespacesOnly() {
-        assertTrue("Should return true when string contains only spaces",
-            CommonUtil.isBlank("   "));
+        assertTrue(CommonUtil.isBlank("   "),
+                "Should return true when string contains only spaces");
     }
 
     @Test
     public void testIsIntValidString() {
-        assertTrue("Should return true when string is null", CommonUtil.isInt("42"));
+        assertTrue(CommonUtil.isInt("42"), "Should return true when string is null");
     }
 
     @Test
     public void testIsIntInvalidString() {
-        assertFalse("Should return false when object passed is not integer",
-            CommonUtil.isInt("foo"));
+        assertFalse(CommonUtil.isInt("foo"),
+                "Should return false when object passed is not integer");
     }
 
     @Test
     public void testIsIntNull() {
-        assertFalse("Should return false when null is passed",
-            CommonUtil.isInt(null));
+        assertFalse(CommonUtil.isInt(null), "Should return false when null is passed");
     }
 
     @Test
