@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,37 +20,34 @@
 package com.puppycrawl.tools.checkstyle.utils;
 
 import static com.puppycrawl.tools.checkstyle.internal.utils.TestUtil.isUtilsClassHasPrivateConstructor;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 public class FilterUtilTest {
 
-    @Rule
-    public final TemporaryFolder temporaryFolder = new TemporaryFolder();
+    @TempDir
+    public File temporaryFolder;
 
     @Test
     public void testIsProperUtilsClass() throws ReflectiveOperationException {
-        assertTrue("Constructor is not private",
-                isUtilsClassHasPrivateConstructor(FilterUtil.class, true));
+        assertTrue(isUtilsClassHasPrivateConstructor(FilterUtil.class, true),
+                "Constructor is not private");
     }
 
     @Test
     public void testExistingFile() throws Exception {
-        final File file = temporaryFolder.newFile();
-        assertTrue("Suppression file exists",
-                FilterUtil.isFileExists(file.getPath()));
+        final File file = File.createTempFile("junit", null, temporaryFolder);
+        assertTrue(FilterUtil.isFileExists(file.getPath()), "Suppression file exists");
     }
 
     @Test
     public void testNonExistentFile() {
-        assertFalse("Suppression file does not exist",
-                FilterUtil.isFileExists("non-existent.xml"));
+        assertFalse(FilterUtil.isFileExists("non-existent.xml"), "Suppression file does not exist");
     }
 
 }
