@@ -57,6 +57,18 @@ public class RootNodeTest extends AbstractPathTestSupport {
         rootNode = new RootNode(rootAst);
     }
 
+    @Test
+    public void testCompareOrder() {
+        try {
+            rootNode.compareOrder(null);
+            fail("Exception is excepted");
+        }
+        catch (UnsupportedOperationException ex) {
+            assertEquals("Operation is not supported",
+                ex.getMessage(), "Invalid exception message");
+        }
+    }
+
     @Test
     public void testXpath() throws Exception {
         final String xpath = "/";
@@ -88,11 +100,6 @@ public class RootNodeTest extends AbstractPathTestSupport {
         assertEquals("ROOT", rootNode.getLocalPart(), "Invalid local part");
     }
 
-    @Test
-    public void testGetStringValue() {
-        assertEquals("ROOT", rootNode.getStringValue(), "Invalid string value");
-    }
-
     @Test
     public void testIterate() {
         try (AxisIterator following = rootNode.iterateAxis(AxisInfo.FOLLOWING)) {
@@ -121,6 +128,18 @@ public class RootNodeTest extends AbstractPathTestSupport {
         }
     }
 
+    @Test
+    public void testGetStringValue() {
+        try {
+            rootNode.getStringValue();
+            fail("Exception is excepted");
+        }
+        catch (UnsupportedOperationException ex) {
+            assertEquals("Operation is not supported",
+                    ex.getMessage(), "Invalid exception message");
+        }
+    }
+
     @Test
     public void testGetAttributeValue() {
         try {
@@ -135,9 +154,9 @@ public class RootNodeTest extends AbstractPathTestSupport {
 
     @Test
     public void testGetDeclaredNamespaces() {
+        final NamespaceBinding[] namespaceBindings = {new NamespaceBinding("prefix", "uri")};
         try {
-            rootNode.getDeclaredNamespaces(
-                    new NamespaceBinding[] {new NamespaceBinding("prefix", "uri")});
+            rootNode.getDeclaredNamespaces(namespaceBindings);
             fail("Exception is excepted");
         }
         catch (UnsupportedOperationException ex) {
