@@ -19,6 +19,7 @@
 
 package com.puppycrawl.tools.checkstyle.xpath;
 
+import static com.google.common.truth.Truth.assertWithMessage;
 import static com.puppycrawl.tools.checkstyle.internal.utils.XpathUtil.getXpathItems;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.nullValue;
@@ -45,6 +46,28 @@ public class XpathMapperTest extends AbstractPathTestSupport {
         return "com/puppycrawl/tools/checkstyle/xpath/xpathmapper";
     }
 
+    @Test
+    public void testNodeOrdering() throws Exception {
+        final String xpath = "//METHOD_DEF/SLIST/*";
+        final RootNode rootNode = getRootNode("InputXpathMapperAst.java");
+        final List<NodeInfo> nodes = getXpathItems(xpath, rootNode);
+        for (int i = 1; i < nodes.size(); i++) {
+            final NodeInfo curr = nodes.get(i);
+            final NodeInfo prev = nodes.get(i - 1);
+
+            if (curr.getLineNumber() == prev.getLineNumber()) {
+                assertWithMessage("Column number is not in document order")
+                    .that(curr.getColumnNumber())
+                    .isGreaterThan(prev.getColumnNumber());
+            }
+            else {
+                assertWithMessage("Line number is not in document order")
+                    .that(curr.getLineNumber())
+                    .isGreaterThan(prev.getLineNumber());
+            }
+        }
+    }
+
     @Test
     public void testFullPath() throws Exception {
         final String xpath = "/CLASS_DEF/OBJBLOCK/METHOD_DEF[1]/SLIST/VARIABLE_DEF[2]";
@@ -129,7 +152,7 @@ public class XpathMapperTest extends AbstractPathTestSupport {
                 TokenTypes.PACKAGE_DEF);
         final DetailAST expectedAnnotationsNode = expectedPackageDefNode
                 .findFirstToken(TokenTypes.ANNOTATIONS);
-        final DetailAST[] expected = {expectedAnnotationsNode, expectedPackageDefNode};
+        final DetailAST[] expected = {expectedPackageDefNode, expectedAnnotationsNode};
         assertThat("Result nodes differ from expected", actual, equalTo(expected));
     }
 
@@ -147,8 +170,8 @@ public class XpathMapperTest extends AbstractPathTestSupport {
         final DetailAST expectedMethodDefNode2 = expectedObjblockNode
                 .findFirstToken(TokenTypes.METHOD_DEF)
                 .getNextSibling();
-        final DetailAST[] expected = {expectedClassDefNode, expectedMethodDefNode,
-            expectedMethodDefNode2, expectedObjblockNode};
+        final DetailAST[] expected = {expectedClassDefNode, expectedObjblockNode,
+            expectedMethodDefNode, expectedMethodDefNode2};
         assertThat("Result nodes differ from expected", actual, equalTo(expected));
     }
 
@@ -317,7 +340,7 @@ public class XpathMapperTest extends AbstractPathTestSupport {
                 TokenTypes.CLASS_DEF);
         final DetailAST[] expected = {expectedClassDefNode};
         final ElementNode classDefNode = (ElementNode) nodes.get(0);
-        assertThat("Invalid node name", classDefNode.getStringValue(), equalTo("CLASS_DEF"));
+        assertThat("Invalid node name", classDefNode.getLocalPart(), equalTo("CLASS_DEF"));
         assertThat("Result nodes differ from expected", actual, equalTo(expected));
     }
 
@@ -863,8 +886,8 @@ public class XpathMapperTest extends AbstractPathTestSupport {
                 TokenTypes.CLASS_DEF)
                 .findFirstToken(TokenTypes.OBJBLOCK)
                 .findFirstToken(TokenTypes.METHOD_DEF);
-        final DetailAST[] expected = {expectedMethodDefNode.getNextSibling(),
-            expectedMethodDefNode};
+        final DetailAST[] expected = {expectedMethodDefNode,
+            expectedMethodDefNode.getNextSibling()};
         assertThat("Result nodes differ from expected", actual, equalTo(expected));
         assertThat("Invalid token type", actual[0].getType(), equalTo(TokenTypes.METHOD_DEF));
         assertThat("Invalid token type", actual[1].getType(), equalTo(TokenTypes.METHOD_DEF));
@@ -892,8 +915,8 @@ public class XpathMapperTest extends AbstractPathTestSupport {
         final DetailAST expectedSemiNode1 = expectedVariableDefNode1.getNextSibling();
         final DetailAST expectedVariableDefNode2 = expectedSemiNode1.getNextSibling();
         final DetailAST expectedSemiNode2 = expectedVariableDefNode2.getNextSibling();
-        final DetailAST[] expected = {expectedSemiNode2, expectedSemiNode1,
-            expectedVariableDefNode2, expectedVariableDefNode1};
+        final DetailAST[] expected = {expectedVariableDefNode1, expectedSemiNode1,
+            expectedVariableDefNode2, expectedSemiNode2};
         assertThat("Result nodes differ from expected", actual, equalTo(expected));
     }
 
@@ -911,7 +934,7 @@ public class XpathMapperTest extends AbstractPathTestSupport {
                 .findFirstToken(TokenTypes.VARIABLE_DEF);
         final DetailAST expectedVariableDefNode2 = expectedVariableDefNode1.getNextSibling()
                 .getNextSibling();
-        final DetailAST[] expected = {expectedVariableDefNode2, expectedVariableDefNode1};
+        final DetailAST[] expected = {expectedVariableDefNode1, expectedVariableDefNode2};
         assertThat("Result nodes differ from expected", actual, equalTo(expected));
     }
 
@@ -946,7 +969,7 @@ public class XpathMapperTest extends AbstractPathTestSupport {
         final DetailAST expectedPackageDefNode = getSiblingByType(rootNode.getUnderlyingNode(),
                 TokenTypes.PACKAGE_DEF);
         final DetailAST expectedAnnotationsNode = expectedPackageDefNode.getFirstChild();
-        final DetailAST[] expected = {expectedAnnotationsNode, expectedPackageDefNode};
+        final DetailAST[] expected = {expectedPackageDefNode, expectedAnnotationsNode};
         assertThat("Result nodes differ from expected", actual, equalTo(expected));
     }
 
