@@ -9,8 +9,8 @@ public class InputFinalClassClassWithPrivateCtorWithNestedExtendingClass {
 
     class B {
         private B() {}
-        private class ExtendB extends
-                com.puppycrawl.tools.checkstyle.checks.design.finalclass.InputFinalClassClassWithPrivateCtorWithNestedExtendingClass.B {}
+        private class ExtendB extends com.puppycrawl.tools.checkstyle.checks.design.finalclass.
+            InputFinalClassClassWithPrivateCtorWithNestedExtendingClass.B {}
     }
 
     class C {
