@@ -60,7 +60,7 @@ public class InputEmptyCatchBlockDefaultLF
     private void foo5() {
         try {
             throw new IOException();
-        } catch (IOException | NullPointerException | ArithmeticException e) { // Some singleline comment
+        } catch (IOException | NullPointerException | ArithmeticException e) { // singleline comment
         }
     }
 
