@@ -1,13 +1,12 @@
 package com.puppycrawl.tools.checkstyle.checks.coding.illegaltype;
 import java.util.TreeSet;
-import java.util.Hashtable;
 //configuration: default
 public class InputIllegalTypeMemberModifiers {
     private AbstractClass a = null; //WARNING
     private NotAnAbstractClass b = null; /*another comment*/
 
-    private com.puppycrawl.tools.checkstyle.checks.coding.illegaltype.InputIllegalTypeMemberModifiers.AbstractClass c = null; //WARNING
-    private com.puppycrawl.tools.checkstyle.checks.coding.illegaltype.InputIllegalTypeMemberModifiers.NotAnAbstractClass d = null;
+    private java.util.AbstractList c = null; //WARNING
+    private java.util.List d = null;
 
     private abstract class AbstractClass {/*one more comment*/}
 
@@ -20,7 +19,7 @@ public class InputIllegalTypeMemberModifiers {
     }
 
     //WARNING if memberModifiers is set and contains TokenTypes.LITERAL_PROTECTED
-    protected com.puppycrawl.tools.checkstyle.checks.coding.illegaltype.InputIllegalTypeMemberModifiers.AbstractClass c1 = null;
+    protected java.util.AbstractList c1 = null;
     //NO WARNING if memberModifiers is set and does not contain TokenTypes.LITERAL_PUBLIC
     public final static java.util.TreeSet<Object> table3() { return null; }
 
