@@ -7,7 +7,7 @@ public class InputOneTopLevelClassDeclarationOrder
     }
 }
 
-enum InputDeclarationOrderEnum
+enum InputDeclarationOrderEnum // violation
 {
     ENUM_VALUE_1;
 
@@ -16,3 +16,8 @@ enum InputDeclarationOrderEnum
         protected final int maxTotalConcurrentTasks = 0;
     }
 }
+
+@interface InputDeclarationOrderAnnotation // violation
+{
+
+}
