@@ -3,8 +3,8 @@ package com.puppycrawl.tools.checkstyle.checks.imports.customimportorder;
 import java.util.Map.Entry;
 import java.util.Map;
 
-import com.google.common.*;
-import com.google.common.annotations.*;
+import com.google.common.base.*;
+import com.google.common.base.internal.*;
 
 public class InputCustomImportOrderCompareImports {
 }
