@@ -1,6 +1,6 @@
 package com.puppycrawl.tools.checkstyle.checks.imports.importorder;
 
-import org.*;
+import org.antlr.v4.runtime.*;
 
 import static java.lang.Math.PI;
 import static org.antlr.v4.runtime.Recognizer.EOF;
