@@ -8,7 +8,7 @@ package com.puppycrawl.tools.checkstyle.checks.javadoc.javadoctype;
    Checks javadoc scoping for inner classes.
 
    Once the Javadoc Check Scope has been left,
-   all inner elements should not be reported as error,
+   all inner elements should not be reported as violation,
    even if they belong to the checkscope if isolated.
 
    @author lkuehne
@@ -39,4 +39,8 @@ public class InputJavadocTypeScopeInnerClasses
             }
         }
     }
+    /** */
+    protected class InnerPublic2<T>
+    {
+    }
 }
